@@ -29,6 +29,7 @@
 #include "bstmenus.h"
 #include "bstprocedure.h"
 #include "bstprojectctrl.h"
+#include "bstprofiler.h"
 
 
 /* --- prototypes --- */
@@ -46,6 +47,23 @@ static gboolean       app_action_check            (gpointer     data,
 
 
 /* --- menus --- */
+enum {
+  ACTION_INTERNALS = BST_ACTION_APP_LAST,
+  /* dialogs */
+  ACTION_SHOW_PREFERENCES,
+  ACTION_SHOW_PROC_BROWSER,
+  ACTION_SHOW_PROFILER,
+  ACTION_EXTRA_VIEW,
+  ACTION_RACK_EDITOR,
+#define ACTION_HELP_FIRST   ACTION_HELP_FAQ
+  ACTION_HELP_FAQ,
+  ACTION_HELP_KEYTABLE,
+  ACTION_HELP_RELEASE_NOTES,
+  ACTION_HELP_GSL_PLAN,
+  ACTION_HELP_QUICK_START,
+  ACTION_HELP_ABOUT,
+#define ACTION_HELP_LAST    ACTION_HELP_ABOUT
+};
 static const GxkStockAction file_open_actions[] = {
   { N_("_New"),                 "<ctrl>N",      N_("Create new project"),
     BST_ACTION_NEW_PROJECT,     BST_STOCK_NEW,  },
@@ -69,13 +87,13 @@ static const GxkStockAction file_epilog_actions[] = {
     BST_ACTION_EXIT,            BST_STOCK_QUIT, },
 };
 static const GxkStockAction preference_actions[] = {
-  { N_("_Preferences..."),      NULL,           NULL,   BST_ACTION_SHOW_PREFERENCES,    BST_STOCK_PREFERENCES, },
+  { N_("_Preferences..."),      NULL,           NULL,   ACTION_SHOW_PREFERENCES,    BST_STOCK_PREFERENCES, },
 };
 static const GxkStockAction rebuild_actions[] = {
   { N_("Rebuild"),              NULL,           NULL,   BST_ACTION_REBUILD, },
 };
 static const GxkStockAction about_actions[] = {
-  { N_("_About..."),            NULL,           NULL,   BST_ACTION_HELP_ABOUT,          BST_STOCK_ABOUT },
+  { N_("_About..."),            NULL,           NULL,   ACTION_HELP_ABOUT,          BST_STOCK_ABOUT },
 };
 static const GxkStockAction undo_actions[] = {
   { N_("_Undo"),                "<ctrl>Z",      NULL,
@@ -89,11 +107,13 @@ static const GxkStockAction undo_dvl_actions[] = {
 };
 static const GxkStockAction dialog_actions[] = {
   { N_("Procedure _Browser"),   NULL,           NULL,
-    BST_ACTION_SHOW_PROC_BROWSER, },
+    ACTION_SHOW_PROC_BROWSER, },
   { N_("Rack Editor"),          NULL,           NULL,
-    BST_ACTION_RACK_EDITOR, },
+    ACTION_RACK_EDITOR, },
+  { N_("Profiler"),             NULL,           NULL,
+    ACTION_SHOW_PROFILER, },
   { N_("New View"),             NULL,           NULL,
-    BST_ACTION_EXTRA_VIEW, },
+    ACTION_EXTRA_VIEW, },
 };
 static const GxkStockAction playback_actions[] = {
   { N_("_Play"),                "<ctrl>P",      NULL,
@@ -122,12 +142,12 @@ static const GxkStockAction library_files_actions[] = {
     BST_ACTION_SAVE_EFFECT, },
 };
 static const GxkStockAction simple_help_actions[] = {
-  { N_("_Release Notes..."),    NULL,           NULL,   BST_ACTION_HELP_RELEASE_NOTES,  BST_STOCK_DOC_NEWS },
-  { N_("Quick Start..."),       NULL,           NULL,   BST_ACTION_HELP_QUICK_START,    BST_STOCK_HELP },
-  { N_("_FAQ..."),              NULL,           NULL,   BST_ACTION_HELP_FAQ,            BST_STOCK_DOC_FAQ },
+  { N_("_Release Notes..."),    NULL,           NULL,   ACTION_HELP_RELEASE_NOTES,  BST_STOCK_DOC_NEWS },
+  { N_("Quick Start..."),       NULL,           NULL,   ACTION_HELP_QUICK_START,    BST_STOCK_HELP },
+  { N_("_FAQ..."),              NULL,           NULL,   ACTION_HELP_FAQ,            BST_STOCK_DOC_FAQ },
 };
 static const GxkStockAction devel_help_actions[] = {
-  { N_("GSL Engine..."),        NULL,           NULL,   BST_ACTION_HELP_GSL_PLAN,       BST_STOCK_DOC_DEVEL },
+  { N_("GSL Engine..."),        NULL,           NULL,   ACTION_HELP_GSL_PLAN,       BST_STOCK_DOC_DEVEL },
 };
 
 
@@ -143,13 +163,13 @@ bst_app_class_init (BstAppClass *class)
 {
   GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
-
+  
   bst_app_class = class;
-
+  
   object_class->destroy = bst_app_destroy;
-
+  
   widget_class->delete_event = bst_app_handle_delete_event;
-
+  
   class->apps = NULL;
 }
 
@@ -179,7 +199,7 @@ bst_app_init (BstApp *self)
                 "flags", GXK_DIALOG_STATUS_SHELL,
                 NULL);
   bst_app_register (self);
-  self->box = gxk_gadget_create ("beast", "application-box", NULL);
+  self->box = gxk_radget_create ("beast", "application-box", NULL);
   gtk_container_add (GTK_CONTAINER (GXK_DIALOG (self)->vbox), self->box);
   
   /* publish widget specific actions */
@@ -244,20 +264,26 @@ bst_app_init (BstApp *self)
   al1 = skin_entries_create (self);
   gxk_action_list_sort (al1);
   gxk_widget_publish_action_list (widget, "skin-options", al1);
-
+  
   /* setup playback controls */
   self->pcontrols = g_object_new (BST_TYPE_PROJECT_CTRL, NULL);
-  gxk_gadget_add (self->box, "control-area", self->pcontrols);
-
+  gxk_radget_add (self->box, "control-area", self->pcontrols);
+  
   /* setup WAVE file entry */
+  gxk_radget_add (self->box, "control-area", gxk_vseparator_space_new (TRUE));
   self->wave_file = bst_param_new_proxy (bse_proxy_get_pspec (BSE_SERVER, "wave_file"), BSE_SERVER);
-  gxk_gadget_add (self->box, "control-area", gxk_vseparator_space_new (TRUE));
-  gxk_gadget_add (self->box, "control-area", gxk_param_create_editor (self->wave_file, "name"));
-  gxk_gadget_add (self->box, "control-area", gxk_param_create_editor (self->wave_file, NULL));
+  if (0) // FIXME
+    gxk_radget_add (self->box, "control-area-file-label", gxk_param_create_editor (self->wave_file, "name"));
+  else
+    gxk_radget_add (self->box, "control-area-file-label", g_object_new (GTK_TYPE_LABEL,
+                                                                        "visible", TRUE,
+                                                                        "label", _("Export Audio"),
+                                                                        NULL));
+  gxk_radget_add (self->box, "control-area-file-entry", gxk_param_create_editor (self->wave_file, NULL));
   gxk_param_update (self->wave_file);
-
+  
   /* setup the main notebook */
-  self->notebook = gxk_gadget_find (self->box, "main-notebook");
+  self->notebook = gxk_radget_find (self->box, "main-notebook");
   gxk_nullify_in_object (self, &self->notebook);
   g_object_connect (self->notebook,
                     "swapped_signal_after::switch-page", gxk_widget_update_actions, self,
@@ -269,7 +295,7 @@ static void
 bst_app_destroy (GtkObject *object)
 {
   BstApp *self = BST_APP (object);
-
+  
   if (self->wave_file)
     {
       gxk_param_destroy (self->wave_file);
@@ -278,24 +304,24 @@ bst_app_destroy (GtkObject *object)
   
   if (self->rack_dialog)
     gtk_widget_destroy (self->rack_dialog);
-
+  
   if (self->project)
     {
       if (self->pcontrols)
         bst_project_ctrl_set_project (BST_PROJECT_CTRL (self->pcontrols), 0);
       bse_project_deactivate (self->project);
       bse_proxy_disconnect (self->project,
-                           "any_signal", bst_app_reload_supers, self,
-                           "any_signal", gxk_widget_update_actions, self,
-                           NULL);
+                            "any_signal", bst_app_reload_supers, self,
+                            "any_signal", gxk_widget_update_actions, self,
+                            NULL);
       bse_item_unuse (self->project);
       self->project = 0;
     }
-
+  
   bst_app_unregister (self);
-
+  
   GTK_OBJECT_CLASS (bst_app_parent_class)->destroy (object);
-
+  
   if (!bst_app_class->apps && bst_app_class->seen_apps)
     {
       bst_app_class->seen_apps = FALSE;
@@ -309,19 +335,19 @@ bst_app_new (SfiProxy project)
   GdkGeometry geometry;
   GtkWidget *widget;
   BstApp *self;
-
+  
   g_return_val_if_fail (BSE_IS_PROJECT (project), NULL);
-
+  
   widget = gtk_widget_new (BST_TYPE_APP,
                            "default_width", 640,
                            "default_height", 512,
                            NULL);
   self = BST_APP (widget);
-
+  
   geometry.min_width = 320;
   geometry.min_height = 450;
   gtk_window_set_geometry_hints (GTK_WINDOW (widget), NULL, &geometry, GDK_HINT_MIN_SIZE);
-
+  
   self->project = project;
   bse_item_use (self->project);
   bse_proxy_connect (self->project,
@@ -335,11 +361,11 @@ bst_app_new (SfiProxy project)
     bst_project_ctrl_set_project (BST_PROJECT_CTRL (self->pcontrols), self->project);
   
   bst_app_reload_supers (self);
-
+  
   /* update menu entries
    */
   gxk_widget_update_actions (self);
-
+  
   return self;
 }
 
@@ -349,11 +375,11 @@ bst_app_find (SfiProxy project)
   GSList *slist;
   
   g_return_val_if_fail (BSE_IS_PROJECT (project), NULL);
-
+  
   for (slist = bst_app_class->apps; slist; slist = slist->next)
     {
       BstApp *app = slist->data;
-
+      
       if (app->project == project)
         return app;
     }
@@ -364,14 +390,14 @@ GtkWidget*
 bst_app_get_current_shell (BstApp *app)
 {
   g_return_val_if_fail (BST_IS_APP (app), NULL);
-
+  
   if (app->notebook && app->notebook->cur_page)
     {
       g_return_val_if_fail (BST_IS_SUPER_SHELL (gtk_notebook_current_widget (app->notebook)), NULL);
-
+      
       return gtk_notebook_current_widget (app->notebook);
     }
-
+  
   return NULL;
 }
 
@@ -397,7 +423,7 @@ bst_app_reload_supers (BstApp *app)
   guint i;
   
   g_return_if_fail (BST_IS_APP (app));
-
+  
   old_focus = GTK_WINDOW (app)->focus_widget;
   if (old_focus)
     gtk_widget_ref (old_focus);
@@ -408,16 +434,16 @@ bst_app_reload_supers (BstApp *app)
       page_list = g_slist_prepend (page_list, gtk_notebook_current_widget (app->notebook));
       gtk_container_remove (GTK_CONTAINER (app->notebook), page_list->data);
     }
-
+  
   iseq = bse_project_get_supers (app->project);
   for (i = 0; i < iseq->n_items; i++)
     {
       GtkWidget *label, *page = NULL;
       GSList *node;
-
+      
       if (!BST_DBG_EXT && bse_item_internal (iseq->items[i]))
         continue;
-
+      
       for (node = page_list; node; node = node->next)
         if (BST_SUPER_SHELL (node->data)->super == iseq->items[i])
           {
@@ -453,7 +479,7 @@ bst_app_reload_supers (BstApp *app)
     gxk_notebook_set_current_page_widget (app->notebook, song_page);
   else if (synth_page)
     gxk_notebook_set_current_page_widget (app->notebook, synth_page);
-
+  
   if (old_focus)
     {
       if (old_page && gtk_widget_is_ancestor (old_focus, old_page) &&
@@ -474,13 +500,13 @@ bst_app_handle_delete_event (GtkWidget   *widget,
                              GdkEventAny *event)
 {
   BstApp *app;
-
+  
   g_return_val_if_fail (BST_IS_APP (widget), FALSE);
-
+  
   app = BST_APP (widget);
-
+  
   gtk_widget_destroy (widget);
-
+  
   return TRUE;
 }
 
@@ -488,9 +514,9 @@ static void
 rebuild_super_shell (BstSuperShell *super_shell)
 {
   SfiProxy proxy;
-
+  
   g_return_if_fail (BST_IS_SUPER_SHELL (super_shell));
-
+  
   proxy = super_shell->super;
   bse_item_use (proxy);
   bst_super_shell_set_super (super_shell, 0);
@@ -632,7 +658,7 @@ bst_app_run_script_proc (gpointer data,
   GtkWidget *shell = bst_app_get_current_shell (self);
   SfiProxy super = shell ? BST_SUPER_SHELL (shell)->super : 0;
   const gchar *song = "", *wave_repo = "", *snet = "", *csynth = "";
-
+  
   if (BSE_IS_SONG (super))
     song = "song";
   else if (BSE_IS_WAVE_REPO (super))
@@ -643,7 +669,7 @@ bst_app_run_script_proc (gpointer data,
       if (BSE_IS_CSYNTH (super))
         csynth = "csynth";
     }
-
+  
   bst_procedure_exec_auto (cat->type,
                            "project", SFI_TYPE_PROXY, self->project,
                            song, SFI_TYPE_PROXY, super,
@@ -654,25 +680,24 @@ bst_app_run_script_proc (gpointer data,
 }
 
 void
-bst_app_trigger_action (BstApp *app,
-                        gulong  action)
+bst_app_show_release_notes (BstApp *app)
 {
-  if (app_action_check (app, action))
-    app_action_exec (app, action);
+  if (app_action_check (app, ACTION_HELP_RELEASE_NOTES))
+    app_action_exec (app, ACTION_HELP_RELEASE_NOTES);
 }
 
 static void
 app_action_exec (gpointer data,
                  gulong   action)
 {
-  static GtkWidget *bst_help_dialogs[BST_ACTION_HELP_LAST - BST_ACTION_HELP_FIRST + 1] = { NULL, };
+  static GtkWidget *bst_help_dialogs[ACTION_HELP_LAST - ACTION_HELP_FIRST + 1] = { NULL, };
   static GtkWidget *bst_preferences = NULL;
   BstApp *self = BST_APP (data);
   gchar *help_file = NULL, *help_title = NULL;
   GtkWidget *widget = GTK_WIDGET (self);
   
   gxk_status_window_push (widget);
-
+  
   switch (action)
     {
       SfiProxy proxy;
@@ -681,7 +706,7 @@ app_action_exec (gpointer data,
       if (bst_app_class)
         {
           GSList *slist, *free_slist = g_slist_copy (bst_app_class->apps);
-
+          
           for (slist = free_slist; slist; slist = slist->next)
             gxk_toplevel_delete (slist->data);
           g_slist_free (free_slist);
@@ -695,11 +720,11 @@ app_action_exec (gpointer data,
         {
           SfiProxy project = bse_server_use_new_project (BSE_SERVER, "Untitled.bse");
           BstApp *new_app;
-
+          
           bse_project_get_wave_repo (project);
           new_app = bst_app_new (project);
           bse_item_unuse (project);
-
+          
           gxk_idle_show_widget (GTK_WIDGET (new_app));
         }
       break;
@@ -757,7 +782,7 @@ app_action_exec (gpointer data,
     case BST_ACTION_STOP_PLAYBACK:
       bst_project_ctrl_stop (BST_PROJECT_CTRL (self->pcontrols));
       break;
-    case BST_ACTION_RACK_EDITOR:
+    case ACTION_RACK_EDITOR:
       if (!self->rack_dialog)
         {
           BstRackEditor *ed = g_object_new (BST_TYPE_RACK_EDITOR,
@@ -774,7 +799,7 @@ app_action_exec (gpointer data,
         }
       gxk_widget_showraise (self->rack_dialog);
       break;
-    case BST_ACTION_SHOW_PREFERENCES:
+    case ACTION_SHOW_PREFERENCES:
       if (!bst_preferences)
         {
           GtkWidget *widget = g_object_new (BST_TYPE_PREFERENCES,
@@ -791,16 +816,20 @@ app_action_exec (gpointer data,
         bst_preferences_revert (BST_PREFERENCES (gxk_dialog_get_child (GXK_DIALOG (bst_preferences))));
       gxk_widget_showraise (bst_preferences);
       break;
-    case BST_ACTION_EXTRA_VIEW:
+    case ACTION_EXTRA_VIEW:
       any = (GtkWidget*) bst_app_new (self->project);
       gxk_idle_show_widget (any);
       break;
-    case BST_ACTION_SHOW_PROC_BROWSER:
+    case ACTION_SHOW_PROFILER:
+      any = bst_profiler_window_get ();
+      gxk_idle_show_widget (any);
+      break;
+    case ACTION_SHOW_PROC_BROWSER:
 #if 0 // FIXME
       if (!bst_proc_browser)
         {
           GtkWidget *widget;
-
+          
           widget = bst_proc_browser_new ();
           gtk_widget_show (widget);
           bst_proc_browser = gxk_dialog_new (&bst_proc_browser,
@@ -849,54 +878,54 @@ app_action_exec (gpointer data,
                              NULL);
       gtk_widget_queue_draw (GTK_WIDGET (self->notebook));
       break;
-    case BST_ACTION_HELP_FAQ:
+    case ACTION_HELP_FAQ:
       help_file = g_strconcat (BST_PATH_DOCS, "/faq.markup", NULL);
       help_title = g_strdup (help_file);
       goto HELP_DIALOG;
-    case BST_ACTION_HELP_GSL_PLAN:
+    case ACTION_HELP_GSL_PLAN:
       help_file = g_strconcat (BST_PATH_DOCS, "/engine-mplan.markup", NULL);
       help_title = g_strdup (help_file);
       goto HELP_DIALOG;
-    case BST_ACTION_HELP_QUICK_START:
+    case ACTION_HELP_QUICK_START:
       help_file = g_strconcat (BST_PATH_DOCS, "/quickstart.markup", NULL);
       help_title = g_strdup (help_file);
       goto HELP_DIALOG;
-    case BST_ACTION_HELP_RELEASE_NOTES:
+    case ACTION_HELP_RELEASE_NOTES:
       help_file = g_strconcat (BST_PATH_DOCS, "/release-notes.markup", NULL);
       help_title = g_strdup_printf (_("BEAST-%s Release Notes"), BST_VERSION);
       goto HELP_DIALOG;
     HELP_DIALOG:
-      if (!bst_help_dialogs[action - BST_ACTION_HELP_FIRST])
+      if (!bst_help_dialogs[action - ACTION_HELP_FIRST])
         {
           GtkWidget *sctext = gxk_scroll_text_create (GXK_SCROLL_TEXT_NAVIGATABLE, NULL);
           gchar *index = g_strconcat ("file://", BST_PATH_DOCS, "/beast-index.markup", NULL);
           gxk_scroll_text_set_index (sctext, index);
           g_free (index);
           gxk_scroll_text_enter (sctext, help_file);
-          bst_help_dialogs[action - BST_ACTION_HELP_FIRST] = gxk_dialog_new (&bst_help_dialogs[action - BST_ACTION_HELP_FIRST],
-                                                                             NULL,
-                                                                             GXK_DIALOG_HIDE_ON_DELETE | GXK_DIALOG_DELETE_BUTTON,
-                                                                             help_title, sctext);
-          g_object_set (bst_help_dialogs[action - BST_ACTION_HELP_FIRST],
+          bst_help_dialogs[action - ACTION_HELP_FIRST] = gxk_dialog_new (&bst_help_dialogs[action - ACTION_HELP_FIRST],
+                                                                         NULL,
+                                                                         GXK_DIALOG_HIDE_ON_DELETE | GXK_DIALOG_DELETE_BUTTON,
+                                                                         help_title, sctext);
+          g_object_set (bst_help_dialogs[action - ACTION_HELP_FIRST],
                         "default_width", 560,
                         "default_height", 640,
                         NULL);
         }
       g_free (help_file);
       g_free (help_title);
-      gxk_scroll_text_rewind (gxk_dialog_get_child (GXK_DIALOG (bst_help_dialogs[action - BST_ACTION_HELP_FIRST])));
-      gxk_widget_showraise (bst_help_dialogs[action - BST_ACTION_HELP_FIRST]);
+      gxk_scroll_text_rewind (gxk_dialog_get_child (GXK_DIALOG (bst_help_dialogs[action - ACTION_HELP_FIRST])));
+      gxk_widget_showraise (bst_help_dialogs[action - ACTION_HELP_FIRST]);
       break;
-    case BST_ACTION_HELP_ABOUT:
+    case ACTION_HELP_ABOUT:
       beast_show_about_box ();
       break;
     default:
       g_assert_not_reached ();
       break;
     }
-
+  
   gxk_status_window_pop ();
-
+  
   gxk_widget_update_actions_downwards (self);
 }
 
@@ -939,11 +968,12 @@ app_action_check (gpointer data,
       if (self->project && bse_project_is_playing (self->project))
         return TRUE;
       return FALSE;
-    case BST_ACTION_RACK_EDITOR:
-    case BST_ACTION_SHOW_PROC_BROWSER:
+    case ACTION_RACK_EDITOR:
+    case ACTION_SHOW_PROC_BROWSER:
       return FALSE;
-    case BST_ACTION_SHOW_PREFERENCES:
-    case BST_ACTION_EXTRA_VIEW:
+    case ACTION_SHOW_PREFERENCES:
+    case ACTION_EXTRA_VIEW:
+    case ACTION_SHOW_PROFILER:
       return TRUE;
     case BST_ACTION_MERGE_EFFECT:
     case BST_ACTION_MERGE_INSTRUMENT:
@@ -952,18 +982,18 @@ app_action_check (gpointer data,
     case BST_ACTION_SAVE_INSTRUMENT:
       super = bst_app_get_current_super (self);
       return BSE_IS_CSYNTH (super) && !bse_project_is_active (self->project);
-    case BST_ACTION_HELP_ABOUT:
-    case BST_ACTION_HELP_FAQ:
-    case BST_ACTION_HELP_GSL_PLAN:
-    case BST_ACTION_HELP_RELEASE_NOTES:
-    case BST_ACTION_HELP_QUICK_START:
+    case ACTION_HELP_ABOUT:
+    case ACTION_HELP_FAQ:
+    case ACTION_HELP_GSL_PLAN:
+    case ACTION_HELP_RELEASE_NOTES:
+    case ACTION_HELP_QUICK_START:
       return TRUE;
     case BST_ACTION_EXIT:
       /* abuse generic "Exit" update to sync Tools menu items */
       super = bst_app_get_current_super (self);
-      gxk_gadget_sensitize (self, "song-submenu", BSE_IS_SONG (super));
-      gxk_gadget_sensitize (self, "synth-submenu", BSE_IS_SNET (super) && !BSE_IS_SONG (super));
-      gxk_gadget_sensitize (self, "waves-submenu", BSE_IS_WAVE_REPO (super));
+      gxk_radget_sensitize (self, "song-submenu", BSE_IS_SONG (super));
+      gxk_radget_sensitize (self, "synth-submenu", BSE_IS_SNET (super) && !BSE_IS_SONG (super));
+      gxk_radget_sensitize (self, "waves-submenu", BSE_IS_WAVE_REPO (super));
       return TRUE;
     default:
       g_warning ("BstApp: unknown action: %lu", action);
