@@ -21,9 +21,6 @@
 
 
 /* --- prototypes --- */
-static void	bst_item_view_class_init	(BstItemViewClass	*klass);
-static void	bst_item_view_init		(BstItemView		*self,
-						 BstItemViewClass	*real_class);
 static void	bst_item_view_destroy		(GtkObject		*object);
 static void	bst_item_view_finalize		(GObject		*object);
 static void	item_view_listen_on		(BstItemView		*self,
@@ -34,32 +31,8 @@ static void	item_view_set_container		(BstItemView		*self,
 						 SfiProxy		 new_container);
 
 
-/* --- static variables --- */
-static gpointer		 parent_class = NULL;
-
-
 /* --- functions --- */
-GType
-bst_item_view_get_type (void)
-{
-  static GType type = 0;
-  if (!type)
-    {
-      static const GTypeInfo type_info = {
-        sizeof (BstItemViewClass),
-	(GBaseInitFunc) NULL,
-	(GBaseFinalizeFunc) NULL,
-	(GClassInitFunc) bst_item_view_class_init,
-	NULL,   /* class_finalize */
-	NULL,   /* class_data */
-	sizeof (BstItemView),
-	0,      /* n_preallocs */
-	(GInstanceInitFunc) bst_item_view_init,
-      };
-      type = g_type_register_static (GTK_TYPE_ALIGNMENT, "BstItemView", &type_info, 0);
-    }
-  return type;
-}
+G_DEFINE_TYPE (BstItemView, bst_item_view, GTK_TYPE_ALIGNMENT);
 
 static void
 bst_item_view_class_init (BstItemViewClass *class)
@@ -67,8 +40,6 @@ bst_item_view_class_init (BstItemViewClass *class)
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
   
-  parent_class = g_type_class_peek_parent (class);
-  
   gobject_class->finalize = bst_item_view_finalize;
 
   object_class->destroy = bst_item_view_destroy;
@@ -82,8 +53,7 @@ bst_item_view_class_init (BstItemViewClass *class)
 }
 
 static void
-bst_item_view_init (BstItemView      *self,
-		    BstItemViewClass *ITEM_VIEW_CLASS)
+bst_item_view_init (BstItemView *self)
 {
   self->container = 0;
 }
@@ -95,7 +65,7 @@ bst_item_view_destroy (GtkObject *object)
 
   bst_item_view_set_container (self, 0);
   
-  GTK_OBJECT_CLASS (parent_class)->destroy (object);
+  GTK_OBJECT_CLASS (bst_item_view_parent_class)->destroy (object);
 }
 
 static void
@@ -109,7 +79,7 @@ bst_item_view_finalize (GObject *object)
   if (self->wlist)
     g_object_unref (self->wlist);
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (bst_item_view_parent_class)->finalize (object);
 }
 
 void
@@ -195,7 +165,7 @@ bst_item_view_set_tree (BstItemView *self,
   g_return_if_fail (self->tree == NULL);
 
   self->tree = tree;
-  gxk_nullify_on_destroy (self->tree, &self->tree);
+  gxk_nullify_in_object (self, &self->tree);
 
   /* keep property editor updated */
   g_object_connect (gtk_tree_view_get_selection (self->tree),
@@ -377,13 +347,15 @@ bst_item_view_get_proxy (BstItemView *self,
       GtkTreeIter siter, witer;
       GtkTreeModel *smodel = gtk_tree_view_get_model (self->tree);
       GtkTreePath *path = gtk_tree_path_new_from_indices (row, -1);
-      gtk_tree_model_get_iter (smodel, &siter, path);
+      if (gxk_tree_model_get_iter (smodel, &siter, path))
+        {
+          if (GTK_IS_TREE_MODEL_SORT (smodel))
+            gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT (smodel), &witer, &siter);
+          else
+            witer = siter;
+          item = bst_child_list_wrapper_get_from_iter (self->wlist, &witer);
+        }
       gtk_tree_path_free (path);
-      if (GTK_IS_TREE_MODEL_SORT (smodel))
-	gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT (smodel), &witer, &siter);
-      else
-	witer = siter;
-      item = bst_child_list_wrapper_get_from_iter (self->wlist, &witer);
     }
   if (item)
     g_return_val_if_fail (BSE_IS_ITEM (item), 0);
@@ -423,7 +395,7 @@ bst_item_view_build_param_view (BstItemView  *self,
 
   /* property view */
   self->pview = bst_param_view_new (0);
-  gxk_nullify_on_destroy (self->pview, &self->pview);
+  gxk_nullify_in_object (self, &self->pview);
   bst_param_view_set_mask (BST_PARAM_VIEW (self->pview), "BseItem", 0, NULL, NULL);
   gtk_widget_show (self->pview);
   gtk_container_add (container, self->pview);
