@@ -102,19 +102,19 @@ main (int   argc,
 
   /* initialize Sfi guts */
   sfi_init ();
-  sfi_log_allow_info ("all");
-  // sfi_log_allow_debug ("misc");
+  sfi_debug_allow ("misc");
   /* ensure SFI can wake us up */
+  sfi_thread_set_name ("Beast GUI");
   sfi_thread_set_wakeup ((SfiThreadWakeup) g_main_context_wakeup,
 			 g_main_context_default (), NULL);
 
   /* pre-parse BEAST args */
   bseconfig = sfi_rec_new ();
-  bst_early_parse_args (&argc, &argv, bseconfig);
 
   /* initialize Gtk+ and go into threading mode */
+  bst_early_parse_args (&argc, &argv, bseconfig);
   gtk_init (&argc, &argv);
-  g_set_prgname ("BEAST");	/* overriding Gdk's program name */
+  g_set_prgname ("beast");	/* overriding Gdk's program name */
   GDK_THREADS_ENTER ();
 
   /* initialize Gtk+ Extension Kit */
@@ -249,7 +249,7 @@ main (int   argc,
    */
   bst_splash_update_entity (beast_splash, _("Dialogs"));
   bst_catch_scripts_and_msgs ();
-  _bst_init_gadgets ();
+  _bst_init_radgets ();
 
   /* open files given on command line
    */
@@ -325,13 +325,14 @@ main (int   argc,
   if (!BST_RC_VERSION || strcmp (BST_RC_VERSION, BST_VERSION))
     {
       save_rc_file = TRUE;
-      bst_app_trigger_action (app, BST_ACTION_HELP_RELEASE_NOTES);
+      bst_app_show_release_notes (app);
       bst_gconfig_set_rc_version (BST_VERSION);
     }
 
-  /* release splash grab */
+  /* release splash grab, install message dialog handler */
   gtk_widget_hide (beast_splash);
   bst_splash_release_grab (beast_splash);
+  sfi_log_set_handler (bst_user_message_log_handler);
   /* away into the main loop */
   while (bst_main_loop_running)
     {
@@ -340,6 +341,7 @@ main (int   argc,
       g_main_iteration (TRUE);
       GDK_THREADS_ENTER ();
     }
+  sfi_log_set_handler (NULL);
   
   /* stop everything playing
    */
@@ -401,18 +403,18 @@ bst_early_parse_args (int    *argc_p,
   gchar *envar;
   guint i, e;
   
-  envar = getenv ("BEAST_DEBUG");
-  if (envar)
-    {
-      sfi_log_allow_debug (envar);
-      sfi_log_allow_info (envar);
-    }
   envar = getenv ("BST_DEBUG");
   if (envar)
-    {
-      sfi_log_allow_debug (envar);
-      sfi_log_allow_info (envar);
-    }
+    sfi_debug_allow (envar);
+  envar = getenv ("BST_NO_DEBUG");
+  if (envar)
+    sfi_debug_deny (envar);
+  envar = getenv ("BEAST_DEBUG");
+  if (envar)
+    sfi_debug_allow (envar);
+  envar = getenv ("BEAST_NO_DEBUG");
+  if (envar)
+    sfi_debug_deny (envar);
 
   for (i = 1; i < argc; i++)
     {
@@ -460,7 +462,7 @@ bst_early_parse_args (int    *argc_p,
 	}
       else if (strcmp ("--debug-list", argv[i]) == 0)
 	{
-	  const gchar **keys = _bst_log_scan_keys ();
+	  const gchar **keys = _bst_log_debug_keys ();
 	  guint i;
 	  g_print ("debug keys: all");
 	  for (i = 0; keys[i]; i++)
@@ -475,15 +477,25 @@ bst_early_parse_args (int    *argc_p,
 	  gchar *equal = argv[i] + 7;
 	  
 	  if (*equal == '=')
-	    {
-	      sfi_log_allow_debug (equal + 1);
-	      sfi_log_allow_info (equal + 1);
-	    }
+            sfi_debug_allow (equal + 1);
 	  else if (i + 1 < argc)
 	    {
 	      argv[i++] = NULL;
-	      sfi_log_allow_debug (argv[i]);
-	      sfi_log_allow_info (argv[i]);
+	      sfi_debug_allow (argv[i]);
+	    }
+	  argv[i] = NULL;
+	}
+      else if (strcmp ("--no-debug", argv[i]) == 0 ||
+	       strncmp ("--no-debug=", argv[i], 8) == 0)
+	{
+	  gchar *equal = argv[i] + 7;
+	  
+	  if (*equal == '=')
+            sfi_debug_deny (equal + 1);
+	  else if (i + 1 < argc)
+	    {
+	      argv[i++] = NULL;
+	      sfi_debug_deny (argv[i]);
 	    }
 	  argv[i] = NULL;
 	}
@@ -517,7 +529,9 @@ bst_early_parse_args (int    *argc_p,
 	{
 	  gchar *arg = argv[i][12 - 1] == '=' ? argv[i] + 12 : (argv[i + 1] ? argv[i + 1] : "");
           gchar *freeme = NULL;
-	  if (strcmp (arg, "docs") == 0)
+	  if (strcmp (arg, "prefix") == 0)
+	    g_print ("%s\n", BST_PATH_PREFIX);
+	  else if (strcmp (arg, "docs") == 0)
 	    g_print ("%s\n", BST_PATH_DOCS);
 	  else if (strcmp (arg, "images") == 0)
 	    g_print ("%s\n", BST_PATH_IMAGES);
@@ -545,7 +559,7 @@ bst_early_parse_args (int    *argc_p,
 	    {
 	      if (arg[0])
                 g_message ("no such resource path: %s", arg);
-	      g_message ("supported resource paths: docs, images, locale, keys, skins, ladspa, plugins, scripts, effects, instruments, demo, samples");
+	      g_message ("supported resource paths: prefix, docs, images, keys, locale, skins, ladspa, plugins, scripts, effects, instruments, demo, samples");
 	    }
           g_free (freeme);
 	  exit (0);
@@ -553,22 +567,15 @@ bst_early_parse_args (int    *argc_p,
     }
   gxk_param_set_devel_tips (bst_developer_hints);
 
-  e = 0;
+  e = 1;
   for (i = 1; i < argc; i++)
-    {
-      if (e)
-	{
-	  if (argv[i])
-	    {
-	      argv[e++] = argv[i];
-	      argv[i] = NULL;
-	    }
-	}
-      else if (!argv[i])
-	e = i;
-    }
-  if (e)
-    *argc_p = e;
+    if (argv[i])
+      {
+        argv[e++] = argv[i];
+        if (i >= e)
+          argv[i] = NULL;
+      }
+  *argc_p = e;
 }
 
 static void G_GNUC_NORETURN
@@ -597,6 +604,7 @@ bst_exit_print_version (void)
   g_print ("\n");
   g_print ("Compiled for: %s\n", BST_ARCH_NAME);
   g_print ("\n");
+  g_print ("Prefix:          %s\n", BST_PATH_PREFIX);
   g_print ("Doc Path:        %s\n", BST_PATH_DOCS);
   g_print ("Image Path:      %s\n", BST_PATH_IMAGES);
   g_print ("Locale Path:     %s\n", BST_PATH_LOCALE);
@@ -634,7 +642,8 @@ bst_print_blurb (void)
   g_print ("  -v, --version           print version and file paths\n");
   g_print ("  --display=DISPLAY       X server for the GUI; see X(1)\n");
   g_print ("Development Options:\n");
-  g_print ("  --debug=KEYS            enable certain verbosity stages\n");
+  g_print ("  --debug=KEYS            enable specific debugging messages\n");
+  g_print ("  --no-debug=KEYS         disable specific debugging messages\n");
   g_print ("  --debug-list            list possible debug keys\n");
   g_print ("  -:[flags]               [flags] can be any of:\n");
   g_print ("                          f - fatal warnings\n");
@@ -685,6 +694,7 @@ beast_show_about_box (void)
     //"Tim Janik",
     //"Stefan Westerfeld",
     /* translations */
+    "Adam Weinberger",
     "Alexandre Prokoudine",
     "Christian Neumair",
     "Christian Rose",
@@ -693,12 +703,14 @@ beast_show_about_box (void)
     "Duarte Loreto",
     "Dulmandakh Sukhbaatar",
     "Francisco Javier F. Serrador",
+    "Gareth Owen",
     "Ismael Andres Rubio Rojas",
     "Kees van den Broek",
     "Kostas Papadimas",
     "Laurent Dhima",
     "Metin Amiroff",
     "Miloslav Trmac",
+    "Raphael Higino",
     "Robert Sedak",
     "Tino Meinen",
     "Vincent van Adrighem",
