@@ -47,6 +47,7 @@ param_searchpath_assign (GtkWidget  *dialog,
 static void
 param_searchpath_popup_remove (GtkWidget *widget)
 {
+  gtk_widget_grab_focus (widget);
   if (gtk_editable_get_editable (GTK_EDITABLE (widget)))
     {
       GtkEntry *entry = GTK_ENTRY (widget);
@@ -78,6 +79,7 @@ param_searchpath_add (GtkWidget   *dialog,
 static void
 param_searchpath_popup_add (GtkWidget *widget)
 {
+  gtk_widget_grab_focus (widget);
   if (gtk_editable_get_editable (GTK_EDITABLE (widget)))
     {
       GtkWidget *dialog = bst_file_dialog_popup_select_dir (widget);
@@ -85,6 +87,27 @@ param_searchpath_popup_add (GtkWidget *widget)
     }
 }
 
+static void
+param_searchpath_replace (GtkWidget   *dialog,
+                          const gchar *file,
+                          gpointer     user_data)
+{
+  GtkWidget *widget = user_data;
+  gtk_entry_set_text (GTK_ENTRY (widget), file);
+  param_searchpath_change_value (widget);
+}
+
+static void
+param_searchpath_popup_replace (GtkWidget *widget)
+{
+  gtk_widget_grab_focus (widget);
+  if (gtk_editable_get_editable (GTK_EDITABLE (widget)))
+    {
+      GtkWidget *dialog = bst_file_dialog_popup_select_file (widget);
+      bst_file_dialog_set_handler (BST_FILE_DIALOG (dialog), param_searchpath_replace, widget, NULL);
+    }
+}
+
 static GtkWidget*
 param_searchpath_create (GxkParam    *param,
                          const gchar *tooltip,
@@ -92,16 +115,30 @@ param_searchpath_create (GxkParam    *param,
 {
   GtkWidget *widget = gxk_param_create_editor (param, "entry");
   GtkWidget *box = gtk_hbox_new (FALSE, 0);
-  GtkWidget *br = bst_stock_icon_button (BST_STOCK_REMOVE);
-  GtkWidget *ba = bst_stock_icon_button (BST_STOCK_ADD);
   g_object_set_data (widget, "beast-GxkParam", param);
   gtk_box_pack_start (GTK_BOX (box), widget, TRUE, TRUE, 0);
-  gtk_box_pack_end (GTK_BOX (box), br, FALSE, TRUE, 0);
-  gtk_box_pack_end (GTK_BOX (box), ba, FALSE, TRUE, 0);
-  g_object_connect (br, "swapped_signal::clicked", param_searchpath_popup_remove, widget, NULL);
-  g_object_connect (ba, "swapped_signal::clicked", param_searchpath_popup_add, widget, NULL);
-  gtk_tooltips_set_tip (GXK_TOOLTIPS, br, tooltip, NULL);
-  gtk_tooltips_set_tip (GXK_TOOLTIPS, ba, tooltip, NULL);
+  if (g_param_spec_check_option (param->pspec, "searchpath"))
+    {
+      GtkWidget *br = bst_stock_icon_button (BST_STOCK_REMOVE);
+      GtkWidget *ba = bst_stock_icon_button (BST_STOCK_ADD);
+      gtk_box_pack_end (GTK_BOX (box), br, FALSE, TRUE, 0);
+      gtk_box_pack_end (GTK_BOX (box), ba, FALSE, TRUE, 0);
+      g_object_connect (br, "swapped_signal::clicked", param_searchpath_popup_remove, widget, NULL);
+      g_object_connect (ba, "swapped_signal::clicked", param_searchpath_popup_add, widget, NULL);
+      gtk_tooltips_set_tip (GXK_TOOLTIPS, br, tooltip, NULL);
+      gtk_tooltips_set_tip (GXK_TOOLTIPS, ba, tooltip, NULL);
+    }
+  else if (g_param_spec_check_option (param->pspec, "filename"))
+    {
+      GtkWidget *bi;
+      if (g_param_spec_check_option (param->pspec, "image"))
+        bi = bst_stock_icon_button (BST_STOCK_BROWSE_IMAGE);
+      else
+        bi = bst_stock_icon_button (BST_STOCK_OPEN);
+      gtk_box_pack_end (GTK_BOX (box), bi, FALSE, TRUE, 0);
+      gtk_tooltips_set_tip (GXK_TOOLTIPS, bi, tooltip, NULL);
+      g_object_connect (bi, "swapped_signal::clicked", param_searchpath_popup_replace, widget, NULL);
+    }
   gtk_widget_show_all (box);
   gxk_widget_add_option (box, "hexpand", "+");
   return box;
@@ -113,3 +150,9 @@ static GxkParamEditor param_searchpath = {
   { "searchpath",       +5,     TRUE, },        /* options, rating, editing */
   param_searchpath_create,  NULL,
 };
+static GxkParamEditor param_filename = {
+  { "filename",         N_("Filename Text Entry"), },
+  { G_TYPE_STRING, },
+  { "filename",         +5,     TRUE, },        /* options, rating, editing */
+  param_searchpath_create,  NULL,
+};
