@@ -19,6 +19,7 @@
 #include "bstprocedure.h"
 #include "bstmenus.h"
 #include "bstparam.h"
+#include "bstgrowbar.h"
 
 #define SCROLLBAR_SPACING (3) /* from gtkscrolledwindow.c:DEFAULT_SCROLLBAR_SPACING */
 
@@ -43,7 +44,6 @@ static gboolean part_dialog_action_check        (gpointer                data,
                                                  gulong                  action);
 static void     part_dialog_run_script_proc     (gpointer                data,
                                                  gulong                  category_id);
-static GtkAdjustment* resizer_adjustment_create (GtkAdjustment          *client);
 
 
 /* --- track actions --- */
@@ -124,7 +124,7 @@ bst_part_dialog_init (BstPartDialog *self)
   GtkObject *adjustment;
   GtkAdjustment *adj;
   GParamSpec *pspec;
-  GxkGadget *gadget;
+  GxkRadget *radget;
 
   /* configure self */
   g_object_set (self,
@@ -134,9 +134,9 @@ bst_part_dialog_init (BstPartDialog *self)
 		"flags", GXK_DIALOG_STATUS_SHELL,
 		NULL);
 
-  /* gadget-complete GUI */
-  gadget = gxk_gadget_create ("beast", "piano-roll-box", NULL);
-  gtk_container_add (GTK_CONTAINER (GXK_DIALOG (self)->vbox), gadget);
+  /* radget-complete GUI */
+  radget = gxk_radget_create ("beast", "piano-roll-box", NULL);
+  gtk_container_add (GTK_CONTAINER (GXK_DIALOG (self)->vbox), radget);
 
   /* publish actions */
   gxk_widget_publish_actions (self, "piano-edit-actions",
@@ -156,7 +156,7 @@ bst_part_dialog_init (BstPartDialog *self)
   gxk_widget_publish_action_list (self, "part-scripts", al1);
 
   /* FIXME: use paned child-properties after gtk+-2.4 */
-  paned = gxk_gadget_find (gadget, "piano-paned");
+  paned = gxk_radget_find (radget, "piano-paned");
   child = g_object_ref (paned->child1);
   gtk_container_remove (GTK_CONTAINER (paned), child);
   gtk_paned_pack1 (paned, child, TRUE, TRUE);
@@ -166,63 +166,61 @@ bst_part_dialog_init (BstPartDialog *self)
   gtk_paned_pack2 (paned, child, FALSE, TRUE);
   g_object_unref (child);
 
+  BstGrowBar *grow_bar = gxk_radget_find (radget, "piano-roll-hgrow-bar");
+
   /* piano roll */
-  self->proll = gxk_gadget_find (gadget, "piano-roll");
+  self->proll = gxk_radget_find (radget, "piano-roll");
   gxk_nullify_in_object (self, &self->proll);
   g_signal_connect (self->proll, "canvas-clicked", G_CALLBACK (piano_canvas_clicked), self);
-  srange = gxk_gadget_find (gadget, "piano-roll-vscrollbar");
+  srange = gxk_radget_find (radget, "piano-roll-vscrollbar");
   gxk_scroll_canvas_set_vadjustment (GXK_SCROLL_CANVAS (self->proll), gtk_range_get_adjustment (srange));
-  srange = gxk_gadget_find (gadget, "piano-roll-hscrollbar");
-  adj = gtk_range_get_adjustment (srange);
+  adj = bst_grow_bar_get_adjustment (grow_bar);
   gxk_scroll_canvas_set_hadjustment (GXK_SCROLL_CANVAS (self->proll), adj);
-  adj = resizer_adjustment_create (adj);
-  srange = gxk_gadget_find (gadget, "piano-roll-hscale");
-  gtk_range_set_adjustment (srange, adj);
-  // g_object_unref (adj);
   self->pictrl = bst_piano_roll_controller_new (self->proll);
   gxk_widget_publish_action_list (self, "pctrl-canvas-tools", bst_piano_roll_controller_canvas_actions (self->pictrl));
   gxk_widget_publish_action_list (self, "pctrl-note-tools", bst_piano_roll_controller_note_actions (self->pictrl));
   gxk_widget_publish_action_list (self, "pctrl-quant-tools", bst_piano_roll_controller_quant_actions (self->pictrl));
 
   /* event roll */
-  self->eroll = gxk_gadget_find (gadget, "event-roll");
+  self->eroll = gxk_radget_find (radget, "event-roll");
   gxk_nullify_in_object (self, &self->eroll);
   g_signal_connect (self->eroll, "canvas-clicked", G_CALLBACK (event_canvas_clicked), self);
   self->ectrl = bst_event_roll_controller_new (self->eroll, self->pictrl->quant_rtools, self->pictrl->canvas_rtools);
-  srange = gxk_gadget_find (gadget, "piano-roll-hscrollbar");
-  gxk_scroll_canvas_set_hadjustment (GXK_SCROLL_CANVAS (self->eroll), gtk_range_get_adjustment (srange));
+  adj = bst_grow_bar_get_adjustment (grow_bar);
+  gxk_scroll_canvas_set_hadjustment (GXK_SCROLL_CANVAS (self->eroll), adj);
   bst_event_roll_set_vpanel_width_hook (self->eroll, (gpointer) bst_piano_roll_get_vpanel_width, self->proll);
 
+  grow_bar = gxk_radget_find (radget, "pattern-view-vgrow-bar");
+
   /* pattern view */
-  self->pview = gxk_gadget_find (gadget, "pattern-view");
+  self->pview = gxk_radget_find (radget, "pattern-view");
   gxk_nullify_in_object (self, &self->pview);
-  srange = gxk_gadget_find (gadget, "pattern-view-hscrollbar");
+  srange = gxk_radget_find (radget, "pattern-view-hscrollbar");
   gxk_scroll_canvas_set_hadjustment (GXK_SCROLL_CANVAS (self->pview), gtk_range_get_adjustment (srange));
-  srange = gxk_gadget_find (gadget, "pattern-view-vscrollbar");
-  adj = gtk_range_get_adjustment (srange);
+  adj = bst_grow_bar_get_adjustment (grow_bar);
   gxk_scroll_canvas_set_vadjustment (GXK_SCROLL_CANVAS (self->pview), adj);
-  adj = resizer_adjustment_create (adj);
-  srange = gxk_gadget_find (gadget, "pattern-view-vscale");
-  gtk_range_set_adjustment (srange, adj);
   self->pvctrl = bst_pattern_controller_new (self->pview, self->pictrl->quant_rtools);
 
   /* pattern view controls */
-  g_signal_connect_swapped (gxk_gadget_find (gadget, "configure-button"), "clicked",
+  g_signal_connect_swapped (gxk_radget_find (radget, "configure-button"), "clicked",
                             G_CALLBACK (bst_pattern_column_layouter_popup), self->pview);
-  box = gxk_gadget_find (gadget, "pattern-control-box");
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->vraster, "name"));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->vraster, "combo-button"));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_vseparator_space_new (TRUE));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->steps, "name"));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->steps, NULL));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_vseparator_space_new (FALSE));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->step_dir, "name"));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->step_dir, "combo-button"));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_vseparator_space_new (FALSE));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->hwrap, NULL));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_vseparator_space_new (TRUE));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->base_octave, "name"));
-  gxk_gadget_add (gadget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->base_octave, NULL));
+  box = gxk_radget_find (radget, "pattern-control-box");
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->vraster, "name"));
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->vraster, "combo-button"));
+  gxk_radget_add (radget, "pattern-control-box", gxk_vseparator_space_new (TRUE));
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->steps, "name"));
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->steps, NULL));
+  gxk_radget_add (radget, "pattern-control-box", gxk_vseparator_space_new (FALSE));
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->step_dir, "name"));
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->step_dir, "combo-button"));
+  gxk_radget_add (radget, "pattern-control-box", gxk_vseparator_space_new (FALSE));
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->hwrap, NULL));
+  gxk_radget_add (radget, "pattern-control-box", gxk_vseparator_space_new (TRUE));
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->base_octave, "name"));
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->base_octave, NULL));
+  gxk_radget_add (radget, "pattern-control-box", gxk_vseparator_space_new (TRUE));
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->row_shading, "name"));
+  gxk_radget_add (radget, "pattern-control-box", gxk_param_create_editor (self->pvctrl->row_shading, "combo-button"));
 
   /* event roll children */
   g_object_new (GTK_TYPE_LABEL, "visible", TRUE, "label", "C", "parent", self->eroll, NULL);
@@ -234,8 +232,8 @@ bst_part_dialog_init (BstPartDialog *self)
     {
       GxkParam *param = gxk_param_new_value (pspec, eparam_changed, self);
       GtkWidget *rwidget = gxk_param_create_editor (param, "choice-button");
-      gxk_gadget_add (gadget, "event-roll-control-area", rwidget);
-      g_object_connect (gadget, "swapped_signal::destroy", gxk_param_destroy, param, NULL);
+      gxk_radget_add (radget, "event-roll-control-area", rwidget);
+      g_object_connect (radget, "swapped_signal::destroy", gxk_param_destroy, param, NULL);
       g_param_spec_unref (pspec);
       sfi_value_set_choice (&param->value, bse_midi_signal_type_to_choice (BSE_MIDI_SIGNAL_VELOCITY));
       gxk_param_apply_value (param); /* update model, auto updates GUI */
@@ -246,9 +244,11 @@ bst_part_dialog_init (BstPartDialog *self)
   g_object_connect (adjustment,
 		    "swapped_signal_after::value_changed", hzoom_changed, self,
 		    NULL);
-  srange = gxk_gadget_find (gadget, "piano-roll-hzoom-scale");
+#if 0
+  srange = gxk_radget_find (radget, "piano-roll-hzoom-scale");
   gtk_range_set_adjustment (srange, GTK_ADJUSTMENT (adjustment));
-  gxk_gadget_add (self, "hzoom-area",
+#endif
+  gxk_radget_add (self, "hzoom-area",
                   g_object_new (GTK_TYPE_SPIN_BUTTON,
                                 "visible", TRUE,
                                 "adjustment", adjustment,
@@ -260,7 +260,7 @@ bst_part_dialog_init (BstPartDialog *self)
   g_object_connect (adjustment,
 		    "swapped_signal_after::value_changed", vzoom_changed, self,
 		    NULL);
-  gxk_gadget_add (self, "vzoom-area",
+  gxk_radget_add (self, "vzoom-area",
                   g_object_new (GTK_TYPE_SPIN_BUTTON,
                                 "visible", TRUE,
                                 "adjustment", adjustment,
@@ -329,7 +329,7 @@ piano_canvas_clicked (BstPianoRoll           *proll,
                       BstPartDialog          *self)
 {
   if (button == 3 && event)
-    gxk_menu_popup (gxk_gadget_find (self, "piano-popup"),
+    gxk_menu_popup (gxk_radget_find (self, "piano-popup"),
                     event->button.x_root, event->button.y_root, FALSE,
                     event->button.button, event->button.time);
 }
@@ -343,7 +343,7 @@ event_canvas_clicked (BstEventRoll           *eroll,
                       BstPartDialog          *self)
 {
   if (button == 3 && event)
-    gxk_menu_popup (gxk_gadget_find (self, "event-popup"),
+    gxk_menu_popup (gxk_radget_find (self, "event-popup"),
                     event->button.x_root, event->button.y_root, FALSE,
                     event->button.button, event->button.time);
 }
@@ -362,56 +362,6 @@ part_dialog_run_script_proc (gpointer                data,
                            NULL);
 }
 
-static void
-resizer_adjustment_client_changed (GtkAdjustment *adj)
-{
-  GtkAdjustment *client = g_object_get_data (adj, "client");
-  gdouble f, u = client->upper;
-  gdouble l = client->lower;
-  gdouble v = client->value + client->page_size;
-  f = (v - l) / (u - l);
-  f = 1.0 - f;
-  if (f != adj->value)
-    {
-      g_object_steal_data (adj, "client");
-      gtk_adjustment_set_value (adj, f);
-      g_object_set_data_full (adj, "client", g_object_ref (client), g_object_unref);
-    }
-}
-
-static void
-resizer_adjustment_value_changed (GtkAdjustment *adj)
-{
-  GtkAdjustment *client = g_object_get_data (adj, "client");
-  if (!client)
-    return;
-  gdouble f, u;
-  gdouble v = client->value + client->page_size;
-  /* calculate new client upper based on client->lower,
-   * client->value (>=50%) and adj->value, which indicates
-   * client->value position within 100%..50%
-   */
-  f = 1.0 - adj->value;
-  u = v / f;
-  if (u != client->upper)
-    {
-      client->upper = u;
-      gtk_adjustment_changed (client);
-    }
-}
-
-static GtkAdjustment*
-resizer_adjustment_create (GtkAdjustment *client)
-{
-  GtkAdjustment *adj = (GtkAdjustment*) gtk_adjustment_new (0, 0, 1 - 0.1, 0.0001, 0.1, 0);
-  g_object_set_data_full (adj, "client", g_object_ref (client), g_object_unref);
-  resizer_adjustment_client_changed (adj);
-  g_signal_connect_object (client, "changed", G_CALLBACK (resizer_adjustment_client_changed), adj, G_CONNECT_SWAPPED);
-  g_signal_connect_object (client, "value-changed", G_CALLBACK (resizer_adjustment_client_changed), adj, G_CONNECT_SWAPPED);
-  g_signal_connect (adj, "value-changed", G_CALLBACK (resizer_adjustment_value_changed), NULL);
-  return adj;
-}
-
 static void
 part_dialog_action_exec (gpointer data,
                          gulong   action)
