@@ -1,5 +1,5 @@
 /* BEAST - Bedevilled Audio System
- * Copyright (C) 1999-2002 Tim Janik and Red Hat, Inc.
+ * Copyright (C) 1999-2004 Tim Janik
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -37,21 +37,23 @@ typedef	struct	_BstPreferences      BstPreferences;
 typedef	struct	_BstPreferencesClass BstPreferencesClass;
 struct _BstPreferences
 {
-  GtkVBox	 parent_object;
+  GtkVBox	        parent_object;
 
-  GtkNotebook	*notebook;
+  GtkNotebook	       *notebook;
+  GtkWidget	       *apply;
 
-  SfiRec	*bstrec;
-  SfiRing	*bstparams;
+  SfiRec	       *rec_gconfig;
+  SfiRing	       *params_gconfig;
 
-  SfiRec        *skinrec;
-  SfiRing       *skinparams;
+  GtkWidget            *box_piano_keys;
+  GtkWidget            *box_generic_keys;
 
-  GParamSpec    *bsepspec;
-  SfiRec	*bserec;
-  SfiRing	*bseparams;
+  SfiRec               *rec_skin;
+  SfiRing              *params_skin;
 
-  GtkWidget	*apply;
+  GParamSpec           *bsepspec;
+  SfiRec	       *bserec;
+  SfiRing	       *bseparams;
 };
 struct _BstPreferencesClass
 {
@@ -62,6 +64,7 @@ struct _BstPreferencesClass
 /* --- prototypes --- */
 GtkType		 bst_preferences_get_type	(void);
 void		 bst_preferences_apply		(BstPreferences *prefs);
+void		 bst_preferences_load_rc_files	(void);
 void		 bst_preferences_save		(BstPreferences *prefs);
 void		 bst_preferences_revert		(BstPreferences *prefs);
 void		 bst_preferences_default_revert	(BstPreferences *prefs);
