@@ -100,21 +100,21 @@ bst_splash_init (BstSplash *self)
 			     "spacing", 0,
 			     "parent", window,
 			     NULL);
-  gxk_nullify_on_destroy (self->vbox, &self->vbox);
+  gxk_nullify_in_object (self, &self->vbox);
   
   /* splash vbox */
   self->splash_box = g_object_new (GTK_TYPE_VBOX,
 				   "visible", TRUE,
 				   "spacing", 0,
 				   NULL);
-  gxk_nullify_on_destroy (self->splash_box, &self->splash_box);
+  gxk_nullify_in_object (self, &self->splash_box);
   gtk_box_pack_start (GTK_BOX (self->vbox), self->splash_box, TRUE, TRUE, 0);
 
   /* progress bar */
   self->pbar = g_object_new (GTK_TYPE_PROGRESS_BAR,
 			     "visible", TRUE,
 			     NULL);
-  gxk_nullify_on_destroy (self->pbar, &self->pbar);
+  gxk_nullify_in_object (self, &self->pbar);
   gtk_box_pack_end (GTK_BOX (self->vbox), GTK_WIDGET (self->pbar), FALSE, TRUE, 0);
   gtk_progress_set_show_text (GTK_PROGRESS (self->pbar), FALSE);
 
@@ -130,7 +130,7 @@ bst_splash_init (BstSplash *self)
 			     "width_request", 1,
 			     "parent", any,
 			     NULL);
-  gxk_nullify_on_destroy (self->item, &self->item);
+  gxk_nullify_in_object (self, &self->item);
 
   /* entity label */
   any = g_object_new (GTK_TYPE_ALIGNMENT,
@@ -144,7 +144,7 @@ bst_splash_init (BstSplash *self)
 			       "width_request", 1,
 			       "parent", any,
 			       NULL);
-  gxk_nullify_on_destroy (self->entity, &self->entity);
+  gxk_nullify_in_object (self, &self->entity);
 }
 
 static void
@@ -400,6 +400,22 @@ bst_splash_set_animation (GtkWidget          *widget,
     bst_splash_update ();
 }
 
+static const gchar*
+splash_select_string (BstSplash *self)
+{
+  guint nth = rand () % self->n_rand_strings;
+  gchar *string = self->strings[nth];
+  self->n_rand_strings -= 1;
+  if (self->n_rand_strings < 1)
+    self->n_rand_strings = self->n_strings;
+  else
+    {
+      self->strings[nth] = self->strings[self->n_rand_strings];
+      self->strings[self->n_rand_strings] = string;
+    }
+  return string;
+}
+
 static gboolean
 about_timer (gpointer data)
 {
@@ -409,7 +425,7 @@ about_timer (gpointer data)
   self->aprogress += delta;
   if (self->aprogress >= 2)
     {
-      gtk_progress_bar_set_text (self->pbar, self->strings[rand () % self->n_strings]);
+      gtk_progress_bar_set_text (self->pbar, splash_select_string (self));
       self->aprogress = 0;
     }
   gtk_progress_bar_set_orientation (self->pbar, self->aprogress < 1 ? GTK_PROGRESS_LEFT_TO_RIGHT : GTK_PROGRESS_RIGHT_TO_LEFT);
@@ -428,10 +444,11 @@ bst_splash_animate_strings (GtkWidget      *splash,
   self->n_strings = 0;
   while (self->strings[self->n_strings])
     self->n_strings++;
+  self->n_rand_strings = self->n_strings;
   if (!self->timer_id)
     self->timer_id = g_timeout_add (40, about_timer, self);
   self->aprogress = 0;
   gtk_progress_bar_set_orientation (self->pbar, GTK_PROGRESS_LEFT_TO_RIGHT);
   gtk_progress_bar_set_fraction (self->pbar, self->aprogress);
-  gtk_progress_bar_set_text (self->pbar, self->strings[rand () % self->n_strings]);
+  gtk_progress_bar_set_text (self->pbar, splash_select_string (self));
 }
