@@ -36,9 +36,12 @@ enum {
   BST_FILE_STORE_COL_LOADABLE,
   BST_FILE_STORE_N_COLS
 };
-GtkTreeModel*   bst_file_store_get_sample_list          (void);
-void            bst_file_store_use_sample_list          (void);
-void            bst_file_store_unuse_sample_list        (void);
+GtkTreeModel*   bst_file_store_create           (void);
+void            bst_file_store_update_list      (GtkTreeModel *model,
+                                                 const gchar  *search_path,
+                                                 const gchar  *filter);
+void            bst_file_store_forget_list      (GtkTreeModel *model);
+void            bst_file_store_destroy          (GtkTreeModel *model);
 
 
 /* --- proxy stores --- */
@@ -49,15 +52,15 @@ enum {
   BST_PROXY_STORE_TYPE,
   BST_PROXY_STORE_N_COLS
 };
-/* store based on a BseProxySeq */
-GtkTreeModel*   bst_proxy_seq_store_new                 (void);
-void            bst_proxy_seq_store_set                 (GtkTreeModel   *self,
-                                                         BseProxySeq    *pseq);
-SfiProxy        bst_proxy_seq_store_get_proxy           (GtkTreeModel   *self,
+/* store based on a BseItemSeq */
+GtkTreeModel*   bst_item_seq_store_new                  (void);
+void            bst_item_seq_store_set                  (GtkTreeModel   *self,
+                                                         BseItemSeq     *iseq);
+SfiProxy        bst_item_seq_store_get_proxy            (GtkTreeModel   *self,
                                                          gint            row);
-SfiProxy        bst_proxy_seq_store_get_from_iter       (GtkTreeModel   *self,
+SfiProxy        bst_item_seq_store_get_from_iter        (GtkTreeModel   *self,
                                                          GtkTreeIter    *iter);
-gboolean        bst_proxy_seq_store_get_iter            (GtkTreeModel   *self,
+gboolean        bst_item_seq_store_get_iter             (GtkTreeModel   *self,
                                                          GtkTreeIter    *iter,
                                                          SfiProxy        proxy);
 /* store based on the child list of a container */
