@@ -22,9 +22,11 @@
 #include "bsttrackview.h"
 #include "bstwaveview.h"
 #include "bstpartview.h"
+#include "bstsongbusview.h"
 #include "bstpianoroll.h"
 #include "bstpatternview.h"
 #include "bsteventroll.h"
+#include "bstgrowbar.h"
 #include <fcntl.h>
 #include <errno.h>
 #include <unistd.h>
@@ -104,21 +106,24 @@ _bst_init_utils (void)
 
 #include "beast-gtk/dialogs/beast-xml-zfiles.c"
 void
-_bst_init_gadgets (void)
+_bst_init_radgets (void)
 {
   gchar *text;
-  gxk_gadget_define_widget_type (BST_TYPE_TRACK_VIEW);
-  gxk_gadget_define_widget_type (BST_TYPE_WAVE_VIEW);
-  gxk_gadget_define_widget_type (BST_TYPE_PART_VIEW);
-  gxk_gadget_define_widget_type (BST_TYPE_PIANO_ROLL);
-  gxk_gadget_define_widget_type (BST_TYPE_EVENT_ROLL);
-  gxk_gadget_define_widget_type (BST_TYPE_PATTERN_VIEW);
-  gxk_gadget_define_widget_type (BST_TYPE_ZOOMED_WINDOW);
-  text = gxk_zfile_uncompress (BST_GADGETS_STANDARD_SIZE, BST_GADGETS_STANDARD_DATA, G_N_ELEMENTS (BST_GADGETS_STANDARD_DATA));
-  gxk_gadget_parse_text ("beast", text, -1, NULL, NULL);
+  gxk_radget_define_widget_type (BST_TYPE_TRACK_VIEW);
+  gxk_radget_define_widget_type (BST_TYPE_HGROW_BAR);
+  gxk_radget_define_widget_type (BST_TYPE_VGROW_BAR);
+  gxk_radget_define_widget_type (BST_TYPE_WAVE_VIEW);
+  gxk_radget_define_widget_type (BST_TYPE_PART_VIEW);
+  gxk_radget_define_widget_type (BST_TYPE_SONG_BUS_VIEW);
+  gxk_radget_define_widget_type (BST_TYPE_PIANO_ROLL);
+  gxk_radget_define_widget_type (BST_TYPE_EVENT_ROLL);
+  gxk_radget_define_widget_type (BST_TYPE_PATTERN_VIEW);
+  gxk_radget_define_widget_type (BST_TYPE_ZOOMED_WINDOW);
+  text = gxk_zfile_uncompress (BST_RADGETS_STANDARD_SIZE, BST_RADGETS_STANDARD_DATA, G_N_ELEMENTS (BST_RADGETS_STANDARD_DATA));
+  gxk_radget_parse_text ("beast", text, -1, NULL, NULL);
   g_free (text);
-  text = gxk_zfile_uncompress (BST_GADGETS_BEAST_SIZE, BST_GADGETS_BEAST_DATA, G_N_ELEMENTS (BST_GADGETS_BEAST_DATA));
-  gxk_gadget_parse_text ("beast", text, -1, NULL, NULL);
+  text = gxk_zfile_uncompress (BST_RADGETS_BEAST_SIZE, BST_RADGETS_BEAST_DATA, G_N_ELEMENTS (BST_RADGETS_BEAST_DATA));
+  gxk_radget_parse_text ("beast", text, -1, NULL, NULL);
   g_free (text);
 }
 
@@ -424,7 +429,8 @@ bst_action_list_add_cat (GxkActionList          *alist,
       p = d ? d + 1 : p;
     }
 
-  gxk_action_list_add_translated (alist, NULL, p, NULL, gxk_factory_path_get_leaf (cat->category),
+  gxk_action_list_add_translated (alist, NULL, p, NULL,
+                                  gxk_factory_path_get_leaf (cat->category),
                                   cat->category_id, stock_id,
                                   acheck, aexec, user_data);
 }
@@ -1241,9 +1247,9 @@ bst_file_scan_find_key (const gchar *file,
 #ifndef BST_DEBUG_KEYS
 #  define BST_DEBUG_KEYS        /* none */
 #endif
-static const gchar *debug_keys[] = { BST_LOG_SCAN_KEYS NULL };
+static const gchar *debug_keys[] = { BST_LOG_DEBUG_KEYS NULL };
 const gchar**
-_bst_log_scan_keys (void)
+_bst_log_debug_keys (void)
 {
   return debug_keys;
 }
