@@ -213,8 +213,8 @@ BstGConfig*     bst_gconfig_get_global (void);
 
 /* --- internal --- */
 void            _bst_init_utils         (void);
-void            _bst_init_gadgets       (void);
-const gchar**   _bst_log_scan_keys      (void);
+void            _bst_init_radgets       (void);
+const gchar**   _bst_log_debug_keys     (void);
 
 G_END_DECLS
 
