@@ -16,16 +16,16 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include	"bstxkb.h"
+#include "bstxkb.h"
 
-#include	"../PKG_config.h"
-#include	<string.h>
+#include "topconfig.h"
+#include <string.h>
 
 #ifdef	BST_WITH_XKB
 
-#include	<X11/Xlib.h>
-#include	<X11/XKBlib.h>
-#include	<X11/extensions/XKBgeom.h>
+#include <X11/Xlib.h>
+#include <X11/XKBlib.h>
+#include <X11/extensions/XKBgeom.h>
 
 
 /* --- variables --- */
