@@ -25,7 +25,7 @@ enum {
   MENU_ITEM_PROP_0,
   MENU_ITEM_PROP_ULINE_LABEL,
   MENU_ITEM_PROP_STOCK_IMAGE,
-  MENU_ITEM_PROP_MENUBAR_IMAGE,
+  MENU_ITEM_PROP_KEEP_MENUBAR_IMAGE,
   MENU_ITEM_PROP_ACCEL_PATH,
   MENU_ITEM_PROP_ACCEL,
   MENU_ITEM_PROP_TITLE_STYLE,
@@ -41,18 +41,14 @@ static void     gxk_menu_item_get_property         (GObject             *object,
                                                     guint                param_id,
                                                     GValue              *value,
                                                     GParamSpec          *pspec);
-
 static void
-menu_item_show_image (GtkImageMenuItem *imitem)
+menu_item_keep_menubar_image (GtkImageMenuItem *imitem)
 {
-  if (imitem->image)
-    {
-      if (GTK_IS_MENU_BAR (GTK_WIDGET (imitem)->parent))
-        gtk_widget_hide (imitem->image);
-      else
-        gtk_widget_show (imitem->image);
-    }
+  if (imitem->image && GTK_IS_MENU_BAR (GTK_WIDGET (imitem)->parent) &&
+      !g_object_get_long (imitem, "gxk-keep-menubar-image"))
+    gtk_image_menu_item_set_image (imitem, NULL);
 }
+
 static void
 gxk_menu_item_set_property (GObject      *object,
                             guint         param_id,
@@ -66,7 +62,7 @@ gxk_menu_item_set_property (GObject      *object,
     {
       const gchar *string, *path;
       gchar *accel;
-      gboolean vbool, pending;
+      gboolean vbool;
     case MENU_ITEM_PROP_ULINE_LABEL:
       if (bin->child)
         gtk_container_remove (GTK_CONTAINER (self), bin->child);
@@ -97,13 +93,10 @@ gxk_menu_item_set_property (GObject      *object,
             }
         }
       break;
-    case MENU_ITEM_PROP_MENUBAR_IMAGE:
+    case MENU_ITEM_PROP_KEEP_MENUBAR_IMAGE:
       vbool = g_value_get_boolean (value);
-      pending = gxk_signal_handler_pending (self, "parent-set", G_CALLBACK (menu_item_show_image), NULL);
-      if (vbool && pending)
-        g_signal_handlers_disconnect_by_func (self, menu_item_show_image, NULL);
-      else if (!vbool && !pending)
-        g_signal_connect (self, "parent-set", G_CALLBACK (menu_item_show_image), NULL);
+      g_object_set_long (self, "gxk-keep-menubar-image", vbool);
+      menu_item_keep_menubar_image (self);
       break;
     case MENU_ITEM_PROP_RIGHT_JUSTIFY:
       gtk_menu_item_set_right_justified (mitem, g_value_get_boolean (value));
@@ -158,6 +151,13 @@ gxk_menu_item_get_property (GObject    *object,
     }
 }
 
+static void
+gxk_menu_item_init (GxkMenuItem *self)
+{
+  g_signal_connect (self, "parent-set", G_CALLBACK (menu_item_keep_menubar_image), NULL);
+  g_signal_connect (self, "check-resize", G_CALLBACK (menu_item_keep_menubar_image), NULL);         
+}
+
 static void
 gxk_menu_item_class_init (GxkMenuItemClass *class)
 {
@@ -168,8 +168,8 @@ gxk_menu_item_class_init (GxkMenuItemClass *class)
                                    g_param_spec_string ("uline-label", NULL, NULL, NULL, G_PARAM_WRITABLE));
   g_object_class_install_property (gobject_class, MENU_ITEM_PROP_STOCK_IMAGE,
                                    g_param_spec_string ("stock-image", NULL, NULL, NULL, G_PARAM_WRITABLE));
-  g_object_class_install_property (gobject_class, MENU_ITEM_PROP_MENUBAR_IMAGE,
-                                   g_param_spec_boolean ("menubar-image", NULL, NULL, TRUE, G_PARAM_WRITABLE));
+  g_object_class_install_property (gobject_class, MENU_ITEM_PROP_KEEP_MENUBAR_IMAGE,
+                                   g_param_spec_boolean ("keep-menubar-image", NULL, NULL, FALSE, G_PARAM_WRITABLE));
   g_object_class_install_property (gobject_class, MENU_ITEM_PROP_ACCEL,
                                    g_param_spec_string ("accel", NULL, NULL, NULL, G_PARAM_WRITABLE));
   g_object_class_install_property (gobject_class, MENU_ITEM_PROP_ACCEL_PATH,
@@ -195,7 +195,7 @@ gxk_menu_item_get_type (void)
         NULL,   /* class_data */
         sizeof (GxkMenuItem),
         0,      /* n_preallocs */
-        (GInstanceInitFunc) NULL,
+        (GInstanceInitFunc) gxk_menu_item_init,
       };
       type = g_type_register_static (GTK_TYPE_IMAGE_MENU_ITEM, "GxkMenuItem", &type_info, 0);
     }
@@ -494,11 +494,11 @@ widget_patcher_hint_resize_inc (GtkWidget *widget)
     }
 }
 static gboolean
-widget_patcher_adopt (GxkGadget          *gadget,
-                      GxkGadget          *parent,
-                      GxkGadgetData      *gdgdata)
+widget_patcher_adopt (GxkRadget          *radget,
+                      GxkRadget          *parent,
+                      GxkRadgetData      *gdgdata)
 {
-  GxkWidgetPatcher *self = GXK_WIDGET_PATCHER (gadget);
+  GxkWidgetPatcher *self = GXK_WIDGET_PATCHER (radget);
   if (self->tooltip)
     {
       gxk_widget_set_latent_tooltip (parent, self->tooltip);
@@ -555,30 +555,30 @@ gxk_widget_patcher_get_type (void)
   return type;
 }
 
-static GxkGadget*
+static GxkRadget*
 widget_patcher_create (GType               type,
                        const gchar        *name,
-                       GxkGadgetData      *gdgdata)
+                       GxkRadgetData      *gdgdata)
 {
   return g_object_new (type, NULL);
 }
 
 static GParamSpec*
-widget_patcher_find_prop (GxkGadget    *gadget,
+widget_patcher_find_prop (GxkRadget    *radget,
                           const gchar  *prop_name)
 {
-  return g_object_class_find_property (G_OBJECT_GET_CLASS (gadget), prop_name);
+  return g_object_class_find_property (G_OBJECT_GET_CLASS (radget), prop_name);
 }
 
-static const GxkGadgetType widget_patcher_def = {
+static const GxkRadgetType widget_patcher_def = {
   widget_patcher_create,
   widget_patcher_find_prop,
-  (void(*)(GxkGadget*,const gchar*,const GValue*)) g_object_set_property,
+  (void(*)(GxkRadget*,const gchar*,const GValue*)) g_object_set_property,
   widget_patcher_adopt,
   NULL,         /* find_pack */
   NULL,         /* set_pack */
 };
-const GxkGadgetType *_gxk_widget_patcher_def = &widget_patcher_def;
+const GxkRadgetType *_gxk_widget_patcher_def = &widget_patcher_def;
 
 
 /* --- focus frame --- */
@@ -606,6 +606,7 @@ focus_frame_expose_event (GtkWidget      *widget,
 static void
 gxk_focus_frame_init (GxkFocusFrame *self)
 {
+  GTK_WIDGET_SET_FLAGS (self, GTK_VISIBLE);
   gtk_container_set_border_width (GTK_CONTAINER (self), 1);
 }
 
@@ -615,3 +616,167 @@ gxk_focus_frame_class_init (GxkFocusFrameClass *class)
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
   widget_class->expose_event = focus_frame_expose_event;
 }
+
+/* --- back shade --- */
+G_DEFINE_TYPE (GxkBackShade, gxk_back_shade, GTK_TYPE_ALIGNMENT);
+
+/* color converion code stolen from gtkstyle.c */
+static void
+rgb_to_hls (gdouble  red,
+            gdouble  green,
+            gdouble  blue,
+            gdouble *h_p,
+            gdouble *l_p,
+            gdouble *s_p)
+{
+  gdouble max = MAX (MAX (red, green), blue);
+  gdouble min = MIN (MIN (red, green), blue);
+  gdouble l = (max + min) / 2.;
+  gdouble h = 0, s = 0;
+  if (max != min)
+    {
+      gdouble delta = max - min;
+      s = delta / (l <= 0.5 ? max + min : 2 - max - min);
+      if (delta == 0.0)
+        delta = 1.0;
+      if (red == max)
+        h = (green - blue) / delta;
+      else if (green == max)
+        h = 2 + (blue - red) / delta;
+      else if (blue == max)
+        h = 4 + (red - green) / delta;
+      h *= 60;
+      if (h < 0.0)
+        h += 360;
+    }
+  *h_p = h;
+  *l_p = l;
+  *s_p = s;
+}
+
+static void
+hls_to_rgb (gdouble  hue,
+            gdouble  lightness,
+            gdouble  saturation,
+            gdouble *r_p,
+            gdouble *g_p,
+            gdouble *b_p)
+{
+  if (saturation == 0)
+    {
+      *r_p = lightness;
+      *g_p = lightness;
+      *b_p = lightness;
+    }
+  else
+    {
+      gdouble m2, chue;
+      if (lightness <= 0.5)
+        m2 = lightness * (1 + saturation);
+      else
+        m2 = lightness + saturation - lightness * saturation;
+      gdouble m1 = 2 * lightness - m2;
+
+      chue = hue + 120;
+      while (chue > 360)
+        chue -= 360;
+      while (chue < 0)
+        chue += 360;
+      if (chue < 60)
+        *r_p = m1 + (m2 - m1) * chue / 60;
+      else if (chue < 180)
+        *r_p = m2;
+      else if (chue < 240)
+        *r_p = m1 + (m2 - m1) * (240 - chue) / 60;
+      else
+        *r_p = m1;
+
+      chue = hue;
+      while (chue > 360)
+        chue -= 360;
+      while (chue < 0)
+        chue += 360;
+      if (chue < 60)
+        *g_p = m1 + (m2 - m1) * chue / 60;
+      else if (chue < 180)
+        *g_p = m2;
+      else if (chue < 240)
+        *g_p = m1 + (m2 - m1) * (240 - chue) / 60;
+      else
+        *g_p = m1;
+
+      chue = hue - 120;
+      while (chue > 360)
+        chue -= 360;
+      while (chue < 0)
+        chue += 360;
+      if (chue < 60)
+        *b_p = m1 + (m2 - m1) * chue / 60;
+      else if (chue < 180)
+        *b_p = m2;
+      else if (chue < 240)
+        *b_p = m1 + (m2 - m1) * (240 - chue) / 60;
+      else
+        *b_p = m1;
+    }
+}
+
+static void
+color_shade (GdkColor *color,
+             gdouble   k)
+{
+  gdouble r = color->red / 65536.;
+  gdouble g = color->green / 65536.;
+  gdouble b = color->blue / 65536.;
+  gdouble h, l, s;
+  rgb_to_hls (r, g, b, &h, &l, &s);
+  l = CLAMP (l * k, 0, 1);
+  s = CLAMP (s * k, 0, 1);
+  hls_to_rgb (h, l, s, &r, &g, &b);
+  color->red = r * 65535.;
+  color->green = g * 65535.;
+  color->blue = b * 65535.0;
+}
+
+static GdkGC*
+get_darkened_gc (GdkWindow *window,
+                 GdkColor  *srccolor,
+                 gint       darken_count)
+{
+  GdkColor color = *srccolor;
+  while (darken_count--)
+    color_shade (&color, 0.93);
+  GdkGC *gc = gdk_gc_new (window);
+  gdk_gc_set_rgb_fg_color (gc, &color);
+  return gc;
+}
+
+static gboolean
+back_shade_expose_event (GtkWidget      *widget,
+                         GdkEventExpose *event)
+{
+  GdkWindow *window = widget->window;
+  GtkStyle *style = widget->style;
+  GdkGC *gc = get_darkened_gc (window, &style->bg[GTK_STATE_NORMAL], 1);
+  GdkRectangle *area = &event->area;
+  gdk_gc_set_clip_rectangle (gc, area);
+  gdk_draw_rectangle (window, gc, TRUE, area->x, area->y, area->width, area->height);
+  gdk_gc_set_clip_rectangle (gc, NULL);
+  g_object_unref (gc);
+  /* chain to parent */
+  return GTK_WIDGET_CLASS (gxk_back_shade_parent_class)->expose_event (widget, event);
+}
+
+static void
+gxk_back_shade_init (GxkBackShade *self)
+{
+  GTK_WIDGET_SET_FLAGS (self, GTK_VISIBLE);
+}
+
+static void
+gxk_back_shade_class_init (GxkBackShadeClass *class)
+{
+  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
+  widget_class->expose_event = back_shade_expose_event;
+}
+
