@@ -41,6 +41,42 @@ static gulong viewable_changed_id = 0;
 
 
 /* --- functions --- */
+#if     GTK_CHECK_VERSION (2, 4, 0)
+static gboolean
+widget_ancestry_mapped (GtkWidget *widget)
+{
+  while (widget)
+    {
+      if (!GTK_WIDGET_MAPPED (widget))
+        return FALSE;
+      widget = widget->parent;
+    }
+  return TRUE;
+}
+
+#if 0
+static void
+widget_print_ancestry (GtkWidget *widget)
+{
+  g_print ("%s: drawable=%d window-viewable=%d ancestry-mapped=%d\n",
+           g_type_name (G_OBJECT_TYPE (widget)), GTK_WIDGET_DRAWABLE (widget),
+           gdk_window_is_viewable (widget->window),
+           widget_ancestry_mapped (widget));
+  if (widget->parent)
+    widget_print_ancestry (widget->parent);
+}
+#endif
+
+static gboolean
+gxk_widget_real_can_activate_accel (GtkWidget *widget, // GTKFIX: #145270, FIXME: remove this
+                                    guint      signal_id)
+{
+  // g_print ("%s: accelerator-check:\n",  g_type_name (G_OBJECT_TYPE (widget))), widget_print_ancestry(widget);
+  /* widgets must be onscreen for accels to take effect */
+  return GTK_WIDGET_IS_SENSITIVE (widget) && GTK_WIDGET_DRAWABLE (widget) && gdk_window_is_viewable (widget->window) && widget_ancestry_mapped (widget);
+}
+#endif
+
 void
 _gxk_init_utils (void)
 {
@@ -55,6 +91,10 @@ _gxk_init_utils (void)
 				       NULL, NULL,
 				       gtk_marshal_VOID__VOID,
 				       G_TYPE_NONE, 0, NULL);
+#if     GTK_CHECK_VERSION (2, 4, 0)
+  GtkWidgetClass *widget_class = gtk_type_class (GTK_TYPE_WIDGET);
+  widget_class->can_activate_accel = gxk_widget_real_can_activate_accel;
+#endif
 }
 
 /**
@@ -516,6 +556,8 @@ idle_shower (GtkWidget **widget_p)
       gtk_signal_disconnect_by_func (GTK_OBJECT (*widget_p),
 				     GTK_SIGNAL_FUNC (gtk_widget_destroyed),
 				     widget_p);
+      if (GTK_WIDGET_DRAWABLE (*widget_p) && GTK_IS_WINDOW (*widget_p))
+        gdk_window_raise ((*widget_p)->window);
       gtk_widget_show (*widget_p);
     }
   g_free (widget_p);
@@ -875,6 +917,23 @@ gxk_widget_force_bg_clear (GtkWidget *widget)
     g_signal_connect (widget, "expose_event", G_CALLBACK (expose_bg_clear), NULL);
 }
 
+/**
+ * gxk_widget_set_tooltip
+ * @widget:  a valid GtkWidget
+ * @tooltip: descriptive tooltip
+ *
+ * As a convenience function, this sets the @tooltip for @widget
+ * on %GXK_TOOLTIPS, if @widget is supposed to have tooltips
+ * according to the system configuration and also sets the latent tooltip.
+ */
+void
+gxk_widget_set_tooltip (GtkWidget   *widget,
+                        const gchar *tooltip)
+{
+  gxk_widget_set_latent_tooltip (widget, tooltip);
+  gtk_tooltips_set_tip (GXK_TOOLTIPS, widget, tooltip, NULL);
+}
+
 /**
  * gxk_widget_set_latent_tooltip
  * @widget:  a valid GtkWidget
@@ -2292,6 +2351,58 @@ gxk_widget_proxy_requisition (GtkWidget *widget)
   g_signal_connect_after (widget, "size_request", G_CALLBACK (requisition_to_aux_info), NULL);
 }
 
+static void
+request_hclient_height (GtkWidget      *widget,
+                        GtkRequisition *requisition,
+                        GtkWidget      *client)
+{
+  GtkRequisition client_requisition;
+  gtk_widget_size_request (client, &client_requisition);
+  requisition->height = client_requisition.width;
+}
+
+/**
+ * gxk_widget_request_hclient_height
+ * @widget: valid #GtkWidget
+ * @client: valid #GtkWidget
+ *
+ * Request the horizontal size of @client as height
+ * for @widget.
+ */
+void
+gxk_widget_request_hclient_height (GtkWidget       *widget,
+                                   GtkWidget       *client)
+{
+  g_signal_handlers_disconnect_by_func (widget, request_hclient_height, client);
+  g_signal_connect_after (widget, "size_request", G_CALLBACK (request_hclient_height), client);
+}
+
+static void
+request_vclient_width (GtkWidget      *widget,
+                       GtkRequisition *requisition,
+                       GtkWidget      *client)
+{
+  GtkRequisition client_requisition;
+  gtk_widget_size_request (client, &client_requisition);
+  requisition->width = client_requisition.height;
+}
+
+/**
+ * gxk_widget_request_vclient_width
+ * @widget: valid #GtkWidget
+ * @client: valid #GtkWidget
+ *
+ * Request the vertical size of @client as width
+ * for @widget.
+ */
+void
+gxk_widget_request_vclient_width (GtkWidget       *widget,
+                                  GtkWidget       *client)
+{
+  g_signal_handlers_disconnect_by_func (widget, request_vclient_width, client);
+  g_signal_connect_after (widget, "size_request", G_CALLBACK (request_vclient_width), client);
+}
+
 /**
  * gxk_widget_has_ancestor
  * @widget:   valid #GtkWidget
