@@ -41,6 +41,10 @@ GtkWidget*      gxk_item_factory_get_item          (GtkItemFactory  *ifactory,
 GtkWidget*      gxk_item_factory_get_widget        (GtkItemFactory  *ifactory,
                                                     const gchar     *path);
 void            gxk_widget_proxy_requisition       (GtkWidget       *widget);
+void            gxk_widget_request_hclient_height  (GtkWidget       *widget,
+                                                    GtkWidget       *client);
+void            gxk_widget_request_vclient_width   (GtkWidget       *widget,
+                                                    GtkWidget       *client);
 gboolean        gxk_widget_has_ancestor            (gpointer         widget,
                                                     gpointer         ancestor);
 void            gxk_widget_regulate                (GtkWidget       *widget,
@@ -182,6 +186,8 @@ void         gxk_widget_modify_as_title           (GtkWidget        *widget);
 void         gxk_widget_modify_bg_as_base         (GtkWidget        *widget);
 void         gxk_widget_modify_base_as_bg         (GtkWidget        *widget);
 void         gxk_widget_force_bg_clear            (GtkWidget        *widget);
+void         gxk_widget_set_tooltip               (GtkWidget        *widget,
+                                                   const gchar      *tooltip);
 void         gxk_widget_set_latent_tooltip        (GtkWidget        *widget,
                                                    const gchar      *tooltip);
 const gchar* gxk_widget_get_latent_tooltip        (GtkWidget        *widget);
