@@ -21,8 +21,8 @@
 #include <bse/gslengine.h>
 #include <bse/gslsignal.h>
 
+#define	DEBUG(...)      sfi_debug ("biquadfilter", __VA_ARGS__)
 #define FREQ_DELTA      0.1
-#define	INFO		sfi_info_keyfunc ("biquadfilter")
 
 /* --- parameters --- */
 enum
@@ -91,11 +91,6 @@ BSE_BUILTIN_TYPE (BseBiquadFilter)
     (GInstanceInitFunc) bse_biquad_filter_init,
   };
 #include "./icons/biquad.c"
-  static const BsePixdata pixdata = {
-    BIQUAD_IMAGE_BYTES_PER_PIXEL | BSE_PIXDATA_1BYTE_RLE,
-    BIQUAD_IMAGE_WIDTH, BIQUAD_IMAGE_HEIGHT,
-    BIQUAD_IMAGE_RLE_PIXEL_DATA,
-  };
   GType type;
   
   type = bse_type_register_static (BSE_TYPE_SOURCE,
@@ -107,8 +102,7 @@ BSE_BUILTIN_TYPE (BseBiquadFilter)
 				   "modulatable center (Cut-Off) frequency and "
 				   "gain input signals.",
 				   &type_info);
-  bse_categories_register_icon ("/Modules/Filters/Biquad Types",
-				type, &pixdata);
+  bse_categories_register_stock_module (N_("/Filters/Biquad Types"), type, biquad_pixstream);
   return type;
 }
 
@@ -369,19 +363,19 @@ bse_biquad_filter_update_modules (BseBiquadFilter *self)
 	  gsl_biquad_config_init (&c, self->filter_type, self->norm_type);
 	  gsl_biquad_config_setup (&c, self->freq / nyquist_freq, self->gain, 0);
 	  gsl_biquad_filter_config (&biquad, &c, TRUE);
-	  INFO ("Bxx(z) = (%.14g + (%.14g + %.14g * z) * z) / (1 + (%.14g + %.14g * z) * z)\n",
-		biquad.xc0, biquad.xc1, biquad.xc2, biquad.yc1, biquad.yc2);
+	  DEBUG ("Bxx(z) = (%.14g + (%.14g + %.14g * z) * z) / (1 + (%.14g + %.14g * z) * z)\n",
+                 biquad.xc0, biquad.xc1, biquad.xc2, biquad.yc1, biquad.yc2);
 	  
 	  gsl_biquad_config_approx_gain (&c, self->gain);
 	  gsl_biquad_filter_config (&approx, &c, TRUE);
-	  INFO ("Byy(z) = (%.14g + (%.14g + %.14g * z) * z) / (1 + (%.14g + %.14g * z) * z)\n",
-		approx.xc0, approx.xc1, approx.xc2, approx.yc1, approx.yc2);
-	  INFO ("Bdd(z) = (%.14g + (%.14g + %.14g * z) * z) / (1 + (%.14g + %.14g * z) * z)\n",
-		biquad.xc0 - approx.xc0,
-		biquad.xc1 - approx.xc1,
-		biquad.xc2 - approx.xc2,
-		biquad.yc1 - approx.yc1,
-		biquad.yc2 - approx.yc2);
+	  DEBUG ("Byy(z) = (%.14g + (%.14g + %.14g * z) * z) / (1 + (%.14g + %.14g * z) * z)\n",
+                 approx.xc0, approx.xc1, approx.xc2, approx.yc1, approx.yc2);
+	  DEBUG ("Bdd(z) = (%.14g + (%.14g + %.14g * z) * z) / (1 + (%.14g + %.14g * z) * z)\n",
+                 biquad.xc0 - approx.xc0,
+                 biquad.xc1 - approx.xc1,
+                 biquad.xc2 - approx.xc2,
+                 biquad.yc1 - approx.yc1,
+                 biquad.yc2 - approx.yc2);
 	}
     }
 }
