@@ -19,17 +19,11 @@ bse_categories_match_typed_setup (BseProcedureClass *proc, GParamSpec **in_pspec
  {
 #line 29 "bsecategories.proc"
   *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
-			    "*", SFI_PARAM_DEFAULT);
+			    "*", SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("type", "Type", "Base type for categories to conform to.",
-			    NULL, SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_STANDARD);
 }
-#line 28 "bsecategories.proc"
-  proc->help = "List BSE categories according to a pattern and type match.";
-#line 23 "bsecategories.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsecategories.proc"
-  proc->license = "GNU General Public License";
 #line 35 "bsecategories.proc"
  }
 static BseErrorType
@@ -70,15 +64,9 @@ bse_categories_match_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPa
  {
 #line 62 "bsecategories.proc"
   *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
-			    "*", SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
+			    "*", SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_STANDARD);
 }
-#line 61 "bsecategories.proc"
-  proc->help = "List BSE categories according to a pattern match.";
-#line 23 "bsecategories.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsecategories.proc"
-  proc->license = "GNU General Public License";
 #line 66 "bsecategories.proc"
  }
 static BseErrorType
@@ -116,15 +104,9 @@ bse_category_from_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPa
  {
 #line 90 "bsecategories.proc"
   *(in_pspecs++) = sfi_pspec_int ("category_id", "Category ID", NULL,
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = bse_param_spec_boxed ("category", "Category", NULL, BSE_TYPE_CATEGORY, SFI_PARAM_DEFAULT);
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_boxed ("category", "Category", NULL, BSE_TYPE_CATEGORY, SFI_PARAM_STANDARD);
 }
-#line 89 "bsecategories.proc"
-  proc->help = "Find a BSE category from it's unique ID.";
-#line 23 "bsecategories.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsecategories.proc"
-  proc->license = "GNU General Public License";
 #line 94 "bsecategories.proc"
  }
 static BseErrorType
@@ -173,17 +155,11 @@ bse_categories_match_method_setup (BseProcedureClass *proc, GParamSpec **in_pspe
  {
 #line 130 "bsecategories.proc"
   *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
-			    "*", SFI_PARAM_DEFAULT);
+			    "*", SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("type", "Type", "Object base type for methods to conform to.",
-			    NULL, SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_STANDARD);
 }
-#line 129 "bsecategories.proc"
-  proc->help = "List BSE categories according to a pattern, of type procedure and applying to a certain object type.";
-#line 23 "bsecategories.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsecategories.proc"
-  proc->license = "GNU General Public License";
 #line 136 "bsecategories.proc"
  }
 static BseErrorType
@@ -217,24 +193,72 @@ bse_categories_match_method_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_bse_categories_match_typed__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "List BSE categories according to a pattern and type match.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_categories_match_typed = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "bse-categories-match-typed", "/Proc/Categories/Match Typed", NULL },
+    "bse-categories-match-typed", 
+    NULL,
+    "/Proc/Categories/Match Typed",
+    NULL,
+    __enode_bse_categories_match_typed__fill_strings,
+  },
   0, bse_categories_match_typed_setup, bse_categories_match_typed_exec, 
 };
+static void
+__enode_bse_categories_match__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "List BSE categories according to a pattern match.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_categories_match = {
   { (BseExportNode*) &__enode_bse_categories_match_typed, BSE_EXPORT_NODE_PROC,
-    "bse-categories-match", "/Proc/Categories/Match", NULL },
+    "bse-categories-match", 
+    NULL,
+    "/Proc/Categories/Match",
+    NULL,
+    __enode_bse_categories_match__fill_strings,
+  },
   0, bse_categories_match_setup, bse_categories_match_exec, 
 };
+static void
+__enode_bse_category_from_id__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Find a BSE category from it's unique ID.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_category_from_id = {
   { (BseExportNode*) &__enode_bse_categories_match, BSE_EXPORT_NODE_PROC,
-    "bse-category-from-id", "/Proc/Categories/From ID", NULL },
+    "bse-category-from-id", 
+    NULL,
+    "/Proc/Categories/From ID",
+    NULL,
+    __enode_bse_category_from_id__fill_strings,
+  },
   0, bse_category_from_id_setup, bse_category_from_id_exec, 
 };
+static void
+__enode_bse_categories_match_method__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "List BSE categories according to a pattern, of type procedure and applying to a certain object type.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_categories_match_method = {
   { (BseExportNode*) &__enode_bse_category_from_id, BSE_EXPORT_NODE_PROC,
-    "bse-categories-match-method", "/Proc/Categories/Match Method", NULL },
+    "bse-categories-match-method", 
+    NULL,
+    "/Proc/Categories/Match Method",
+    NULL,
+    __enode_bse_categories_match_method__fill_strings,
+  },
   0, bse_categories_match_method_setup, bse_categories_match_method_exec, 
 };
 BseExportNode* bse__builtin_init_bsecategories_gen_proc_c (void);
