@@ -121,37 +121,55 @@ get_item_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_list_items__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve all items within a container";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_list_items = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "BseContainer+list-items", 
     NULL,
     "/Methods/BseContainer/General/List Items",
-    "Retrieve all items within a container",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_list_items__fill_strings,
   },
   0, list_items_setup, list_items_exec, 
 };
+static void
+__enode_lookup_item__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Find an immediate child of a container from its uname (the uname "
+	   "is the name of the item, unique between all immediate children of a container).");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_lookup_item = {
   { (BseExportNode*) &__enode_list_items, BSE_EXPORT_NODE_PROC,
     "BseContainer+lookup-item", 
     NULL,
     "/Methods/BseContainer/General/Lookup Item",
-    ("Find an immediate child of a container from its uname (the uname "
-	   "is the name of the item, unique between all immediate children of a container)."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_lookup_item__fill_strings,
   },
   0, lookup_item_setup, lookup_item_exec, 
 };
+static void
+__enode_get_item__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve a containers immediate child from it's sequential id.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_item = {
   { (BseExportNode*) &__enode_lookup_item, BSE_EXPORT_NODE_PROC,
     "BseContainer+get-item", 
     NULL,
     "/Methods/BseContainer/General/Get Item",
-    "Retrieve a containers immediate child from it's sequential id.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_item__fill_strings,
   },
   0, get_item_setup, get_item_exec, 
 };
