@@ -71,7 +71,7 @@ struct _BseContainerClass
 void		bse_container_forall_items	(BseContainer	*container,
 						 BseForallItemsFunc func,
 						 gpointer	 data);
-BseProxySeq*	bse_container_list_items	(BseContainer	*container);
+BseItemSeq*	bse_container_list_items	(BseContainer	*container);
 guint		bse_container_get_item_seqid	(BseContainer	*container,
 						 BseItem	*item);
 BseItem*	bse_container_get_item		(BseContainer	*container,
