@@ -15,11 +15,11 @@
 
 
 /* --- Export to BSE --- */
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_PROCEDURES = {
-  { NULL, },
-};
-BSE_EXPORTS_END;
+BseExportNode* bse__builtin_init_bsecsynth_gen_proc_c (void);
+BseExportNode* bse__builtin_init_bsecsynth_gen_proc_c (void)
+{
+  return NULL;
+}
 
 /**
  ** Generated data ends here
