@@ -34,21 +34,14 @@ struct JStream {
   unsigned int  n_connections;
 private:
   unsigned int  jcount; /* reserved */
-  unsigned int  reserved : 16;
 };
 struct IStream {
   const float  *values;
-private:
-  unsigned int  reserved : 16;
-public:
-  unsigned int  connected : 1;
+  gboolean      connected;
 };
 struct OStream {
   float        *values;
-private:
-  unsigned int  sub_sample_pattern : 16;
-public:
-  unsigned int  connected : 1;
+  gboolean      connected;
 };
 
 class SynthesisModule {
@@ -110,10 +103,10 @@ public:
   guint         ichannels_jstream (guint i)     { return BSE_SOURCE_ICHANNEL_JSTREAM (gobject(), i); }
   guint         ochannels_ostream (guint i)     { return BSE_SOURCE_OCHANNEL_OSTREAM (gobject(), i); }
   const gchar*  ichannel_ident (guint i)        { return BSE_SOURCE_ICHANNEL_IDENT (gobject(), i); }
-  const gchar*  ichannel_name (guint i)         { return BSE_SOURCE_ICHANNEL_NAME (gobject(), i); }
+  const gchar*  ichannel_label (guint i)        { return BSE_SOURCE_ICHANNEL_LABEL (gobject(), i); }
   const gchar*  ichannel_blurb (guint i)        { return BSE_SOURCE_ICHANNEL_BLURB (gobject(), i); }
   const gchar*  ochannel_ident (guint i)        { return BSE_SOURCE_OCHANNEL_IDENT (gobject(), i); }
-  const gchar*  ochannel_name (guint i)         { return BSE_SOURCE_OCHANNEL_NAME (gobject(), i); }
+  const gchar*  ochannel_label (guint i)        { return BSE_SOURCE_OCHANNEL_LABEL (gobject(), i); }
   const gchar*  ochannel_blurb (guint i)        { return BSE_SOURCE_OCHANNEL_BLURB (gobject(), i); }
   virtual SynthesisModule*  create_module        (unsigned int     context_handle,
                                                   GslTrans        *trans) = 0;
