@@ -105,9 +105,9 @@ TypeRegistry::init_types()
       if (li->cinfo)
         {
           if (li->cinfo->category)
-            bse_categories_register (li->cinfo->category, self->gtype_id, NULL);
+            bse_categories_register (li->cinfo->category, NULL, self->gtype_id, NULL);
           if (li->cinfo->blurb)
-            bse_type_set_blurb (self->gtype_id, li->cinfo->blurb);
+            bse_type_add_blurb (self->gtype_id, li->cinfo->blurb);
         }
     }
   delete type_entries;
@@ -121,16 +121,13 @@ bse_terminate_handler ()
     throw;      // rethrow
   }
   catch (Exception &e) {
-    sfi_error ("aborting due to exception: %s [in %s]", e.what(), e.where());
-    abort ();
+    g_error ("aborting due to exception: %s [in %s]", e.what(), e.where());
   }
   catch (std::exception &e) {
-    sfi_error ("aborting due to exception: %s", e.what());
-    abort ();
+    g_error ("aborting due to exception: %s", e.what());
   }
   catch (...) {
-    sfi_error ("aborting due to unknown exception");
-    abort ();
+    g_error ("aborting due to uncaught exception");
   }
 }
 
