@@ -572,142 +572,214 @@ get_string_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_create_entry__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Create a new entry in a data pocket. "
+	   "Entries have a unique ID which is required to set values in a data pocket.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_create_entry = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+create-entry", 
     NULL,
     "/Methods/BseDataPocket/General/Create Entry",
-    ("Create a new entry in a data pocket. "
-	   "Entries have a unique ID which is required to set values in a data pocket."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_create_entry__fill_strings,
   },
   0, create_entry_setup, create_entry_exec, 
 };
+static void
+__enode_delete_entry__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Delete an existing entry from a data pocket";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_delete_entry = {
   { (BseExportNode*) &__enode_create_entry, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+delete-entry", 
     NULL,
     "/Methods/BseDataPocket/General/Delete Entry",
-    "Delete an existing entry from a data pocket",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_delete_entry__fill_strings,
   },
   0, delete_entry_setup, delete_entry_exec, 
 };
+static void
+__enode_get_n_entries__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the number of entries created in a data pocket.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_n_entries = {
   { (BseExportNode*) &__enode_delete_entry, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+get-n-entries", 
     NULL,
     "/Methods/BseDataPocket/General/Get N Entries",
-    "Retrieve the number of entries created in a data pocket.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_n_entries__fill_strings,
   },
   0, get_n_entries_setup, get_n_entries_exec, 
 };
+static void
+__enode_get_nth_entry_id__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the ID of an entry in the data pocket by sequential index.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_nth_entry_id = {
   { (BseExportNode*) &__enode_get_n_entries, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+get-nth-entry-id", 
     NULL,
     "/Methods/BseDataPocket/General/Get Nth Entry Id",
-    "Retrieve the ID of an entry in the data pocket by sequential index.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_nth_entry_id__fill_strings,
   },
   0, get_nth_entry_id_setup, get_nth_entry_id_exec, 
 };
+static void
+__enode_set_float__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Set a named floating point value in a data pocket entry. "
+	   "Names are required to distinguish different values from each other "
+	   "when accessing values in a data pocket.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_set_float = {
   { (BseExportNode*) &__enode_get_nth_entry_id, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+set-float", 
     NULL,
     "/Methods/BseDataPocket/General/Set Float",
-    ("Set a named floating point value in a data pocket entry. "
-	   "Names are required to distinguish different values from each other "
-	   "when accessing values in a data pocket."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_set_float__fill_strings,
   },
   0, set_float_setup, set_float_exec, 
 };
+static void
+__enode_set_int__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Set a named integer value in a data pocket entry. "
+	   "Names are required to distinguish different values from each other "
+	   "when accessing values in a data pocket.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_set_int = {
   { (BseExportNode*) &__enode_set_float, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+set-int", 
     NULL,
     "/Methods/BseDataPocket/General/Set Int",
-    ("Set a named integer value in a data pocket entry. "
-	   "Names are required to distinguish different values from each other "
-	   "when accessing values in a data pocket."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_set_int__fill_strings,
   },
   0, set_int_setup, set_int_exec, 
 };
+static void
+__enode_set_object__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Set a named object reference in a data pocket entry. "
+	   "Object references stored in a data pocket must exist within the "
+	   "same project that the data pocket belongs to");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_set_object = {
   { (BseExportNode*) &__enode_set_int, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+set-object", 
     NULL,
     "/Methods/BseDataPocket/General/Set Object",
-    ("Set a named object reference in a data pocket entry. "
-	   "Object references stored in a data pocket must exist within the "
-	   "same project that the data pocket belongs to"),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_set_object__fill_strings,
   },
   0, set_object_setup, set_object_exec, 
 };
+static void
+__enode_set_string__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Set a named string in a data pocket entry.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_set_string = {
   { (BseExportNode*) &__enode_set_object, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+set-string", 
     NULL,
     "/Methods/BseDataPocket/General/Set String",
-    ("Set a named string in a data pocket entry."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_set_string__fill_strings,
   },
   0, set_string_setup, set_string_exec, 
 };
+static void
+__enode_get_float__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve a previously set floating point value from a data pocket entry.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_float = {
   { (BseExportNode*) &__enode_set_string, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+get-float", 
     NULL,
     "/Methods/BseDataPocket/General/Get Float",
-    "Retrieve a previously set floating point value from a data pocket entry.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_float__fill_strings,
   },
   0, get_float_setup, get_float_exec, 
 };
+static void
+__enode_get_int__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve a previously set integer value from a data pocket entry.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_int = {
   { (BseExportNode*) &__enode_get_float, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+get-int", 
     NULL,
     "/Methods/BseDataPocket/General/Get Int",
-    "Retrieve a previously set integer value from a data pocket entry.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_int__fill_strings,
   },
   0, get_int_setup, get_int_exec, 
 };
+static void
+__enode_get_object__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve a previously set object reference from a data pocket entry.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_object = {
   { (BseExportNode*) &__enode_get_int, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+get-object", 
     NULL,
     "/Methods/BseDataPocket/General/Get Object",
-    "Retrieve a previously set object reference from a data pocket entry.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_object__fill_strings,
   },
   0, get_object_setup, get_object_exec, 
 };
+static void
+__enode_get_string__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve a previously set string from a data pocket entry.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_string = {
   { (BseExportNode*) &__enode_get_object, BSE_EXPORT_NODE_PROC,
     "BseDataPocket+get-string", 
     NULL,
     "/Methods/BseDataPocket/General/Get String",
-    "Retrieve a previously set string from a data pocket entry.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_string__fill_strings,
   },
   0, get_string_setup, get_string_exec, 
 };
