@@ -364,80 +364,122 @@ collect_stats_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_open__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Open the sample for reading.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_open = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "BseEditableSample+open", 
     NULL,
     "/Methods/BseEditableSample/General/Open",
-    ("Open the sample for reading."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_open__fill_strings,
   },
   0, open_setup, open_exec, 
 };
+static void
+__enode_close__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Close an opened sample.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_close = {
   { (BseExportNode*) &__enode_open, BSE_EXPORT_NODE_PROC,
     "BseEditableSample+close", 
     NULL,
     "/Methods/BseEditableSample/General/Close",
-    ("Close an opened sample."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_close__fill_strings,
   },
   0, close_setup, close_exec, 
 };
+static void
+__enode_get_length__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Return the number of values in the sample.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_length = {
   { (BseExportNode*) &__enode_close, BSE_EXPORT_NODE_PROC,
     "BseEditableSample+get-length", 
     NULL,
     "/Methods/BseEditableSample/General/Get Length",
-    ("Return the number of values in the sample."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_length__fill_strings,
   },
   0, get_length_setup, get_length_exec, 
 };
+static void
+__enode_get_n_channels__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Return the number of channels in the sample.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_n_channels = {
   { (BseExportNode*) &__enode_get_length, BSE_EXPORT_NODE_PROC,
     "BseEditableSample+get-n-channels", 
     NULL,
     "/Methods/BseEditableSample/General/Get N Channels",
-    ("Return the number of channels in the sample."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_n_channels__fill_strings,
   },
   0, get_n_channels_setup, get_n_channels_exec, 
 };
+static void
+__enode_get_osc_freq__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Return the oscillator frequency for the sample.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_osc_freq = {
   { (BseExportNode*) &__enode_get_n_channels, BSE_EXPORT_NODE_PROC,
     "BseEditableSample+get-osc-freq", 
     NULL,
     "/Methods/BseEditableSample/General/Get Osc Freq",
-    ("Return the oscillator frequency for the sample."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_osc_freq__fill_strings,
   },
   0, get_osc_freq_setup, get_osc_freq_exec, 
 };
+static void
+__enode_read_samples__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Read a set of samples from a specific offset.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_read_samples = {
   { (BseExportNode*) &__enode_get_osc_freq, BSE_EXPORT_NODE_PROC,
     "BseEditableSample+read-samples", 
     NULL,
     "/Methods/BseEditableSample/General/Read Samples",
-    ("Read a set of samples from a specific offset."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_read_samples__fill_strings,
   },
   0, read_samples_setup, read_samples_exec, 
 };
+static void
+__enode_collect_stats__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Collect statistics from sample blocks as (minimum, maximum) pairs.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_collect_stats = {
   { (BseExportNode*) &__enode_read_samples, BSE_EXPORT_NODE_PROC,
     "BseEditableSample+collect-stats", 
     NULL,
     "/Methods/BseEditableSample/General/Collect Stats",
-    ("Collect statistics from sample blocks as (minimum, maximum) pairs."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_collect_stats__fill_strings,
   },
   0, collect_stats_setup, collect_stats_exec, 
 };
