@@ -39,6 +39,10 @@ GType BSE_TYPE_ID (BseMidiDecoderState) = 0;
  ** Generated data (by mktypes.pl --interns --export-proto)
  **/
 
+/* --- bsesongbus.c --- */
+extern BSE_BUILTIN_PROTO (BseSongBus);
+GType bse_type_builtin_id_BseSongBus = 0;
+
 /* --- bsebiquadfilter.c --- */
 extern BSE_BUILTIN_PROTO (BseBiquadFilter);
 GType bse_type_builtin_id_BseBiquadFilter = 0;
