@@ -57,6 +57,9 @@ extern GType BSE_TYPE_ID (BseMidiDecoderState);
  ** Generated data (by mktypes.pl --externs)
  **/
 
+/* --- bsesongbus.c --- */
+extern GType bse_type_builtin_id_BseSongBus;
+
 /* --- bsebiquadfilter.c --- */
 extern GType bse_type_builtin_id_BseBiquadFilter;
 
@@ -383,6 +386,19 @@ typedef enum {
 const gchar* bse_midi_signal_type_to_choice (BseMidiSignalType value);
 BseMidiSignalType bse_midi_signal_type_from_choice (const gchar *choice);
 
+typedef enum {
+  BSE_THREAD_STATE_UNKNOWN = 0,
+  BSE_THREAD_STATE_RUNNING = 1,
+  BSE_THREAD_STATE_SLEEPING = 2,
+  BSE_THREAD_STATE_DISKWAIT = 3,
+  BSE_THREAD_STATE_TRACED = 4,
+  BSE_THREAD_STATE_PAGING = 5,
+  BSE_THREAD_STATE_ZOMBIE = 6,
+  BSE_THREAD_STATE_DEAD = 7,
+} BseThreadState;
+const gchar* bse_thread_state_to_choice (BseThreadState value);
+BseThreadState bse_thread_state_from_choice (const gchar *choice);
+
 
 /* record typedefs */
 typedef struct _BsePartNote BsePartNote;
@@ -395,6 +411,8 @@ typedef struct _BseDot BseDot;
 typedef struct _BseTrackPart BseTrackPart;
 typedef struct _BseSongTiming BseSongTiming;
 typedef struct _BseSampleFileInfo BseSampleFileInfo;
+typedef struct _BseThreadInfo BseThreadInfo;
+typedef struct _BseThreadTotals BseThreadTotals;
 typedef struct _BseGConfig BseGConfig;
 
 
@@ -408,6 +426,7 @@ typedef struct _BsePartControlSeq BsePartControlSeq;
 typedef struct _BseCategorySeq BseCategorySeq;
 typedef struct _BseDotSeq BseDotSeq;
 typedef struct _BseTrackPartSeq BseTrackPartSeq;
+typedef struct _BseThreadInfoSeq BseThreadInfoSeq;
 
 
 /* sequences */
@@ -447,6 +466,10 @@ struct _BseTrackPartSeq {
   guint n_tparts;
   BseTrackPart** tparts;
 };
+struct _BseThreadInfoSeq {
+  guint n_thread_infos;
+  BseThreadInfo** thread_infos;
+};
 
 
 /* records */
@@ -522,6 +545,21 @@ struct _BseSampleFileInfo {
   BseStringSeq* waves;
   SfiInt error;
 };
+struct _BseThreadInfo {
+  gchar* name;
+  BseThreadState state;
+  SfiInt priority;
+  SfiInt processor;
+  SfiInt utime;
+  SfiInt stime;
+  SfiInt cutime;
+  SfiInt cstime;
+};
+struct _BseThreadTotals {
+  BseThreadInfo* main;
+  BseThreadInfo* sequencer;
+  BseThreadInfoSeq* synthesis;
+};
 struct _BseGConfig {
   gchar* sample_path;
   gchar* effect_path;
@@ -609,6 +647,20 @@ BseSampleFileInfo* bse_sample_file_info_from_rec (SfiRec *sfi_rec);
 SfiRec *bse_sample_file_info_to_rec (BseSampleFileInfo* rec);
 void bse_sample_file_info_free (BseSampleFileInfo* rec);
 
+SfiRecFields bse_thread_info_get_fields (void);
+BseThreadInfo* bse_thread_info_new (void);
+BseThreadInfo* bse_thread_info_copy_shallow (BseThreadInfo* rec);
+BseThreadInfo* bse_thread_info_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_thread_info_to_rec (BseThreadInfo* rec);
+void bse_thread_info_free (BseThreadInfo* rec);
+
+SfiRecFields bse_thread_totals_get_fields (void);
+BseThreadTotals* bse_thread_totals_new (void);
+BseThreadTotals* bse_thread_totals_copy_shallow (BseThreadTotals* rec);
+BseThreadTotals* bse_thread_totals_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_thread_totals_to_rec (BseThreadTotals* rec);
+void bse_thread_totals_free (BseThreadTotals* rec);
+
 SfiRecFields bse_gconfig_get_fields (void);
 BseGConfig* bse_gconfig_new (void);
 BseGConfig* bse_gconfig_copy_shallow (BseGConfig* rec);
@@ -700,14 +752,25 @@ SfiSeq *bse_track_part_seq_to_seq (BseTrackPartSeq* seq);
 void bse_track_part_seq_resize (BseTrackPartSeq* seq, guint new_size);
 void bse_track_part_seq_free (BseTrackPartSeq* seq);
 
+GParamSpec* bse_thread_info_seq_get_element (void);
+BseThreadInfoSeq* bse_thread_info_seq_new (void);
+void bse_thread_info_seq_append (BseThreadInfoSeq* seq, BseThreadInfo* element);
+BseThreadInfoSeq* bse_thread_info_seq_copy_shallow (BseThreadInfoSeq* seq);
+BseThreadInfoSeq* bse_thread_info_seq_from_seq (SfiSeq *sfi_seq);
+SfiSeq *bse_thread_info_seq_to_seq (BseThreadInfoSeq* seq);
+void bse_thread_info_seq_resize (BseThreadInfoSeq* seq, guint new_size);
+void bse_thread_info_seq_free (BseThreadInfoSeq* seq);
+
 
 
 /* enum functions */
 const SfiChoiceValues bse_midi_signal_type_get_values (void);
+const SfiChoiceValues bse_thread_state_get_values (void);
 
 
 /* enum type ids */
 extern GType bse__type_id__midi_signal_type;
+extern GType bse__type_id__thread_state;
 
 
 /* record type ids */
@@ -721,6 +784,8 @@ extern GType bse__type_id__dot;
 extern GType bse__type_id__track_part;
 extern GType bse__type_id__song_timing;
 extern GType bse__type_id__sample_file_info;
+extern GType bse__type_id__thread_info;
+extern GType bse__type_id__thread_totals;
 extern GType bse__type_id__gconfig;
 
 
@@ -734,12 +799,14 @@ extern GType bse__type_id__part_control_seq;
 extern GType bse__type_id__category_seq;
 extern GType bse__type_id__dot_seq;
 extern GType bse__type_id__track_part_seq;
+extern GType bse__type_id__thread_info_seq;
 
 #ifndef __cplusplus
 
 
 /* enum type macros */
 #define BSE_TYPE_MIDI_SIGNAL_TYPE		(bse__type_id__midi_signal_type)
+#define BSE_TYPE_THREAD_STATE		(bse__type_id__thread_state)
 
 
 /* record type macros */
@@ -753,6 +820,8 @@ extern GType bse__type_id__track_part_seq;
 #define BSE_TYPE_TRACK_PART		(bse__type_id__track_part)
 #define BSE_TYPE_SONG_TIMING		(bse__type_id__song_timing)
 #define BSE_TYPE_SAMPLE_FILE_INFO		(bse__type_id__sample_file_info)
+#define BSE_TYPE_THREAD_INFO		(bse__type_id__thread_info)
+#define BSE_TYPE_THREAD_TOTALS		(bse__type_id__thread_totals)
 #define BSE_TYPE_GCONFIG		(bse__type_id__gconfig)
 
 
@@ -766,6 +835,7 @@ extern GType bse__type_id__track_part_seq;
 #define BSE_TYPE_CATEGORY_SEQ		(bse__type_id__category_seq)
 #define BSE_TYPE_DOT_SEQ		(bse__type_id__dot_seq)
 #define BSE_TYPE_TRACK_PART_SEQ		(bse__type_id__track_part_seq)
+#define BSE_TYPE_THREAD_INFO_SEQ		(bse__type_id__thread_info_seq)
 
 #endif
 
