@@ -1045,313 +1045,481 @@ fixme_get_parasite_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_get_type__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve an item's type name.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_type = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "BseItem+get-type", 
     NULL,
     "/Methods/BseItem/General/Get Type",
-    "Retrieve an item's type name.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_type__fill_strings,
   },
   0, get_type_setup, get_type_exec, 
 };
+static void
+__enode_get_type_name__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve an item's type name.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_type_name = {
   { (BseExportNode*) &__enode_get_type, BSE_EXPORT_NODE_PROC,
     "BseItem+get-type-name", 
     NULL,
     "/Methods/BseItem/General/Get Type Name",
-    "Retrieve an item's type name.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_type_name__fill_strings,
   },
   0, get_type_name_setup, get_type_name_exec, 
 };
+static void
+__enode_get_type_blurb__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve an item's type description.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_type_blurb = {
   { (BseExportNode*) &__enode_get_type_name, BSE_EXPORT_NODE_PROC,
     "BseItem+get-type-blurb", 
     NULL,
     "/Methods/BseItem/General/Get Type Blurb",
-    "Retrieve an item's type description.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_type_blurb__fill_strings,
   },
   0, get_type_blurb_setup, get_type_blurb_exec, 
 };
+static void
+__enode_get_type_authors__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve authors of an item's type implementation.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_type_authors = {
   { (BseExportNode*) &__enode_get_type_blurb, BSE_EXPORT_NODE_PROC,
     "BseItem+get-type-authors", 
     NULL,
     "/Methods/BseItem/General/Get Type Authors",
-    "Retrieve authors of an item's type implementation.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_type_authors__fill_strings,
   },
   0, get_type_authors_setup, get_type_authors_exec, 
 };
+static void
+__enode_get_type_license__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the license for an item's type implementation.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_type_license = {
   { (BseExportNode*) &__enode_get_type_authors, BSE_EXPORT_NODE_PROC,
     "BseItem+get-type-license", 
     NULL,
     "/Methods/BseItem/General/Get Type License",
-    "Retrieve the license for an item's type implementation.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_type_license__fill_strings,
   },
   0, get_type_license_setup, get_type_license_exec, 
 };
+static void
+__enode_get_parent__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve an item's parent.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_parent = {
   { (BseExportNode*) &__enode_get_type_license, BSE_EXPORT_NODE_PROC,
     "BseItem+get-parent", 
     NULL,
     "/Methods/BseItem/General/Get Parent",
-    "Retrieve an item's parent.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_parent__fill_strings,
   },
   0, get_parent_setup, get_parent_exec, 
 };
+static void
+__enode_get_project__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve an item's project.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_project = {
   { (BseExportNode*) &__enode_get_parent, BSE_EXPORT_NODE_PROC,
     "BseItem+get-project", 
     NULL,
     "/Methods/BseItem/General/Get Project",
-    "Retrieve an item's project.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_project__fill_strings,
   },
   0, get_project_setup, get_project_exec, 
 };
+static void
+__enode_get_uname_path__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the project relative uname path for this item.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_uname_path = {
   { (BseExportNode*) &__enode_get_project, BSE_EXPORT_NODE_PROC,
     "BseItem+get-uname-path", 
     NULL,
     "/Methods/BseItem/General/Get Uname Path",
-    "Retrieve the project relative uname path for this item.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_uname_path__fill_strings,
   },
   0, get_uname_path_setup, get_uname_path_exec, 
 };
+static void
+__enode_internal__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether an item is internal, i.e. owned by another non-internal item.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_internal = {
   { (BseExportNode*) &__enode_get_uname_path, BSE_EXPORT_NODE_PROC,
     "BseItem+internal", 
     NULL,
     "/Methods/BseItem/General/Internal",
-    "Check whether an item is internal, i.e. owned by another non-internal item.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_internal__fill_strings,
   },
   0, internal_setup, internal_exec, 
 };
+static void
+__enode_use__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Increment use count to keep an item alive.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_use = {
   { (BseExportNode*) &__enode_internal, BSE_EXPORT_NODE_PROC,
     "BseItem+use", 
     NULL,
     "/Methods/BseItem/General/Use",
-    "Increment use count to keep an item alive.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_use__fill_strings,
   },
   0, use_setup, use_exec, 
 };
+static void
+__enode_unuse__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Decrement use count for when an item is not needed anymore.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_unuse = {
   { (BseExportNode*) &__enode_use, BSE_EXPORT_NODE_PROC,
     "BseItem+unuse", 
     NULL,
     "/Methods/BseItem/General/Unuse",
-    "Decrement use count for when an item is not needed anymore.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_unuse__fill_strings,
   },
   0, unuse_setup, unuse_exec, 
 };
+static void
+__enode_set_name__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Set an item's name.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_set_name = {
   { (BseExportNode*) &__enode_unuse, BSE_EXPORT_NODE_PROC,
     "BseItem+set-name", 
     NULL,
     "/Methods/BseItem/General/Set Name",
-    "Set an item's name.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_set_name__fill_strings,
   },
   0, set_name_setup, set_name_exec, 
 };
+static void
+__enode_get_name__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve an item's name.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_name = {
   { (BseExportNode*) &__enode_set_name, BSE_EXPORT_NODE_PROC,
     "BseItem+get-name", 
     NULL,
     "/Methods/BseItem/General/Get Name",
-    "Retrieve an item's name.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_name__fill_strings,
   },
   0, get_name_setup, get_name_exec, 
 };
+static void
+__enode_get_name_or_type__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve an item's name or type if it has no name.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_name_or_type = {
   { (BseExportNode*) &__enode_get_name, BSE_EXPORT_NODE_PROC,
     "BseItem+get-name-or-type", 
     NULL,
     "/Methods/BseItem/General/Get Name Or Type",
-    "Retrieve an item's name or type if it has no name.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_name_or_type__fill_strings,
   },
   0, get_name_or_type_setup, get_name_or_type_exec, 
 };
+static void
+__enode_common_ancestor__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the common ancestor of two items if there's any.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_common_ancestor = {
   { (BseExportNode*) &__enode_get_name_or_type, BSE_EXPORT_NODE_PROC,
     "BseItem+common-ancestor", 
     NULL,
     "/Methods/BseItem/General/Common Ancestor",
-    "Retrieve the common ancestor of two items if there's any.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_common_ancestor__fill_strings,
   },
   0, common_ancestor_setup, common_ancestor_exec, 
 };
+static void
+__enode_get_seqid__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("Retrieve an item's sequential ID. The sequential ID depends "
+	   "on the item's type an it's position inbetween siblings "
+	   "of the same type within it's immediate container.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_seqid = {
   { (BseExportNode*) &__enode_common_ancestor, BSE_EXPORT_NODE_PROC,
     "BseItem+get-seqid", 
     NULL,
     "/Methods/BseItem/General/Get Seqid",
-    ("Retrieve an item's sequential ID. The sequential ID depends "
-	   "on the item's type an it's position inbetween siblings "
-	   "of the same type within it's immediate container."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_seqid__fill_strings,
   },
   0, get_seqid_setup, get_seqid_exec, 
 };
+static void
+__enode_check_is_a__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether an item has a certain type.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_check_is_a = {
   { (BseExportNode*) &__enode_get_seqid, BSE_EXPORT_NODE_PROC,
     "BseItem+check-is-a", 
     NULL,
     "/Methods/BseItem/General/Check Is A",
-    "Check whether an item has a certain type.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_check_is_a__fill_strings,
   },
   0, check_is_a_setup, check_is_a_exec, 
 };
+static void
+__enode_list_items__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "List possible values for an item property of an item.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_list_items = {
   { (BseExportNode*) &__enode_check_is_a, BSE_EXPORT_NODE_PROC,
     "BseItem+list-items", 
     NULL,
     "/Methods/BseItem/General/List Items",
-    "List possible values for an item property of an item.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_list_items__fill_strings,
   },
   0, list_items_setup, list_items_exec, 
 };
+static void
+__enode_get_icon__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Get the current icon of an item.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_icon = {
   { (BseExportNode*) &__enode_list_items, BSE_EXPORT_NODE_PROC,
     "BseItem+get-icon", 
     NULL,
     "/Methods/BseItem/General/Get Icon",
-    "Get the current icon of an item.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_icon__fill_strings,
   },
   0, get_icon_setup, get_icon_exec, 
 };
+static void
+__enode_group_undo__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Request multiple modifying actions on an item to be grouped together as single undo operation.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_group_undo = {
   { (BseExportNode*) &__enode_get_icon, BSE_EXPORT_NODE_PROC,
     "BseItem+group-undo", 
     NULL,
     "/Methods/BseItem/General/Group Undo",
-    "Request multiple modifying actions on an item to be grouped together as single undo operation.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_group_undo__fill_strings,
   },
   0, group_undo_setup, group_undo_exec, 
 };
+static void
+__enode_ungroup_undo__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Ends the undo grouping opened up by a previous group-undo() call.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_ungroup_undo = {
   { (BseExportNode*) &__enode_group_undo, BSE_EXPORT_NODE_PROC,
     "BseItem+ungroup-undo", 
     NULL,
     "/Methods/BseItem/General/Ungroup Undo",
-    "Ends the undo grouping opened up by a previous group-undo() call.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_ungroup_undo__fill_strings,
   },
   0, ungroup_undo_setup, ungroup_undo_exec, 
 };
+static void
+__enode_undo__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Call the undo function of the project corresponding to this item if any.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_undo = {
   { (BseExportNode*) &__enode_ungroup_undo, BSE_EXPORT_NODE_PROC,
     "BseItem+undo", 
     NULL,
     "/Methods/BseItem/General/Undo",
-    "Call the undo function of the project corresponding to this item if any.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_undo__fill_strings,
   },
   0, undo_setup, undo_exec, 
 };
+static void
+__enode_redo__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Call the redo function of the project corresponding to this item if any.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_redo = {
   { (BseExportNode*) &__enode_undo, BSE_EXPORT_NODE_PROC,
     "BseItem+redo", 
     NULL,
     "/Methods/BseItem/General/Redo",
-    "Call the redo function of the project corresponding to this item if any.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_redo__fill_strings,
   },
   0, redo_setup, redo_exec, 
 };
+static void
+__enode_clear_undo__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Call the clear-undo function of the project corresponding to this item if any.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_clear_undo = {
   { (BseExportNode*) &__enode_redo, BSE_EXPORT_NODE_PROC,
     "BseItem+clear-undo", 
     NULL,
     "/Methods/BseItem/General/Clear Undo",
-    "Call the clear-undo function of the project corresponding to this item if any.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_clear_undo__fill_strings,
   },
   0, clear_undo_setup, clear_undo_exec, 
 };
+static void
+__enode_undo_depth__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Call the undo-depth function of the project corresponding to this item if any.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_undo_depth = {
   { (BseExportNode*) &__enode_clear_undo, BSE_EXPORT_NODE_PROC,
     "BseItem+undo-depth", 
     NULL,
     "/Methods/BseItem/General/Undo Depth",
-    "Call the undo-depth function of the project corresponding to this item if any.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_undo_depth__fill_strings,
   },
   0, undo_depth_setup, undo_depth_exec, 
 };
+static void
+__enode_redo_depth__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Call the redo-depth function of the project corresponding to this item if any.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_redo_depth = {
   { (BseExportNode*) &__enode_undo_depth, BSE_EXPORT_NODE_PROC,
     "BseItem+redo-depth", 
     NULL,
     "/Methods/BseItem/General/Redo Depth",
-    "Call the redo-depth function of the project corresponding to this item if any.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_redo_depth__fill_strings,
   },
   0, redo_depth_setup, redo_depth_exec, 
 };
+static void
+__enode_fixme_set_parasite__fill_strings (BseExportStrings *es)
+{
+  es->blurb = NULL;
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_fixme_set_parasite = {
   { (BseExportNode*) &__enode_redo_depth, BSE_EXPORT_NODE_PROC,
     "BseItem+fixme-set-parasite", 
     NULL,
     "/Methods/BseItem/General/Fixme Set Parasite",
     NULL,
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    __enode_fixme_set_parasite__fill_strings,
   },
   0, fixme_set_parasite_setup, fixme_set_parasite_exec, 
 };
+static void
+__enode_fixme_get_parasite__fill_strings (BseExportStrings *es)
+{
+  es->blurb = NULL;
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_fixme_get_parasite = {
   { (BseExportNode*) &__enode_fixme_set_parasite, BSE_EXPORT_NODE_PROC,
     "BseItem+fixme-get-parasite", 
     NULL,
     "/Methods/BseItem/General/Fixme Get Parasite",
     NULL,
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    __enode_fixme_get_parasite__fill_strings,
   },
   0, fixme_get_parasite_setup, fixme_get_parasite_exec, 
 };
