@@ -39,6 +39,9 @@ void		bse_init_intern		(gint		*argc,
 					 gchar	      ***argv,
 					 SfiRec		*config);
 
+/* BSE thread pid (or 0) */
+guint           bse_main_getpid         (void);
+
 
 /* --- global macros --- */
 #define	BSE_THREADS_ENTER()			// bse_main_global_lock ()
@@ -49,6 +52,7 @@ void		bse_init_intern		(gint		*argc,
 
 
 /* --- internal --- */
+void    _bse_init_c_wrappers    ();
 extern GMainContext *bse_main_context;
 extern SfiMutex	     bse_main_sequencer_mutex;
 extern gboolean      bse_main_debug_extensions;
