@@ -55,14 +55,20 @@ current_time_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_current_time__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Test";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_current_time = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "BseMidiNotifier+current-time", 
     NULL,
     "/Methods/BseMidiNotifier/General/Current Time",
-    "Test",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_current_time__fill_strings,
   },
   0, current_time_setup, current_time_exec, 
 };
