@@ -1363,311 +1363,479 @@ get_timing_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_insert_note_auto__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Insert a new note into a part with automatic channel selection.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_insert_note_auto = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "BsePart+insert-note-auto", 
     NULL,
     "/Methods/BsePart/General/Insert Note Auto",
-    "Insert a new note into a part with automatic channel selection.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_insert_note_auto__fill_strings,
   },
   0, insert_note_auto_setup, insert_note_auto_exec, 
 };
+static void
+__enode_insert_note__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Insert a new note into a part.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_insert_note = {
   { (BseExportNode*) &__enode_insert_note_auto, BSE_EXPORT_NODE_PROC,
     "BsePart+insert-note", 
     NULL,
     "/Methods/BsePart/General/Insert Note",
-    "Insert a new note into a part.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_insert_note__fill_strings,
   },
   0, insert_note_setup, insert_note_exec, 
 };
+static void
+__enode_insert_control__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Insert a new control event into a part.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_insert_control = {
   { (BseExportNode*) &__enode_insert_note, BSE_EXPORT_NODE_PROC,
     "BsePart+insert-control", 
     NULL,
     "/Methods/BsePart/General/Insert Control",
-    "Insert a new control event into a part.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_insert_control__fill_strings,
   },
   0, insert_control_setup, insert_control_exec, 
 };
+static void
+__enode_change_note__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Change an existing note within a part.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_change_note = {
   { (BseExportNode*) &__enode_insert_control, BSE_EXPORT_NODE_PROC,
     "BsePart+change-note", 
     NULL,
     "/Methods/BsePart/General/Change Note",
-    "Change an existing note within a part.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_change_note__fill_strings,
   },
   0, change_note_setup, change_note_exec, 
 };
+static void
+__enode_change_control__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Change an existing control event within a part.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_change_control = {
   { (BseExportNode*) &__enode_change_note, BSE_EXPORT_NODE_PROC,
     "BsePart+change-control", 
     NULL,
     "/Methods/BsePart/General/Change Control",
-    "Change an existing control event within a part.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_change_control__fill_strings,
   },
   0, change_control_setup, change_control_exec, 
 };
+static void
+__enode_delete_event__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Delete an existing event from a part.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_delete_event = {
   { (BseExportNode*) &__enode_change_control, BSE_EXPORT_NODE_PROC,
     "BsePart+delete-event", 
     NULL,
     "/Methods/BsePart/General/Delete Event",
-    "Delete an existing event from a part.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_delete_event__fill_strings,
   },
   0, delete_event_setup, delete_event_exec, 
 };
+static void
+__enode_is_event_selected__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether an event is selected.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_is_event_selected = {
   { (BseExportNode*) &__enode_delete_event, BSE_EXPORT_NODE_PROC,
     "BsePart+is-event-selected", 
     NULL,
     "/Methods/BsePart/General/Is Event Selected",
-    "Check whether an event is selected.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_is_event_selected__fill_strings,
   },
   0, is_event_selected_setup, is_event_selected_exec, 
 };
+static void
+__enode_list_notes_crossing__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "List all notes within or crossing a tick range.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_list_notes_crossing = {
   { (BseExportNode*) &__enode_is_event_selected, BSE_EXPORT_NODE_PROC,
     "BsePart+list-notes-crossing", 
     NULL,
     "/Methods/BsePart/General/List Notes Crossing",
-    "List all notes within or crossing a tick range.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_list_notes_crossing__fill_strings,
   },
   0, list_notes_crossing_setup, list_notes_crossing_exec, 
 };
+static void
+__enode_list_notes_within__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "List all notes within a tick range.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_list_notes_within = {
   { (BseExportNode*) &__enode_list_notes_crossing, BSE_EXPORT_NODE_PROC,
     "BsePart+list-notes-within", 
     NULL,
     "/Methods/BsePart/General/List Notes Within",
-    "List all notes within a tick range.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_list_notes_within__fill_strings,
   },
   0, list_notes_within_setup, list_notes_within_exec, 
 };
+static void
+__enode_list_controls__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "List all control events within a tick range.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_list_controls = {
   { (BseExportNode*) &__enode_list_notes_within, BSE_EXPORT_NODE_PROC,
     "BsePart+list-controls", 
     NULL,
     "/Methods/BsePart/General/List Controls",
-    "List all control events within a tick range.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_list_controls__fill_strings,
   },
   0, list_controls_setup, list_controls_exec, 
 };
+static void
+__enode_queue_notes__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Queue updates for all notes starting within the given rectangle.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_queue_notes = {
   { (BseExportNode*) &__enode_list_controls, BSE_EXPORT_NODE_PROC,
     "BsePart+queue-notes", 
     NULL,
     "/Methods/BsePart/General/Queue Notes",
-    "Queue updates for all notes starting within the given rectangle.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_queue_notes__fill_strings,
   },
   0, queue_notes_setup, queue_notes_exec, 
 };
+static void
+__enode_queue_controls__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Queue updates for all control events and notes starting within the given range.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_queue_controls = {
   { (BseExportNode*) &__enode_queue_notes, BSE_EXPORT_NODE_PROC,
     "BsePart+queue-controls", 
     NULL,
     "/Methods/BsePart/General/Queue Controls",
-    "Queue updates for all control events and notes starting within the given range.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_queue_controls__fill_strings,
   },
   0, queue_controls_setup, queue_controls_exec, 
 };
+static void
+__enode_list_selected_notes__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "List all currently selected notes.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_list_selected_notes = {
   { (BseExportNode*) &__enode_queue_controls, BSE_EXPORT_NODE_PROC,
     "BsePart+list-selected-notes", 
     NULL,
     "/Methods/BsePart/General/List Selected Notes",
-    "List all currently selected notes.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_list_selected_notes__fill_strings,
   },
   0, list_selected_notes_setup, list_selected_notes_exec, 
 };
+static void
+__enode_list_selected_controls__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "List all currently selected control events of a specific type.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_list_selected_controls = {
   { (BseExportNode*) &__enode_list_selected_notes, BSE_EXPORT_NODE_PROC,
     "BsePart+list-selected-controls", 
     NULL,
     "/Methods/BsePart/General/List Selected Controls",
-    "List all currently selected control events of a specific type.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_list_selected_controls__fill_strings,
   },
   0, list_selected_controls_setup, list_selected_controls_exec, 
 };
+static void
+__enode_check_overlap__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether a note would overlap with neighbours.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_check_overlap = {
   { (BseExportNode*) &__enode_list_selected_controls, BSE_EXPORT_NODE_PROC,
     "BsePart+check-overlap", 
     NULL,
     "/Methods/BsePart/General/Check Overlap",
-    "Check whether a note would overlap with neighbours.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_check_overlap__fill_strings,
   },
   0, check_overlap_setup, check_overlap_exec, 
 };
+static void
+__enode_get_notes__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve all notes of specific frequency at or crossing a specific tick.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_notes = {
   { (BseExportNode*) &__enode_check_overlap, BSE_EXPORT_NODE_PROC,
     "BsePart+get-notes", 
     NULL,
     "/Methods/BsePart/General/Get Notes",
-    "Retrieve all notes of specific frequency at or crossing a specific tick.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_notes__fill_strings,
   },
   0, get_notes_setup, get_notes_exec, 
 };
+static void
+__enode_get_controls__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve all control events of a specific type at specified tick.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_controls = {
   { (BseExportNode*) &__enode_get_notes, BSE_EXPORT_NODE_PROC,
     "BsePart+get-controls", 
     NULL,
     "/Methods/BsePart/General/Get Controls",
-    "Retrieve all control events of a specific type at specified tick.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_controls__fill_strings,
   },
   0, get_controls_setup, get_controls_exec, 
 };
+static void
+__enode_get_channel_controls__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve all control events of a specific type within range of a channel.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_channel_controls = {
   { (BseExportNode*) &__enode_get_controls, BSE_EXPORT_NODE_PROC,
     "BsePart+get-channel-controls", 
     NULL,
     "/Methods/BsePart/General/Get Channel Controls",
-    "Retrieve all control events of a specific type within range of a channel.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_channel_controls__fill_strings,
   },
   0, get_channel_controls_setup, get_channel_controls_exec, 
 };
+static void
+__enode_get_min_note__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the minimum note supported in this part.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_min_note = {
   { (BseExportNode*) &__enode_get_channel_controls, BSE_EXPORT_NODE_PROC,
     "BsePart+get-min-note", 
     NULL,
     "/Methods/BsePart/General/Get Min Note",
-    "Retrieve the minimum note supported in this part.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_min_note__fill_strings,
   },
   0, get_min_note_setup, get_min_note_exec, 
 };
+static void
+__enode_get_max_note__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the maximum note supported in this part.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_max_note = {
   { (BseExportNode*) &__enode_get_min_note, BSE_EXPORT_NODE_PROC,
     "BsePart+get-max-note", 
     NULL,
     "/Methods/BsePart/General/Get Max Note",
-    "Retrieve the maximum note supported in this part.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_max_note__fill_strings,
   },
   0, get_max_note_setup, get_max_note_exec, 
 };
+static void
+__enode_select_notes_exclusive__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Select all notes within rectangle and deselect all others.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_select_notes_exclusive = {
   { (BseExportNode*) &__enode_get_max_note, BSE_EXPORT_NODE_PROC,
     "BsePart+select-notes-exclusive", 
     NULL,
     "/Methods/BsePart/General/Select Notes Exclusive",
-    "Select all notes within rectangle and deselect all others.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_select_notes_exclusive__fill_strings,
   },
   0, select_notes_exclusive_setup, select_notes_exclusive_exec, 
 };
+static void
+__enode_select_controls_exclusive__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Select all control events within range and deselect all others.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_select_controls_exclusive = {
   { (BseExportNode*) &__enode_select_notes_exclusive, BSE_EXPORT_NODE_PROC,
     "BsePart+select-controls-exclusive", 
     NULL,
     "/Methods/BsePart/General/Select Controls Exclusive",
-    "Select all control events within range and deselect all others.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_select_controls_exclusive__fill_strings,
   },
   0, select_controls_exclusive_setup, select_controls_exclusive_exec, 
 };
+static void
+__enode_select_notes__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Select all notes within rectangle.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_select_notes = {
   { (BseExportNode*) &__enode_select_controls_exclusive, BSE_EXPORT_NODE_PROC,
     "BsePart+select-notes", 
     NULL,
     "/Methods/BsePart/General/Select Notes",
-    "Select all notes within rectangle.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_select_notes__fill_strings,
   },
   0, select_notes_setup, select_notes_exec, 
 };
+static void
+__enode_deselect_notes__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Deselect all notes within rectangle.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_deselect_notes = {
   { (BseExportNode*) &__enode_select_notes, BSE_EXPORT_NODE_PROC,
     "BsePart+deselect-notes", 
     NULL,
     "/Methods/BsePart/General/Deselect Notes",
-    "Deselect all notes within rectangle.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_deselect_notes__fill_strings,
   },
   0, deselect_notes_setup, deselect_notes_exec, 
 };
+static void
+__enode_deselect_controls__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Deselect all controls within given range.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_deselect_controls = {
   { (BseExportNode*) &__enode_deselect_notes, BSE_EXPORT_NODE_PROC,
     "BsePart+deselect-controls", 
     NULL,
     "/Methods/BsePart/General/Deselect Controls",
-    "Deselect all controls within given range.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_deselect_controls__fill_strings,
   },
   0, deselect_controls_setup, deselect_controls_exec, 
 };
+static void
+__enode_select_event__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Select an existing event.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_select_event = {
   { (BseExportNode*) &__enode_deselect_controls, BSE_EXPORT_NODE_PROC,
     "BsePart+select-event", 
     NULL,
     "/Methods/BsePart/General/Select Event",
-    "Select an existing event.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_select_event__fill_strings,
   },
   0, select_event_setup, select_event_exec, 
 };
+static void
+__enode_deselect_event__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Deselect an existing event.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_deselect_event = {
   { (BseExportNode*) &__enode_select_event, BSE_EXPORT_NODE_PROC,
     "BsePart+deselect-event", 
     NULL,
     "/Methods/BsePart/General/Deselect Event",
-    "Deselect an existing event.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_deselect_event__fill_strings,
   },
   0, deselect_event_setup, deselect_event_exec, 
 };
+static void
+__enode_get_timing__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve song timing information at a specific tick.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_timing = {
   { (BseExportNode*) &__enode_deselect_event, BSE_EXPORT_NODE_PROC,
     "BsePart+get-timing", 
     NULL,
     "/Methods/BsePart/General/Get Timing",
-    "Retrieve song timing information at a specific tick.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_timing__fill_strings,
   },
   0, get_timing_setup, get_timing_exec, 
 };
