@@ -111,12 +111,15 @@ gboolean           bse_part_change_control            (BsePart           *self,
                                                        guint              tick,
                                                        BseMidiSignalType  ctype,
                                                        gfloat             value);
-BsePartNoteSeq*    bse_part_list_notes_crossing       (BsePart           *self,
+BsePartNoteSeq*    bse_part_list_notes                (BsePart           *self,
+                                                       guint              channel,
                                                        guint              tick,
                                                        guint              duration,
                                                        gint               min_note,
-                                                       gint               max_note);
+                                                       gint               max_note,
+                                                       gboolean           include_crossings);
 BsePartControlSeq* bse_part_list_controls             (BsePart           *self,
+                                                       guint              channel, /* for note events */
                                                        guint              tick,
                                                        guint              duration,
                                                        BseMidiSignalType  ctype);
@@ -130,6 +133,7 @@ BsePartNoteSeq*    bse_part_list_selected_notes       (BsePart           *self);
 BsePartControlSeq* bse_part_list_selected_controls    (BsePart           *self,
                                                        BseMidiSignalType  ctype);
 void               bse_part_select_notes              (BsePart           *self,
+                                                       guint              channel,
                                                        guint              tick,
                                                        guint              duration,
                                                        gint               min_note,
@@ -141,6 +145,7 @@ void               bse_part_select_controls           (BsePart           *self,
                                                        BseMidiSignalType  ctype,
                                                        gboolean           selected);
 void               bse_part_select_notes_exclusive    (BsePart           *self,
+                                                       guint              channel,
                                                        guint              tick,
                                                        guint              duration,
                                                        gint               min_note,
