@@ -349,80 +349,122 @@ bse_string_extract_number_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_bse_note_to_freq__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the frequency of a certain note.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_note_to_freq = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "bse-note-to-freq", 
     NULL,
     "/Proc/Note to Freq",
-    "Retrieve the frequency of a certain note.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_bse_note_to_freq__fill_strings,
   },
   0, bse_note_to_freq_setup, bse_note_to_freq_exec, 
 };
+static void
+__enode_bse_note_from_freq__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the note of a certain frequency.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_note_from_freq = {
   { (BseExportNode*) &__enode_bse_note_to_freq, BSE_EXPORT_NODE_PROC,
     "bse-note-from-freq", 
     NULL,
     "/Proc/Note from Freq",
-    "Retrieve the note of a certain frequency.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_bse_note_from_freq__fill_strings,
   },
   0, bse_note_from_freq_setup, bse_note_from_freq_exec, 
 };
+static void
+__enode_bse_type_options__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the options of a specific type.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_type_options = {
   { (BseExportNode*) &__enode_bse_note_from_freq, BSE_EXPORT_NODE_PROC,
     "bse-type-options", 
     NULL,
     "/Proc/Type Options",
-    "Retrieve the options of a specific type.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_bse_type_options__fill_strings,
   },
   0, bse_type_options_setup, bse_type_options_exec, 
 };
+static void
+__enode_bse_type_blurb__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the description of a specific type.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_type_blurb = {
   { (BseExportNode*) &__enode_bse_type_options, BSE_EXPORT_NODE_PROC,
     "bse-type-blurb", 
     NULL,
     "/Proc/Type Blurb",
-    "Retrieve the description of a specific type.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_bse_type_blurb__fill_strings,
   },
   0, bse_type_blurb_setup, bse_type_blurb_exec, 
 };
+static void
+__enode_bse_type_authors__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the authors who implemented a specific type.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_type_authors = {
   { (BseExportNode*) &__enode_bse_type_blurb, BSE_EXPORT_NODE_PROC,
     "bse-type-authors", 
     NULL,
     "/Proc/Type Authors",
-    "Retrieve the authors who implemented a specific type.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_bse_type_authors__fill_strings,
   },
   0, bse_type_authors_setup, bse_type_authors_exec, 
 };
+static void
+__enode_bse_type_license__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the license of a type impementation.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_type_license = {
   { (BseExportNode*) &__enode_bse_type_authors, BSE_EXPORT_NODE_PROC,
     "bse-type-license", 
     NULL,
     "/Proc/Type License",
-    "Retrieve the license of a type impementation.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_bse_type_license__fill_strings,
   },
   0, bse_type_license_setup, bse_type_license_exec, 
 };
+static void
+__enode_bse_string_extract_number__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve numbers from a string.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_bse_string_extract_number = {
   { (BseExportNode*) &__enode_bse_type_license, BSE_EXPORT_NODE_PROC,
     "bse-string-extract-number", 
     NULL,
     "/Proc/String Extract Number",
-    "Retrieve numbers from a string.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_bse_string_extract_number__fill_strings,
   },
   0, bse_string_extract_number_setup, bse_string_extract_number_exec, 
 };
