@@ -27,6 +27,8 @@
 
 std::set<std::string> needTypes;
 std::set<std::string> needClasses;
+std::set<std::string> excludeTypes;
+
 bool silent = false;
 
 void print(const gchar *format, ...)
@@ -86,7 +88,8 @@ std::string getMethod (const std::string& name)
   return result;
 }
 
-std::string signalName (const std::string& signal)
+std::string
+signalName (const std::string& signal)
 {
   std::string result;
   std::string::const_iterator si = signal.begin ();
@@ -175,7 +178,9 @@ std::string idlType (GType g)
     default:
       if (s == "SfiFBlock")
         return "FBlock";
-      g_error ("bseprocidl: unsupported signal argument type: %s", s.c_str());
+      else if (s == "SfiRec")
+        return "Rec";
+      g_error ("bseprocidl: unsupported argument type: %s", s.c_str());
       return "*ERROR*";
     }
 }
@@ -232,6 +237,7 @@ void printMethods (const std::string& iface)
   for (i = 0; i < cseq->n_cats; i++)
     {
       GType type_id = g_type_from_name (cseq->cats[i]->type);
+      const gchar *blurb = bse_type_get_blurb (type_id);
       BseProcedureClass *klass = (BseProcedureClass *)g_type_class_ref (type_id);
       
       /* procedures */
@@ -259,9 +265,9 @@ void printMethods (const std::string& iface)
 	  print(") {\n");
 	  indent++;
           
-	  if (klass->help)
+	  if (blurb)
 	    {
-	      char *ehelp = g_strescape (klass->help, 0);
+	      char *ehelp = g_strescape (blurb, 0);
 	      printIndent ();
 	      print ("Info HELP = \"%s\";\n", ehelp);
 	      g_free (ehelp);
@@ -287,7 +293,7 @@ void printInterface (const std::string& iface, const std::string& parent = "")
 {
   std::string idliface = removeBse (iface);
 
-  if (iface == "BseAmplifier")
+  if (excludeTypes.count (iface))
     return;
 
   setActiveInterface (idliface, parent);
@@ -305,25 +311,51 @@ void printInterface (const std::string& iface, const std::string& parent = "")
 	    {
 	      GSignalQuery query;
 	      g_signal_query (sids[s], &query);
+
+              // FIXME: some core types are implemented as plugins, and thus have
+              // class destructors that are executed right after type registration.
+              // that's why we can't query their signals here
+              if (!query.signal_id)
+                continue;
+
+	      // FIXME: how to deal with Bse::MidiEvent?
+	      if (signalName (query.signal_name) == "midi_event")
+		continue;
+
 	      printIndent();
-              // FIXME: disabled signals, since it currently breaks
-	      // print ("signal %s (", signalName (query.signal_name).c_str());
+	      print ("signal %s (", signalName (query.signal_name).c_str());
 	      for (guint p = 0; p < query.n_params; p++)
 		{
 		  std::string ptype = idlType (query.param_types[p]);
 		  std::string pname = ""; pname += char('a' + p);
 		  if (p != 0)
-                    ; // print(", ");
-		  //print ("%s %s", ptype.c_str(), pname.c_str());
+                    print(", ");
+		  print ("%s %s", ptype.c_str(), pname.c_str());
                 }
-	      //print(");\n");
+	      print(");\n");
 	    }
 	}
       else
 	{
 	  print("/* type %s (%s) is not instantiatable */\n", g_type_name (type_id), iface.c_str());
 	}
-      
+     
+      /* properties */
+      GObjectClass *klass = (GObjectClass *)g_type_class_ref (type_id);
+      if (klass)
+	{
+	  guint n_properties = 0;
+	  GParamSpec **properties = g_object_class_list_properties (klass, &n_properties);
+	 
+	  for (guint i = 0; i < n_properties; i++)
+	    {
+	      if (properties[i]->owner_type == type_id)
+		printPSpec (("property "+idlType(properties[i]->value_type)+" ").c_str(), properties[i]);
+	    }
+	  g_free (properties);
+	  g_type_class_unref (klass);
+	}
+
       const gchar **children = sfi_glue_iface_children (iface.c_str());
       while (*children)
         printInterface (*children++, idliface);
@@ -344,10 +376,7 @@ printChoices (void)
       gboolean regular_choice = strcmp (name, "BseErrorType") != 0;
       GEnumValue *val;
 
-      if (children[i] == BSE_TYPE_MIDI_SIGNAL_TYPE)
-        continue;       /* FIXME: hack to skip predefined enums */
-      
-      if (needTypes.count (name))
+      if (needTypes.count (name) && !excludeTypes.count (name))
 	{
 	  /* enum definition */
 	  printIndent ();
@@ -388,6 +417,23 @@ printForwardDecls ()
 
 int main (int argc, char **argv)
 {
+  /* exclude all types given in a file, passed as first argument, from generation */
+  if (argc == 2)
+    {
+      FILE *excludefile = fopen (argv[1], "r");
+      if (!excludefile)
+	fprintf (stderr, "excludefile %s not found\n", argv[1]);
+      else
+	{
+	  char buffer[1024];
+	  while (fgets (buffer, 1024, excludefile))
+	    {
+	      buffer[strlen(buffer) - 1] = 0;
+	      printf ("// bseprocidl: type %s excluded from generation\n", buffer);
+	      excludeTypes.insert (buffer);
+	    }
+	}
+    }
   g_thread_init (NULL);
   bse_init_intern (&argc, &argv, NULL);
   
