@@ -1284,324 +1284,498 @@ clear_undo_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_is_playing__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether a project is currently playing";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_is_playing = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "BseProject+is-playing", 
     NULL,
     "/Methods/BseProject/General/Is Playing",
-    "Check whether a project is currently playing",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_is_playing__fill_strings,
   },
   0, is_playing_setup, is_playing_exec, 
 };
+static void
+__enode_is_active__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether a project is active";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_is_active = {
   { (BseExportNode*) &__enode_is_playing, BSE_EXPORT_NODE_PROC,
     "BseProject+is-active", 
     NULL,
     "/Methods/BseProject/General/Is Active",
-    "Check whether a project is active",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_is_active__fill_strings,
   },
   0, is_active_setup, is_active_exec, 
 };
+static void
+__enode_import_midi_file__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Import a song from a MIDI file.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_import_midi_file = {
   { (BseExportNode*) &__enode_is_active, BSE_EXPORT_NODE_PROC,
     "BseProject+import-midi-file", 
     NULL,
     "/Methods/BseProject/File/Import MIDI",
-    "Import a song from a MIDI file.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_import_midi_file__fill_strings,
   },
   0, import_midi_file_setup, import_midi_file_exec, 
 };
+static void
+__enode_restore_from_file__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Load a project from file";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_restore_from_file = {
   { (BseExportNode*) &__enode_import_midi_file, BSE_EXPORT_NODE_PROC,
     "BseProject+restore-from-file", 
     NULL,
     "/Methods/BseProject/File/Restore",
-    "Load a project from file",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_restore_from_file__fill_strings,
   },
   0, restore_from_file_setup, restore_from_file_exec, 
 };
+static void
+__enode_store_bse__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Save supers of a project into a BSE file. "
+          "If no super is specified, the project itself is stored.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_store_bse = {
   { (BseExportNode*) &__enode_restore_from_file, BSE_EXPORT_NODE_PROC,
     "BseProject+store-bse", 
     NULL,
     "/Methods/BseProject/File/Store",
-    "Save supers of a project into a BSE file. "
-          "If no super is specified, the project itself is stored.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_store_bse__fill_strings,
   },
   0, store_bse_setup, store_bse_exec, 
 };
+static void
+__enode_create_song__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Create a song for this project.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_create_song = {
   { (BseExportNode*) &__enode_store_bse, BSE_EXPORT_NODE_PROC,
     "BseProject+create-song", 
     NULL,
     "/Methods/BseProject/General/Create Song",
-    "Create a song for this project.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_create_song__fill_strings,
   },
   0, create_song_setup, create_song_exec, 
 };
+static void
+__enode_get_wave_repo__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Ensure the project has a wave repository";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_wave_repo = {
   { (BseExportNode*) &__enode_create_song, BSE_EXPORT_NODE_PROC,
     "BseProject+get-wave-repo", 
     NULL,
     "/Methods/BseProject/General/Get Wave Repo",
-    "Ensure the project has a wave repository",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_wave_repo__fill_strings,
   },
   0, get_wave_repo_setup, get_wave_repo_exec, 
 };
+static void
+__enode_get_data_pocket__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve a specifically named data pocket for this project";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_data_pocket = {
   { (BseExportNode*) &__enode_get_wave_repo, BSE_EXPORT_NODE_PROC,
     "BseProject+get-data-pocket", 
     NULL,
     "/Methods/BseProject/General/Get Data Pocket",
-    "Retrieve a specifically named data pocket for this project",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_data_pocket__fill_strings,
   },
   0, get_data_pocket_setup, get_data_pocket_exec, 
 };
+static void
+__enode_create_csynth__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Create a synthsizer network for this project.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_create_csynth = {
   { (BseExportNode*) &__enode_get_data_pocket, BSE_EXPORT_NODE_PROC,
     "BseProject+create-csynth", 
     NULL,
     "/Methods/BseProject/General/Create Csynth",
-    "Create a synthsizer network for this project.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_create_csynth__fill_strings,
   },
   0, create_csynth_setup, create_csynth_exec, 
 };
+static void
+__enode_create_midi_synth__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Create a MIDI synthesizer network for this project.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_create_midi_synth = {
   { (BseExportNode*) &__enode_create_csynth, BSE_EXPORT_NODE_PROC,
     "BseProject+create-midi-synth", 
     NULL,
     "/Methods/BseProject/General/Create Midi Synth",
-    "Create a MIDI synthesizer network for this project.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_create_midi_synth__fill_strings,
   },
   0, create_midi_synth_setup, create_midi_synth_exec, 
 };
+static void
+__enode_remove_snet__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Remove an existing synthesizer network from this project.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_remove_snet = {
   { (BseExportNode*) &__enode_create_midi_synth, BSE_EXPORT_NODE_PROC,
     "BseProject+remove-snet", 
     NULL,
     "/Methods/BseProject/General/Remove Snet",
-    "Remove an existing synthesizer network from this project.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_remove_snet__fill_strings,
   },
   0, remove_snet_setup, remove_snet_exec, 
 };
+static void
+__enode_list_uname_paths__fill_strings (BseExportStrings *es)
+{
+  es->blurb = ("List uname paths for all items of a specified type within this project. "
+           "By their uname paths, items are uniquely identifyable within a project.");
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_list_uname_paths = {
   { (BseExportNode*) &__enode_remove_snet, BSE_EXPORT_NODE_PROC,
     "BseProject+list-uname-paths", 
     NULL,
     "/Methods/BseProject/General/List Uname Paths",
-    ("List uname paths for all items of a specified type within this project. "
-           "By their uname paths, items are uniquely identifyable within a project."),
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_list_uname_paths__fill_strings,
   },
   0, list_uname_paths_setup, list_uname_paths_exec, 
 };
+static void
+__enode_find_item__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Find an item within a project, given its uname path.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_find_item = {
   { (BseExportNode*) &__enode_list_uname_paths, BSE_EXPORT_NODE_PROC,
     "BseProject+find-item", 
     NULL,
     "/Methods/BseProject/General/Find Item",
-    "Find an item within a project, given its uname path.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_find_item__fill_strings,
   },
   0, find_item_setup, find_item_exec, 
 };
+static void
+__enode_match_items_by_uname__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve all items of a specific type within a project with matching uname";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_match_items_by_uname = {
   { (BseExportNode*) &__enode_find_item, BSE_EXPORT_NODE_PROC,
     "BseProject+match-items-by-uname", 
     NULL,
     "/Methods/BseProject/General/Match Items By Uname",
-    "Retrieve all items of a specific type within a project with matching uname",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_match_items_by_uname__fill_strings,
   },
   0, match_items_by_uname_setup, match_items_by_uname_exec, 
 };
+static void
+__enode_get_supers__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve all supers of this project.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_supers = {
   { (BseExportNode*) &__enode_match_items_by_uname, BSE_EXPORT_NODE_PROC,
     "BseProject+get-supers", 
     NULL,
     "/Methods/BseProject/General/Get Supers",
-    "Retrieve all supers of this project.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_supers__fill_strings,
   },
   0, get_supers_setup, get_supers_exec, 
 };
+static void
+__enode_can_play__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether project playback would makes sense.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_can_play = {
   { (BseExportNode*) &__enode_get_supers, BSE_EXPORT_NODE_PROC,
     "BseProject+can-play", 
     NULL,
     "/Methods/BseProject/General/Can Play",
-    "Check whether project playback would makes sense.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_can_play__fill_strings,
   },
   0, can_play_setup, can_play_exec, 
 };
+static void
+__enode_get_state__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the current project state.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_get_state = {
   { (BseExportNode*) &__enode_can_play, BSE_EXPORT_NODE_PROC,
     "BseProject+get-state", 
     NULL,
     "/Methods/BseProject/General/Get State",
-    "Retrieve the current project state.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_get_state__fill_strings,
   },
   0, get_state_setup, get_state_exec, 
 };
+static void
+__enode_activate__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Activate a project, precondition to start playback.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_activate = {
   { (BseExportNode*) &__enode_get_state, BSE_EXPORT_NODE_PROC,
     "BseProject+activate", 
     NULL,
     "/Methods/BseProject/General/Activate",
-    "Activate a project, precondition to start playback.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_activate__fill_strings,
   },
   0, activate_setup, activate_exec, 
 };
+static void
+__enode_start_playback__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Start playback in an activated project.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_start_playback = {
   { (BseExportNode*) &__enode_activate, BSE_EXPORT_NODE_PROC,
     "BseProject+start-playback", 
     NULL,
     "/Methods/BseProject/General/Start Playback",
-    "Start playback in an activated project.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_start_playback__fill_strings,
   },
   0, start_playback_setup, start_playback_exec, 
 };
+static void
+__enode_play__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Activate a project and start project playback (and already playing project is first halted).";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_play = {
   { (BseExportNode*) &__enode_start_playback, BSE_EXPORT_NODE_PROC,
     "BseProject+play", 
     NULL,
     "/Methods/BseProject/General/Play",
-    "Activate a project and start project playback (and already playing project is first halted).",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_play__fill_strings,
   },
   0, play_setup, play_exec, 
 };
+static void
+__enode_deactivate__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Deactivate the project, automatically stop playback.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_deactivate = {
   { (BseExportNode*) &__enode_play, BSE_EXPORT_NODE_PROC,
     "BseProject+deactivate", 
     NULL,
     "/Methods/BseProject/General/Deactivate",
-    "Deactivate the project, automatically stop playback.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_deactivate__fill_strings,
   },
   0, deactivate_setup, deactivate_exec, 
 };
+static void
+__enode_stop_playback__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Stop project playback.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_stop_playback = {
   { (BseExportNode*) &__enode_deactivate, BSE_EXPORT_NODE_PROC,
     "BseProject+stop-playback", 
     NULL,
     "/Methods/BseProject/General/Stop Playback",
-    "Stop project playback.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_stop_playback__fill_strings,
   },
   0, stop_playback_setup, stop_playback_exec, 
 };
+static void
+__enode_stop__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Stop project playback and deactivate project.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_stop = {
   { (BseExportNode*) &__enode_stop_playback, BSE_EXPORT_NODE_PROC,
     "BseProject+stop", 
     NULL,
     "/Methods/BseProject/General/Stop",
-    "Stop project playback and deactivate project.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_stop__fill_strings,
   },
   0, stop_setup, stop_exec, 
 };
+static void
+__enode_auto_deactivate__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Automatically deactivate a project once playback stopped.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_auto_deactivate = {
   { (BseExportNode*) &__enode_stop, BSE_EXPORT_NODE_PROC,
     "BseProject+auto-deactivate", 
     NULL,
     "/Methods/BseProject/General/Auto Deactivate",
-    "Automatically deactivate a project once playback stopped.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_auto_deactivate__fill_strings,
   },
   0, auto_deactivate_setup, auto_deactivate_exec, 
 };
+static void
+__enode_undo_depth__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether a project can perform undo steps";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_undo_depth = {
   { (BseExportNode*) &__enode_auto_deactivate, BSE_EXPORT_NODE_PROC,
     "BseProject+undo-depth", 
     NULL,
     "/Methods/BseProject/General/Undo Depth",
-    "Check whether a project can perform undo steps",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_undo_depth__fill_strings,
   },
   0, undo_depth_setup, undo_depth_exec, 
 };
+static void
+__enode_undo__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Undo a previous operation in a project";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_undo = {
   { (BseExportNode*) &__enode_undo_depth, BSE_EXPORT_NODE_PROC,
     "BseProject+undo", 
     NULL,
     "/Methods/BseProject/General/Undo",
-    "Undo a previous operation in a project",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_undo__fill_strings,
   },
   0, undo_setup, undo_exec, 
 };
+static void
+__enode_redo_depth__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether a project can perform redo steps";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_redo_depth = {
   { (BseExportNode*) &__enode_undo, BSE_EXPORT_NODE_PROC,
     "BseProject+redo-depth", 
     NULL,
     "/Methods/BseProject/General/Redo Depth",
-    "Check whether a project can perform redo steps",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_redo_depth__fill_strings,
   },
   0, redo_depth_setup, redo_depth_exec, 
 };
+static void
+__enode_redo__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Redo a previously undone operaiton in a project";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_redo = {
   { (BseExportNode*) &__enode_redo_depth, BSE_EXPORT_NODE_PROC,
     "BseProject+redo", 
     NULL,
     "/Methods/BseProject/General/Redo",
-    "Redo a previously undone operaiton in a project",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_redo__fill_strings,
   },
   0, redo_setup, redo_exec, 
 };
+static void
+__enode_clear_undo__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Delete all recorded undo or redo steps.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_clear_undo = {
   { (BseExportNode*) &__enode_redo, BSE_EXPORT_NODE_PROC,
     "BseProject+clear-undo", 
     NULL,
     "/Methods/BseProject/General/Clear Undo",
-    "Delete all recorded undo or redo steps.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_clear_undo__fill_strings,
   },
   0, clear_undo_setup, clear_undo_exec, 
 };
