@@ -54,6 +54,8 @@ struct _BseProject
   guint		      deactivate_timer;
   gint64	      deactivate_usecs;
   guint64	      deactivate_min_tick;
+
+  BseMidiReceiver    *midi_receiver;
 };
 struct _BseProjectClass
 {
@@ -81,6 +83,7 @@ BseItem*	bse_project_item_from_upath	(BseProject	*project,
 BseErrorType	bse_project_restore		(BseProject	*project,
 						 BseStorage	*storage);
 BseErrorType	bse_project_store_bse		(BseProject	*project,
+						 BseSuper       *super,
 						 const gchar	*bse_file,
 						 gboolean        self_contained);
 BseObject*	bse_project_upath_resolver	(gpointer        project /* func_data */,
