@@ -207,47 +207,71 @@ remove_source_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_supports_user_synths__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether users may edit synthesis modules of this network";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_supports_user_synths = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "BseSNet+supports-user-synths", 
     NULL,
     "/Methods/BseSNet/General/Supports User Synths",
-    "Check whether users may edit synthesis modules of this network",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_supports_user_synths__fill_strings,
   },
   0, supports_user_synths_setup, supports_user_synths_exec, 
 };
+static void
+__enode_can_create_source__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether inserting a new module into a synthesis network is possible";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_can_create_source = {
   { (BseExportNode*) &__enode_supports_user_synths, BSE_EXPORT_NODE_PROC,
     "BseSNet+can-create-source", 
     NULL,
     "/Methods/BseSNet/General/Can Create Source",
-    "Check whether inserting a new module into a synthesis network is possible",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_can_create_source__fill_strings,
   },
   0, can_create_source_setup, can_create_source_exec, 
 };
+static void
+__enode_create_source__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Insert a new module into a synthesis network";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_create_source = {
   { (BseExportNode*) &__enode_can_create_source, BSE_EXPORT_NODE_PROC,
     "BseSNet+create-source", 
     NULL,
     "/Methods/BseSNet/General/Create Source",
-    "Insert a new module into a synthesis network",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_create_source__fill_strings,
   },
   0, create_source_setup, create_source_exec, 
 };
+static void
+__enode_remove_source__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Remove an existing module from its synthesis network";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_remove_source = {
   { (BseExportNode*) &__enode_create_source, BSE_EXPORT_NODE_PROC,
     "BseSNet+remove-source", 
     NULL,
     "/Methods/BseSNet/General/Remove Source",
-    "Remove an existing module from its synthesis network",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_remove_source__fill_strings,
   },
   0, remove_source_setup, remove_source_exec, 
 };
