@@ -7,6 +7,7 @@
 #include <bse/bseplugin.h>
 #include <bse/bseprocedure.h>
 #include <bse/bsesong.h>
+#include <bse/bsesongbus.h>
 #include <bse/bsepart.h>
 #include <bse/bsetrack.h>
 #include "bsemidireceiver.h"
@@ -15,47 +16,145 @@
 #include "gslcommon.h"
 #include "gslengine.h"
 
-#line 32 "bsesong.proc"
+#line 33 "bsesong.proc"
 
 
-/* --- create-part --- */
+/* --- create-bus --- */
 static void
-create_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 34 "bsesong.proc"
+create_bus_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 35 "bsesong.proc"
  {
-#line 36 "bsesong.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
+#line 37 "bsesong.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("song", NULL, NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
-  *(out_pspecs++)   = bse_param_spec_object ("part", "Part", NULL,
-				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
-#line 40 "bsesong.proc"
+  *(out_pspecs++)   = bse_param_spec_object ("bus", NULL, NULL,
+				 BSE_TYPE_SONG_BUS, SFI_PARAM_STANDARD);
+#line 41 "bsesong.proc"
 }  }
 static BseErrorType
-#line 40 "bsesong.proc"
-create_part_exec (BseProcedureClass *proc,
+#line 41 "bsesong.proc"
+create_bus_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 43 "bsesong.proc"
-{
 #line 44 "bsesong.proc"
+{
+#line 45 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseUndoStack *ustack;
   BseItem *child;
 
-#line 49 "bsesong.proc"
+#line 50 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 53 "bsesong.proc"
+#line 54 "bsesong.proc"
+  
+  ustack = bse_item_undo_open (self, "create-bus");
+  child = bse_container_new_child (BSE_CONTAINER (self), BSE_TYPE_SONG_BUS, NULL);
+  bse_item_push_undo_proc (self, "remove-bus", child);
+  bse_item_undo_close (ustack);
+  
+#line 60 "bsesong.proc"
+  
+  bse_value_set_object (out_values++, child);
+  
+  return BSE_ERROR_NONE;
+}
+
+/* --- remove-bus --- */
+static void
+remove_bus_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 66 "bsesong.proc"
+ {
+#line 68 "bsesong.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("song", NULL, NULL,
+				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = bse_param_spec_object ("bus", NULL, NULL,
+				 BSE_TYPE_SONG_BUS, SFI_PARAM_STANDARD);
+#line 72 "bsesong.proc"
+}  }
+static BseErrorType
+#line 72 "bsesong.proc"
+remove_bus_exec (BseProcedureClass *proc,
+        const GValue      *in_values,
+        GValue            *out_values)
+#line 75 "bsesong.proc"
+{
+#line 76 "bsesong.proc"
+  
+  BseSong *self = bse_value_get_object (in_values++);
+  BseItem *child = bse_value_get_object (in_values++);
+  BseErrorType error = BSE_ERROR_NONE;
+  
+#line 81 "bsesong.proc"
+  
+  if (!BSE_IS_SONG (self) || !BSE_IS_SONG_BUS (child) || BSE_ITEM (child)->parent != BSE_ITEM (self))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+  
+#line 85 "bsesong.proc"
+  
+  if (BSE_SOURCE_PREPARED (self))
+    error = BSE_ERROR_SOURCE_BUSY;
+  else
+    {
+      BseUndoStack *ustack = bse_item_undo_open (self, "remove-child %s", bse_object_debug_name (child));
+#line 91 "bsesong.proc"
+      
+      bse_container_uncross_undoable (BSE_CONTAINER (self), child);
+#line 93 "bsesong.proc"
+      
+      bse_item_push_redo_proc (self, "remove-bus", child);
+#line 95 "bsesong.proc"
+      
+      bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
+#line 97 "bsesong.proc"
+      
+      bse_item_undo_close (ustack);
+    }
+
+  return error;
+}
+
+/* --- create-part --- */
+static void
+create_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 104 "bsesong.proc"
+ {
+#line 106 "bsesong.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
+				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_object ("part", "Part", NULL,
+				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
+#line 110 "bsesong.proc"
+}  }
+static BseErrorType
+#line 110 "bsesong.proc"
+create_part_exec (BseProcedureClass *proc,
+        const GValue      *in_values,
+        GValue            *out_values)
+#line 113 "bsesong.proc"
+{
+#line 114 "bsesong.proc"
+  
+  BseSong *self = bse_value_get_object (in_values++);
+  BseUndoStack *ustack;
+  BseItem *child;
+
+#line 119 "bsesong.proc"
+  
+  if (!BSE_IS_SONG (self))
+    return BSE_ERROR_PROC_PARAM_INVAL;
+  
+#line 123 "bsesong.proc"
   
   ustack = bse_item_undo_open (self, "create-part");
   child = bse_container_new_child (BSE_CONTAINER (self), BSE_TYPE_PART, NULL);
   bse_item_push_undo_proc (self, "remove-part", child);
   bse_item_undo_close (ustack);
   
-#line 59 "bsesong.proc"
+#line 129 "bsesong.proc"
   
   bse_value_set_object (out_values++, child);
   
@@ -65,50 +164,50 @@ create_part_exec (BseProcedureClass *proc,
 /* --- remove-part --- */
 static void
 remove_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 65 "bsesong.proc"
+#line 135 "bsesong.proc"
  {
-#line 67 "bsesong.proc"
+#line 137 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
-#line 71 "bsesong.proc"
+#line 141 "bsesong.proc"
 }  }
 static BseErrorType
-#line 71 "bsesong.proc"
+#line 141 "bsesong.proc"
 remove_part_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 74 "bsesong.proc"
+#line 144 "bsesong.proc"
 {
-#line 75 "bsesong.proc"
+#line 145 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseItem *child = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   
-#line 80 "bsesong.proc"
+#line 150 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_PART (child) || BSE_ITEM (child)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 84 "bsesong.proc"
+#line 154 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
   else
     {
       BseUndoStack *ustack = bse_item_undo_open (self, "remove-child %s", bse_object_debug_name (child));
-#line 90 "bsesong.proc"
+#line 160 "bsesong.proc"
       
       bse_container_uncross_undoable (BSE_CONTAINER (self), child);
-#line 92 "bsesong.proc"
+#line 162 "bsesong.proc"
       
       bse_item_push_redo_proc (self, "remove-part", child);
-#line 94 "bsesong.proc"
+#line 164 "bsesong.proc"
       
       bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
-#line 96 "bsesong.proc"
+#line 166 "bsesong.proc"
       
       bse_item_undo_close (ustack);
     }
@@ -119,34 +218,34 @@ remove_part_exec (BseProcedureClass *proc,
 /* --- create-track --- */
 static void
 create_track_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 103 "bsesong.proc"
+#line 173 "bsesong.proc"
  {
-#line 105 "bsesong.proc"
+#line 175 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("track", "Track", NULL,
 				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
-#line 109 "bsesong.proc"
+#line 179 "bsesong.proc"
 }  }
 static BseErrorType
-#line 109 "bsesong.proc"
+#line 179 "bsesong.proc"
 create_track_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 112 "bsesong.proc"
+#line 182 "bsesong.proc"
 {
-#line 113 "bsesong.proc"
+#line 183 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   BseItem *child = NULL;
 
-#line 118 "bsesong.proc"
+#line 188 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 122 "bsesong.proc"
+#line 192 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
@@ -158,7 +257,7 @@ create_track_exec (BseProcedureClass *proc,
       bse_item_undo_close (ustack);
     }
 
-#line 133 "bsesong.proc"
+#line 203 "bsesong.proc"
   
   bse_value_set_object (out_values++, child);
   
@@ -168,51 +267,51 @@ create_track_exec (BseProcedureClass *proc,
 /* --- remove-track --- */
 static void
 remove_track_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 139 "bsesong.proc"
+#line 209 "bsesong.proc"
  {
-#line 141 "bsesong.proc"
+#line 211 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("track", "Track", NULL,
 				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
-#line 145 "bsesong.proc"
+#line 215 "bsesong.proc"
 }  }
 static BseErrorType
-#line 145 "bsesong.proc"
+#line 215 "bsesong.proc"
 remove_track_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 148 "bsesong.proc"
+#line 218 "bsesong.proc"
 {
-#line 149 "bsesong.proc"
+#line 219 "bsesong.proc"
   
   BseSong *self  = bse_value_get_object (in_values++);
   BseItem *child = bse_value_get_object (in_values++);
   BseErrorType error = BSE_ERROR_NONE;
   
-#line 154 "bsesong.proc"
+#line 224 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_TRACK (child) ||
       BSE_ITEM (child)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 159 "bsesong.proc"
+#line 229 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self))
     error = BSE_ERROR_SOURCE_BUSY;
   else
     {
       BseUndoStack *ustack = bse_item_undo_open (self, "remove-child %s", bse_object_debug_name (child));
-#line 165 "bsesong.proc"
+#line 235 "bsesong.proc"
       
       bse_container_uncross_undoable (BSE_CONTAINER (self), child);
-#line 167 "bsesong.proc"
+#line 237 "bsesong.proc"
       
       bse_item_push_redo_proc (self, "remove-track", child);
-#line 169 "bsesong.proc"
+#line 239 "bsesong.proc"
       
       bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
-#line 171 "bsesong.proc"
+#line 241 "bsesong.proc"
       
       bse_item_undo_close (ustack);
     }
@@ -223,25 +322,25 @@ remove_track_exec (BseProcedureClass *proc,
 /* --- find-track-for-part --- */
 static void
 find_track_for_part_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 178 "bsesong.proc"
+#line 248 "bsesong.proc"
  {
-#line 180 "bsesong.proc"
+#line 250 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("part", "Part", NULL,
 				 BSE_TYPE_PART, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("track", "Track", NULL,
 				 BSE_TYPE_TRACK, SFI_PARAM_STANDARD);
-#line 186 "bsesong.proc"
+#line 256 "bsesong.proc"
 }  }
 static BseErrorType
-#line 186 "bsesong.proc"
+#line 256 "bsesong.proc"
 find_track_for_part_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 189 "bsesong.proc"
+#line 259 "bsesong.proc"
 {
-#line 190 "bsesong.proc"
+#line 260 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   BsePart *part = bse_value_get_object (in_values++);
@@ -249,13 +348,13 @@ find_track_for_part_exec (BseProcedureClass *proc,
   guint tick = 0;
   SfiRing *ring;
 
-#line 197 "bsesong.proc"
+#line 267 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_PART (part) ||
       BSE_ITEM (part)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 202 "bsesong.proc"
+#line 272 "bsesong.proc"
   
   for (ring = self->tracks_SL; ring; ring = sfi_ring_walk (ring, self->tracks_SL))
     {
@@ -271,7 +370,7 @@ find_track_for_part_exec (BseProcedureClass *proc,
   if (!track)
     track = self->tracks_SL ? self->tracks_SL->data : NULL;
 
-#line 217 "bsesong.proc"
+#line 287 "bsesong.proc"
   
   bse_value_set_object (out_values++, track);
   
@@ -281,9 +380,9 @@ find_track_for_part_exec (BseProcedureClass *proc,
 /* --- synthesize-note --- */
 static void
 synthesize_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 223 "bsesong.proc"
+#line 293 "bsesong.proc"
  {
-#line 225 "bsesong.proc"
+#line 295 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL,
 				 BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_object ("track", "Track", NULL,
@@ -296,16 +395,16 @@ synthesize_note_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
   *(in_pspecs++)    = sfi_pspec_real ("velocity", "Velocity", NULL,
 			  1.0, 0, 1.0, 0.01,
 			  SFI_PARAM_STANDARD ":scale");
-#line 237 "bsesong.proc"
+#line 307 "bsesong.proc"
 }  }
 static BseErrorType
-#line 237 "bsesong.proc"
+#line 307 "bsesong.proc"
 synthesize_note_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 240 "bsesong.proc"
+#line 310 "bsesong.proc"
 {
-#line 241 "bsesong.proc"
+#line 311 "bsesong.proc"
   
   BseSong *self      = bse_value_get_object (in_values++);
   BseTrack *track    = bse_value_get_object (in_values++);
@@ -314,13 +413,13 @@ synthesize_note_exec (BseProcedureClass *proc,
   gint     fine_tune = sfi_value_get_int (in_values++);
   gfloat   velocity  = sfi_value_get_real (in_values++);
   
-#line 249 "bsesong.proc"
+#line 319 "bsesong.proc"
   
   if (!BSE_IS_SONG (self) || !BSE_IS_TRACK (track) ||
       BSE_ITEM (track)->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 254 "bsesong.proc"
+#line 324 "bsesong.proc"
   
   if (BSE_SOURCE_PREPARED (self) && self->midi_receiver_SL)
     {
@@ -343,37 +442,37 @@ synthesize_note_exec (BseProcedureClass *proc,
 /* --- get-timing --- */
 static void
 get_timing_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 273 "bsesong.proc"
+#line 343 "bsesong.proc"
  {
-#line 275 "bsesong.proc"
+#line 345 "bsesong.proc"
   *(in_pspecs++)    = bse_param_spec_object ("song", "Song", NULL, BSE_TYPE_SONG, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("tick", "Tick", "Tick to retrieve timing info about", 0, 0, G_MAXINT, 384, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_boxed ("timing", "Timing", "Song Timing", BSE_TYPE_SONG_TIMING, SFI_PARAM_STANDARD);
-#line 278 "bsesong.proc"
+#line 348 "bsesong.proc"
 }  }
 static BseErrorType
-#line 278 "bsesong.proc"
+#line 348 "bsesong.proc"
 get_timing_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 281 "bsesong.proc"
+#line 351 "bsesong.proc"
 {
-#line 282 "bsesong.proc"
+#line 352 "bsesong.proc"
   
   BseSong *self = bse_value_get_object (in_values++);
   SfiInt   tick = sfi_value_get_int (in_values++);
   BseSongTiming timing = { 0, };
 
-#line 287 "bsesong.proc"
+#line 357 "bsesong.proc"
   
   if (!BSE_IS_SONG (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 291 "bsesong.proc"
+#line 361 "bsesong.proc"
   
   bse_song_get_timing (self, tick, &timing);
 
-#line 294 "bsesong.proc"
+#line 364 "bsesong.proc"
   
   bse_value_set_boxed (out_values++, &timing);
   
@@ -381,80 +480,156 @@ get_timing_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
-static BseExportNodeProc __enode_create_part = {
+static void
+__enode_create_bus__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Create a new Bus in a Song";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
+static BseExportNodeProc __enode_create_bus = {
   { NULL, BSE_EXPORT_NODE_PROC,
+    "BseSong+create-bus", 
+    NULL,
+    "/Methods/BseSong/General/Create Bus",
+    NULL,
+    __enode_create_bus__fill_strings,
+  },
+  0, create_bus_setup, create_bus_exec, 
+};
+static void
+__enode_remove_bus__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Delete a Bus from a Song";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
+static BseExportNodeProc __enode_remove_bus = {
+  { (BseExportNode*) &__enode_create_bus, BSE_EXPORT_NODE_PROC,
+    "BseSong+remove-bus", 
+    NULL,
+    "/Methods/BseSong/General/Remove Bus",
+    NULL,
+    __enode_remove_bus__fill_strings,
+  },
+  0, remove_bus_setup, remove_bus_exec, 
+};
+static void
+__enode_create_part__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Create a new Part in a Song";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
+static BseExportNodeProc __enode_create_part = {
+  { (BseExportNode*) &__enode_remove_bus, BSE_EXPORT_NODE_PROC,
     "BseSong+create-part", 
     NULL,
     "/Methods/BseSong/General/Create Part",
-    "Create a new Part in a Song",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_create_part__fill_strings,
   },
   0, create_part_setup, create_part_exec, 
 };
+static void
+__enode_remove_part__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Delete a Part from a Song";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_remove_part = {
   { (BseExportNode*) &__enode_create_part, BSE_EXPORT_NODE_PROC,
     "BseSong+remove-part", 
     NULL,
     "/Methods/BseSong/General/Remove Part",
-    "Delete a Part from a Song",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_remove_part__fill_strings,
   },
   0, remove_part_setup, remove_part_exec, 
 };
+static void
+__enode_create_track__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Create a new Track for a Song";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_create_track = {
   { (BseExportNode*) &__enode_remove_part, BSE_EXPORT_NODE_PROC,
     "BseSong+create-track", 
     NULL,
     "/Methods/BseSong/General/Create Track",
-    "Create a new Track for a Song",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_create_track__fill_strings,
   },
   0, create_track_setup, create_track_exec, 
 };
+static void
+__enode_remove_track__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Delete a Track from a Song";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_remove_track = {
   { (BseExportNode*) &__enode_create_track, BSE_EXPORT_NODE_PROC,
     "BseSong+remove-track", 
     NULL,
     "/Methods/BseSong/General/Remove Track",
-    "Delete a Track from a Song",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_remove_track__fill_strings,
   },
   0, remove_track_setup, remove_track_exec, 
 };
+static void
+__enode_find_track_for_part__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Find a track suitable for playing notes of a given part.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_find_track_for_part = {
   { (BseExportNode*) &__enode_remove_track, BSE_EXPORT_NODE_PROC,
     "BseSong+find-track-for-part", 
     NULL,
     "/Methods/BseSong/General/Find Track For Part",
-    "Find a track suitable for playing notes of a given part.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_find_track_for_part__fill_strings,
   },
   0, find_track_for_part_setup, find_track_for_part_exec, 
 };
+static void
+__enode_synthesize_note__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Synthesize a note on a song of an active project.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_synthesize_note = {
   { (BseExportNode*) &__enode_find_track_for_part, BSE_EXPORT_NODE_PROC,
     "BseSong+synthesize-note", 
     NULL,
     "/Methods/BseSong/General/Synthesize Note",
-    "Synthesize a note on a song of an active project.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_synthesize_note__fill_strings,
   },
   0, synthesize_note_setup, synthesize_note_exec, 
 };
+static void
+__enode_get_timing__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve song timing information at a specific tick.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_get_timing = {
   { (BseExportNode*) &__enode_synthesize_note, BSE_EXPORT_NODE_PROC,
     "BseSong+get-timing", 
     NULL,
     "/Methods/BseSong/General/Get Timing",
-    "Retrieve song timing information at a specific tick.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_get_timing__fill_strings,
   },
   0, get_timing_setup, get_timing_exec, 
 };
