@@ -942,239 +942,365 @@ set_pos_exec (BseProcedureClass *proc,
 
 
 /* --- Export to BSE --- */
+static void
+__enode_set_input_by_id__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Connect a module input to another module's output.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_set_input_by_id = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "BseSource+set-input-by-id", 
     NULL,
     "/Methods/BseSource/General/Set Input By Id",
-    "Connect a module input to another module's output.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_set_input_by_id__fill_strings,
   },
   0, set_input_by_id_setup, set_input_by_id_exec, 
 };
+static void
+__enode_set_input__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Connect a module input to another module's output.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_set_input = {
   { (BseExportNode*) &__enode_set_input_by_id, BSE_EXPORT_NODE_PROC,
     "BseSource+set-input", 
     NULL,
     "/Methods/BseSource/General/Set Input",
-    "Connect a module input to another module's output.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_set_input__fill_strings,
   },
   0, set_input_setup, set_input_exec, 
 };
+static void
+__enode_unset_input_by_id__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Disconnect a module input.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_unset_input_by_id = {
   { (BseExportNode*) &__enode_set_input, BSE_EXPORT_NODE_PROC,
     "BseSource+unset-input-by-id", 
     NULL,
     "/Methods/BseSource/General/Unset Input By Id",
-    "Disconnect a module input.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_unset_input_by_id__fill_strings,
   },
   0, unset_input_by_id_setup, unset_input_by_id_exec, 
 };
+static void
+__enode_unset_input__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Disconnect a module input.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_unset_input = {
   { (BseExportNode*) &__enode_unset_input_by_id, BSE_EXPORT_NODE_PROC,
     "BseSource+unset-input", 
     NULL,
     "/Methods/BseSource/General/Unset Input",
-    "Disconnect a module input.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_unset_input__fill_strings,
   },
   0, unset_input_setup, unset_input_exec, 
 };
+static void
+__enode_clear_inputs__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Disconnect all module inputs.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_clear_inputs = {
   { (BseExportNode*) &__enode_unset_input, BSE_EXPORT_NODE_PROC,
     "BseSource+clear-inputs", 
     NULL,
     "/Methods/BseSource/General/Clear Inputs",
-    "Disconnect all module inputs.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_clear_inputs__fill_strings,
   },
   0, clear_inputs_setup, clear_inputs_exec, 
 };
+static void
+__enode_clear_outputs__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Disconnect all module outputs.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_clear_outputs = {
   { (BseExportNode*) &__enode_clear_inputs, BSE_EXPORT_NODE_PROC,
     "BseSource+clear-outputs", 
     NULL,
     "/Methods/BseSource/General/Clear Outputs",
-    "Disconnect all module outputs.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_clear_outputs__fill_strings,
   },
   0, clear_outputs_setup, clear_outputs_exec, 
 };
+static void
+__enode_has_outputs__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check whether a module has output channel connections.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_has_outputs = {
   { (BseExportNode*) &__enode_clear_outputs, BSE_EXPORT_NODE_PROC,
     "BseSource+has-outputs", 
     NULL,
     "/Methods/BseSource/General/Has Outputs",
-    "Check whether a module has output channel connections.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_has_outputs__fill_strings,
   },
   0, has_outputs_setup, has_outputs_exec, 
 };
+static void
+__enode_n_ichannels__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Get the number of input channels of a module.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_n_ichannels = {
   { (BseExportNode*) &__enode_has_outputs, BSE_EXPORT_NODE_PROC,
     "BseSource+n-ichannels", 
     NULL,
     "/Methods/BseSource/General/N Ichannels",
-    "Get the number of input channels of a module.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_n_ichannels__fill_strings,
   },
   0, n_ichannels_setup, n_ichannels_exec, 
 };
+static void
+__enode_ichannel_label__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Get input channel name.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_ichannel_label = {
   { (BseExportNode*) &__enode_n_ichannels, BSE_EXPORT_NODE_PROC,
     "BseSource+ichannel-label", 
     NULL,
     "/Methods/BseSource/General/Ichannel Label",
-    "Get input channel name.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_ichannel_label__fill_strings,
   },
   0, ichannel_label_setup, ichannel_label_exec, 
 };
+static void
+__enode_ichannel_ident__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Get canonical input channel name.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_ichannel_ident = {
   { (BseExportNode*) &__enode_ichannel_label, BSE_EXPORT_NODE_PROC,
     "BseSource+ichannel-ident", 
     NULL,
     "/Methods/BseSource/General/Ichannel Ident",
-    "Get canonical input channel name.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_ichannel_ident__fill_strings,
   },
   0, ichannel_ident_setup, ichannel_ident_exec, 
 };
+static void
+__enode_ichannel_blurb__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Get input channel description.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_ichannel_blurb = {
   { (BseExportNode*) &__enode_ichannel_ident, BSE_EXPORT_NODE_PROC,
     "BseSource+ichannel-blurb", 
     NULL,
     "/Methods/BseSource/General/Ichannel Blurb",
-    "Get input channel description.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_ichannel_blurb__fill_strings,
   },
   0, ichannel_blurb_setup, ichannel_blurb_exec, 
 };
+static void
+__enode_is_joint_ichannel_by_id__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check if an input channel is a joint (multi-connect) channel.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_is_joint_ichannel_by_id = {
   { (BseExportNode*) &__enode_ichannel_blurb, BSE_EXPORT_NODE_PROC,
     "BseSource+is-joint-ichannel-by-id", 
     NULL,
     "/Methods/BseSource/General/Is Joint Ichannel By Id",
-    "Check if an input channel is a joint (multi-connect) channel.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_is_joint_ichannel_by_id__fill_strings,
   },
   0, is_joint_ichannel_by_id_setup, is_joint_ichannel_by_id_exec, 
 };
+static void
+__enode_is_joint_ichannel__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Check if an input channel is a joint (multi-connect) channel.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_is_joint_ichannel = {
   { (BseExportNode*) &__enode_is_joint_ichannel_by_id, BSE_EXPORT_NODE_PROC,
     "BseSource+is-joint-ichannel", 
     NULL,
     "/Methods/BseSource/General/Is Joint Ichannel",
-    "Check if an input channel is a joint (multi-connect) channel.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_is_joint_ichannel__fill_strings,
   },
   0, is_joint_ichannel_setup, is_joint_ichannel_exec, 
 };
+static void
+__enode_ichannel_get_n_joints__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve the number of inputs connected to an input channel.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_ichannel_get_n_joints = {
   { (BseExportNode*) &__enode_is_joint_ichannel, BSE_EXPORT_NODE_PROC,
     "BseSource+ichannel-get-n-joints", 
     NULL,
     "/Methods/BseSource/General/Ichannel Get N Joints",
-    "Retrieve the number of inputs connected to an input channel.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_ichannel_get_n_joints__fill_strings,
   },
   0, ichannel_get_n_joints_setup, ichannel_get_n_joints_exec, 
 };
+static void
+__enode_ichannel_get_osource__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve output module connected to a specific joint of an input channel";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_ichannel_get_osource = {
   { (BseExportNode*) &__enode_ichannel_get_n_joints, BSE_EXPORT_NODE_PROC,
     "BseSource+ichannel-get-osource", 
     NULL,
     "/Methods/BseSource/General/Ichannel Get Osource",
-    "Retrieve output module connected to a specific joint of an input channel",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_ichannel_get_osource__fill_strings,
   },
   0, ichannel_get_osource_setup, ichannel_get_osource_exec, 
 };
+static void
+__enode_ichannel_get_ochannel__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve output channel of the module connected to a specific joint of an input channel.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_ichannel_get_ochannel = {
   { (BseExportNode*) &__enode_ichannel_get_osource, BSE_EXPORT_NODE_PROC,
     "BseSource+ichannel-get-ochannel", 
     NULL,
     "/Methods/BseSource/General/Ichannel Get Ochannel",
-    "Retrieve output channel of the module connected to a specific joint of an input channel.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_ichannel_get_ochannel__fill_strings,
   },
   0, ichannel_get_ochannel_setup, ichannel_get_ochannel_exec, 
 };
+static void
+__enode_n_ochannels__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Get the number of output channels of a module.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_n_ochannels = {
   { (BseExportNode*) &__enode_ichannel_get_ochannel, BSE_EXPORT_NODE_PROC,
     "BseSource+n-ochannels", 
     NULL,
     "/Methods/BseSource/General/N Ochannels",
-    "Get the number of output channels of a module.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_n_ochannels__fill_strings,
   },
   0, n_ochannels_setup, n_ochannels_exec, 
 };
+static void
+__enode_ochannel_label__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Get output channel name.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_ochannel_label = {
   { (BseExportNode*) &__enode_n_ochannels, BSE_EXPORT_NODE_PROC,
     "BseSource+ochannel-label", 
     NULL,
     "/Methods/BseSource/General/Ochannel Label",
-    "Get output channel name.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_ochannel_label__fill_strings,
   },
   0, ochannel_label_setup, ochannel_label_exec, 
 };
+static void
+__enode_ochannel_ident__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Get canonical output channel name.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_ochannel_ident = {
   { (BseExportNode*) &__enode_ochannel_label, BSE_EXPORT_NODE_PROC,
     "BseSource+ochannel-ident", 
     NULL,
     "/Methods/BseSource/General/Ochannel Ident",
-    "Get canonical output channel name.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_ochannel_ident__fill_strings,
   },
   0, ochannel_ident_setup, ochannel_ident_exec, 
 };
+static void
+__enode_ochannel_blurb__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Get output channel description.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_ochannel_blurb = {
   { (BseExportNode*) &__enode_ochannel_ident, BSE_EXPORT_NODE_PROC,
     "BseSource+ochannel-blurb", 
     NULL,
     "/Methods/BseSource/General/Ochannel Blurb",
-    "Get output channel description.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_ochannel_blurb__fill_strings,
   },
   0, ochannel_blurb_setup, ochannel_blurb_exec, 
 };
+static void
+__enode_set_pos__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Set the x and y position of a module. In contrast to setting the position "
+          "through ordinary object property setters, this function will not update "
+          "the module position if the passed in arguments are sufficiently equal to "
+          "the values already set on the object. As such, it does not record an extra "
+          "undo step for setting properties to values they already have and if necessary "
+          "turns setting of x and y positions into an atomic undo operation.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU Lesser General Public License";
+}
 static BseExportNodeProc __enode_set_pos = {
   { (BseExportNode*) &__enode_ochannel_blurb, BSE_EXPORT_NODE_PROC,
     "BseSource+set-pos", 
     NULL,
     "/Methods/BseSource/General/Set Pos",
-    "Set the x and y position of a module. In contrast to setting the position "
-          "through ordinary object property setters, this function will not update "
-          "the module position if the passed in arguments are sufficiently equal to "
-          "the values already set on the object. As such, it does not record an extra "
-          "undo step for setting properties to values they already have and if necessary "
-          "turns setting of x and y positions into an atomic undo operation.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU Lesser General Public License",
+    NULL,
+    __enode_set_pos__fill_strings,
   },
   0, set_pos_setup, set_pos_exec, 
 };
