@@ -99,11 +99,6 @@ BSE_BUILTIN_TYPE (BseStandardOsc)
     (GInstanceInitFunc) bse_standard_osc_init,
   };
 #include "./icons/osc.c"
-  static const BsePixdata pixdata = {
-    OSC_IMAGE_BYTES_PER_PIXEL | BSE_PIXDATA_1BYTE_RLE,
-    OSC_IMAGE_WIDTH, OSC_IMAGE_HEIGHT,
-    OSC_IMAGE_RLE_PIXEL_DATA,
-  };
   GType type;
   
   type = bse_type_register_static (BSE_TYPE_SOURCE,
@@ -111,9 +106,7 @@ BSE_BUILTIN_TYPE (BseStandardOsc)
 				   _("StandardOsc is the BSE basis oscillator which supports various types "
                                      "of wave forms and modulation inputs."),
 				   &type_info);
-  bse_categories_register_icon (_("/Modules/Audio Sources/Standard Oscillator"),
-				type,
-				&pixdata);
+  bse_categories_register_stock_module (N_("/Audio Sources/Standard Oscillator"), type, osc_pixstream);
   return type;
 }
 
@@ -191,7 +184,7 @@ bse_standard_osc_class_init (BseStandardOscClass *class)
   bse_object_class_add_param (object_class, _("Pulse Modulation"),
 			      PROP_PULSE_MOD_PERC,
 			      sfi_pspec_real ("pulse_mod_perc", _("Pulse Modulation [%]"),
-					      _("Strength of pulse wisth modulation input "
+					      _("Strength of pulse width modulation input "
                                                 "(Pulse has to be selected as wave form for this to take effect)"),
 					      0.0, 0.0, 100.0, 5.0,
 					      SFI_PARAM_STANDARD ":f:dial"));
