@@ -229,58 +229,88 @@ chunk_get_mix_freq_exec (BseProcedureClass *proc,
 }
 
 /* --- Export to BSE --- */
+static void
+__enode_load_wave__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Load sample chunks from a wave file";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_load_wave = {
   { NULL, BSE_EXPORT_NODE_PROC,
     "BseWave+load-wave", 
     NULL,
     "/Methods/BseWave/General/Load Wave",
-    "Load sample chunks from a wave file",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_load_wave__fill_strings,
   },
   0, load_wave_setup, load_wave_exec, 
 };
+static void
+__enode_n_wave_chunks__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Get the number of wave chunks of a wave";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_n_wave_chunks = {
   { (BseExportNode*) &__enode_load_wave, BSE_EXPORT_NODE_PROC,
     "BseWave+n-wave-chunks", 
     NULL,
     "/Methods/BseWave/General/N Wave Chunks",
-    "Get the number of wave chunks of a wave",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_n_wave_chunks__fill_strings,
   },
   0, n_wave_chunks_setup, n_wave_chunks_exec, 
 };
+static void
+__enode_use_editable__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve an editable sample object for a wave chunk.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_use_editable = {
   { (BseExportNode*) &__enode_n_wave_chunks, BSE_EXPORT_NODE_PROC,
     "BseWave+use-editable", 
     NULL,
     "/Methods/BseWave/General/Use Editable",
-    "Retrieve an editable sample object for a wave chunk.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_use_editable__fill_strings,
   },
   0, use_editable_setup, use_editable_exec, 
 };
+static void
+__enode_chunk_get_osc_freq__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve oscillating frequency of a wave chunk.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_chunk_get_osc_freq = {
   { (BseExportNode*) &__enode_use_editable, BSE_EXPORT_NODE_PROC,
     "BseWave+chunk-get-osc-freq", 
     NULL,
     "/Methods/BseWave/General/Chunk Get Osc Freq",
-    "Retrieve oscillating frequency of a wave chunk.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_chunk_get_osc_freq__fill_strings,
   },
   0, chunk_get_osc_freq_setup, chunk_get_osc_freq_exec, 
 };
+static void
+__enode_chunk_get_mix_freq__fill_strings (BseExportStrings *es)
+{
+  es->blurb = "Retrieve mixing frequency of a wave chunk.";
+  es->authors = "Tim Janik <timj@gtk.org>";
+  es->license = "GNU General Public License";
+}
 static BseExportNodeProc __enode_chunk_get_mix_freq = {
   { (BseExportNode*) &__enode_chunk_get_osc_freq, BSE_EXPORT_NODE_PROC,
     "BseWave+chunk-get-mix-freq", 
     NULL,
     "/Methods/BseWave/General/Chunk Get Mix Freq",
-    "Retrieve mixing frequency of a wave chunk.",
-    "Tim Janik <timj@gtk.org>",
-    "GNU General Public License",
+    NULL,
+    __enode_chunk_get_mix_freq__fill_strings,
   },
   0, chunk_get_mix_freq_setup, chunk_get_mix_freq_exec, 
 };
