@@ -135,7 +135,7 @@ gsl_data_cache_open (GslDataCache *dcache)
       if (error)
 	{
 	  /* FIXME: this is pretty fatal, throw out zero blocks now? */
-	  sfi_info ("%s: failed to open \"%s\": %s", G_STRLOC, dcache->dhandle->name, gsl_strerror (error));
+	  sfi_diag ("%s: failed to open \"%s\": %s", G_STRLOC, dcache->dhandle->name, gsl_strerror (error));
 	}
       else
 	{
@@ -335,7 +335,7 @@ data_cache_new_node_L (GslDataCache *dcache,
       result = gsl_data_handle_read (dcache->dhandle, offset, size, data);
       if (result < 0)
 	{
-          sfi_info ("ReadAhead: failed to read from \"%s\"", dcache->dhandle->name);
+          sfi_diag ("ReadAhead: failed to read from \"%s\"", dcache->dhandle->name);
 	  break;
 	}
       else
