@@ -25,7 +25,7 @@
 #include <unistd.h>
 
 
-#define	DEBUG	sfi_debug_keyfunc ("engine")
+#define DEBUG(...)      sfi_debug ("engine", __VA_ARGS__)
 
 /* some systems don't have ERESTART (which is what linux returns for system
  * calls on pipes which are being interrupted). most probably just use EINTR,
@@ -1320,24 +1320,24 @@ gsl_engine_init (gboolean run_threaded)
       if (!err)
 	{
 	  glong d_long = fcntl (master_data.wakeup_pipe[0], F_GETFL, 0);
-	  /* sfi_debug ("master_wpipe-readfd, blocking=%ld", d_long & O_NONBLOCK); */
+	  /* DEBUG ("master_wpipe-readfd, blocking=%ld", d_long & O_NONBLOCK); */
 	  d_long |= O_NONBLOCK;
 	  err = fcntl (master_data.wakeup_pipe[0], F_SETFL, d_long);
 	}
       if (!err)
 	{
 	  glong d_long = fcntl (master_data.wakeup_pipe[1], F_GETFL, 0);
-	  /* sfi_debug ("master_wpipe-writefd, blocking=%ld", d_long & O_NONBLOCK); */
+	  /* DEBUG ("master_wpipe-writefd, blocking=%ld", d_long & O_NONBLOCK); */
 	  d_long |= O_NONBLOCK;
 	  err = fcntl (master_data.wakeup_pipe[1], F_SETFL, d_long);
 	}
       if (err)
 	g_error ("failed to create wakeup pipe: %s", g_strerror (errno));
-      master_thread = sfi_thread_run ("Master", (SfiThreadFunc) _engine_master_thread, &master_data);
+      master_thread = sfi_thread_run ("DSP #1", (SfiThreadFunc) _engine_master_thread, &master_data);
       if (!master_thread)
 	g_error ("failed to create master thread");
       if (0)
-	sfi_thread_run ("Slave", slave, NULL);
+	sfi_thread_run ("DSP #2", slave, NULL);
     }
 }
 
@@ -1408,6 +1408,21 @@ gsl_engine_dispatch (void)
     gsl_engine_garbage_collect ();
 }
 
+SfiThread**
+gsl_engine_get_threads (guint *n_threads)
+{
+  SfiThread **t;
+  if (!master_thread)
+    {
+      *n_threads = 0;
+      return NULL;
+    }
+  *n_threads = 1;
+  t = g_new0 (SfiThread*, 2);
+  t[0] = master_thread;
+  return t;
+}
+
 /**
  * gsl_engine_tick_stamp_from_systime
  * @systime: System time in micro seconds.
