@@ -37,7 +37,7 @@ gfloat*		gsl_engine_const_values		(gfloat		value);
 
 
 /* --- MasterThread --- */
-void		_engine_recycle_const_values	(void);
+void		_engine_recycle_const_values	(gboolean        nuke_all);
 void		_engine_node_collect_jobs	(EngineNode	*node);
 /* master node list */
 void		_engine_mnl_remove		(EngineNode	*node);
