@@ -105,7 +105,7 @@ fill_block (GslWaveChunk *wchunk,
   GslDataCacheNode *dnode;
   WPos wpos;
   
-  wpos.dir = wchunk->n_channels;
+  wpos.dir = 1; // wchunk->n_channels;
   if (backward)
     wpos.dir = -wpos.dir;
   wpos.pos = offset;
@@ -237,11 +237,6 @@ setup_pblocks (GslWaveChunk *wchunk)
     }
   else
     {
-      /*
-	wchunk->enter.first = wchunk->head.last;
-	wchunk->enter.last = wchunk->head.last;
-	wchunk->enter.length = 0;
-      */
       wchunk->enter.first = wchunk->tail.first;
       wchunk->enter.last = wchunk->head.last;
       wchunk->enter.length = 0;
@@ -620,9 +615,9 @@ wave_chunk_setup_loop (GslWaveChunk *wchunk)
 
 GslWaveChunk*
 gsl_wave_chunk_new (GslDataCache   *dcache,
-		    gfloat          osc_freq,
-		    gfloat          mix_freq,
-		    GslWaveLoopType loop_type,
+                    gfloat          mix_freq,
+                    gfloat          osc_freq,
+                    GslWaveLoopType loop_type,
 		    GslLong         loop_first,
 		    GslLong         loop_last,
 		    guint           loop_count)
@@ -775,9 +770,9 @@ _gsl_wave_chunk_copy (GslWaveChunk *wchunk)
   g_return_val_if_fail (wchunk->ref_count > 0, NULL);
   
   return gsl_wave_chunk_new (wchunk->dcache,
-			     wchunk->osc_freq,
-			     wchunk->mix_freq,
-			     wchunk->loop_type,
+                             wchunk->mix_freq,
+                             wchunk->osc_freq,
+                             wchunk->loop_type,
 			     wchunk->loop_first,
 			     wchunk->loop_last,
 			     wchunk->loop_count);
