@@ -8,6 +8,8 @@
 
 #define bse_midi_signal_type_to_choice beast__bse_midi_signal_type_to_choice
 #define bse_midi_signal_type_from_choice beast__bse_midi_signal_type_from_choice
+#define bse_thread_state_to_choice beast__bse_thread_state_to_choice
+#define bse_thread_state_from_choice beast__bse_thread_state_from_choice
 #define bse_biquad_filter_type_to_choice beast__bse_biquad_filter_type_to_choice
 #define bse_biquad_filter_type_from_choice beast__bse_biquad_filter_type_from_choice
 #define bse_biquad_filter_norm_to_choice beast__bse_biquad_filter_norm_to_choice
@@ -76,6 +78,16 @@
 #define bse_sample_file_info_from_rec beast__bse_sample_file_info_from_rec
 #define bse_sample_file_info_to_rec beast__bse_sample_file_info_to_rec
 #define bse_sample_file_info_free beast__bse_sample_file_info_free
+#define bse_thread_info_new beast__bse_thread_info_new
+#define bse_thread_info_copy_shallow beast__bse_thread_info_copy_shallow
+#define bse_thread_info_from_rec beast__bse_thread_info_from_rec
+#define bse_thread_info_to_rec beast__bse_thread_info_to_rec
+#define bse_thread_info_free beast__bse_thread_info_free
+#define bse_thread_totals_new beast__bse_thread_totals_new
+#define bse_thread_totals_copy_shallow beast__bse_thread_totals_copy_shallow
+#define bse_thread_totals_from_rec beast__bse_thread_totals_from_rec
+#define bse_thread_totals_to_rec beast__bse_thread_totals_to_rec
+#define bse_thread_totals_free beast__bse_thread_totals_free
 #define bse_gconfig_new beast__bse_gconfig_new
 #define bse_gconfig_copy_shallow beast__bse_gconfig_copy_shallow
 #define bse_gconfig_from_rec beast__bse_gconfig_from_rec
@@ -149,6 +161,13 @@
 #define bse_track_part_seq_to_seq beast__bse_track_part_seq_to_seq
 #define bse_track_part_seq_resize beast__bse_track_part_seq_resize
 #define bse_track_part_seq_free beast__bse_track_part_seq_free
+#define bse_thread_info_seq_new beast__bse_thread_info_seq_new
+#define bse_thread_info_seq_append beast__bse_thread_info_seq_append
+#define bse_thread_info_seq_copy_shallow beast__bse_thread_info_seq_copy_shallow
+#define bse_thread_info_seq_from_seq beast__bse_thread_info_seq_from_seq
+#define bse_thread_info_seq_to_seq beast__bse_thread_info_seq_to_seq
+#define bse_thread_info_seq_resize beast__bse_thread_info_seq_resize
+#define bse_thread_info_seq_free beast__bse_thread_info_seq_free
 #define bse_sniffer_request_seq_new beast__bse_sniffer_request_seq_new
 #define bse_sniffer_request_seq_append beast__bse_sniffer_request_seq_append
 #define bse_sniffer_request_seq_copy_shallow beast__bse_sniffer_request_seq_copy_shallow
@@ -271,6 +290,7 @@
 #define bse_source_unset_input beast__bse_source_unset_input
 #define bse_source_unset_input_by_id beast__bse_source_unset_input_by_id
 #define bse_track_create_sniffer beast__bse_track_create_sniffer
+#define bse_track_get_last_tick beast__bse_track_get_last_tick
 #define bse_track_get_part beast__bse_track_get_part
 #define bse_track_get_timing beast__bse_track_get_timing
 #define bse_track_insert_part beast__bse_track_insert_part
@@ -347,13 +367,16 @@
 #define bse_snet_supports_user_synths beast__bse_snet_supports_user_synths
 #define bse_wave_repo_load_file beast__bse_wave_repo_load_file
 #define bse_wave_repo_remove_wave beast__bse_wave_repo_remove_wave
+#define bse_song_create_bus beast__bse_song_create_bus
 #define bse_song_create_part beast__bse_song_create_part
 #define bse_song_create_track beast__bse_song_create_track
 #define bse_song_find_track_for_part beast__bse_song_find_track_for_part
 #define bse_song_get_timing beast__bse_song_get_timing
+#define bse_song_remove_bus beast__bse_song_remove_bus
 #define bse_song_remove_part beast__bse_song_remove_part
 #define bse_song_remove_track beast__bse_song_remove_track
 #define bse_song_synthesize_note beast__bse_song_synthesize_note
+#define bse_collect_thread_totals beast__bse_collect_thread_totals
 #define bse_category_from_id beast__bse_category_from_id
 #define bse_categories_match beast__bse_categories_match
 #define bse_categories_match_method beast__bse_categories_match_method
@@ -385,6 +408,8 @@ typedef struct _BseDot BseDot;
 typedef struct _BseTrackPart BseTrackPart;
 typedef struct _BseSongTiming BseSongTiming;
 typedef struct _BseSampleFileInfo BseSampleFileInfo;
+typedef struct _BseThreadInfo BseThreadInfo;
+typedef struct _BseThreadTotals BseThreadTotals;
 typedef struct _BseGConfig BseGConfig;
 typedef struct _BseSnifferRequest BseSnifferRequest;
 typedef struct _BseIntSeq BseIntSeq;
@@ -396,6 +421,7 @@ typedef struct _BsePartControlSeq BsePartControlSeq;
 typedef struct _BseCategorySeq BseCategorySeq;
 typedef struct _BseDotSeq BseDotSeq;
 typedef struct _BseTrackPartSeq BseTrackPartSeq;
+typedef struct _BseThreadInfoSeq BseThreadInfoSeq;
 typedef struct _BseSnifferRequestSeq BseSnifferRequestSeq;
 
 typedef enum {
@@ -573,6 +599,17 @@ typedef enum {
   BSE_MIDI_SIGNAL_CONTROL_127 = 172,
 } BseMidiSignalType;
 
+typedef enum {
+  BSE_THREAD_STATE_UNKNOWN = 1,
+  BSE_THREAD_STATE_RUNNING = 2,
+  BSE_THREAD_STATE_SLEEPING = 3,
+  BSE_THREAD_STATE_DISKWAIT = 4,
+  BSE_THREAD_STATE_TRACED = 5,
+  BSE_THREAD_STATE_PAGING = 6,
+  BSE_THREAD_STATE_ZOMBIE = 7,
+  BSE_THREAD_STATE_DEAD = 8,
+} BseThreadState;
+
 typedef enum {
   BSE_BIQUAD_FILTER_RESONANT_LOWPASS = 1,
   BSE_BIQUAD_FILTER_RESONANT_HIGHPASS = 2,
@@ -591,10 +628,12 @@ typedef enum {
 } BseRegistrationType;
 
 typedef enum {
-  BSE_USER_MSG_INFO = 1,
-  BSE_USER_MSG_QUESTION = 2,
-  BSE_USER_MSG_WARNING = 3,
-  BSE_USER_MSG_ERROR = 4,
+  BSE_USER_MSG_UNSPECIFIED = 1,
+  BSE_USER_MSG_DEBUG = 2,
+  BSE_USER_MSG_DIAG = 3,
+  BSE_USER_MSG_INFO = 4,
+  BSE_USER_MSG_WARNING = 5,
+  BSE_USER_MSG_ERROR = 6,
 } BseUserMsgType;
 
 typedef enum {
@@ -760,6 +799,21 @@ struct _BseSampleFileInfo {
   BseStringSeq* waves;
   SfiInt error;
 };
+struct _BseThreadInfo {
+  gchar* name;
+  BseThreadState state;
+  SfiInt priority;
+  SfiInt processor;
+  SfiInt utime;
+  SfiInt stime;
+  SfiInt cutime;
+  SfiInt cstime;
+};
+struct _BseThreadTotals {
+  BseThreadInfo* main;
+  BseThreadInfo* sequencer;
+  BseThreadInfoSeq* synthesis;
+};
 struct _BseGConfig {
   gchar* sample_path;
   gchar* effect_path;
@@ -818,6 +872,10 @@ struct _BseTrackPartSeq {
   guint n_tparts;
   BseTrackPart** tparts;
 };
+struct _BseThreadInfoSeq {
+  guint n_thread_infos;
+  BseThreadInfo** thread_infos;
+};
 struct _BseSnifferRequestSeq {
   guint n_requests;
   BseSnifferRequest** requests;
@@ -882,6 +940,18 @@ BseSampleFileInfo* bse_sample_file_info_from_rec (SfiRec *sfi_rec);
 SfiRec *bse_sample_file_info_to_rec (BseSampleFileInfo* rec);
 void bse_sample_file_info_free (BseSampleFileInfo* rec);
 
+BseThreadInfo* bse_thread_info_new (void);
+BseThreadInfo* bse_thread_info_copy_shallow (BseThreadInfo* rec);
+BseThreadInfo* bse_thread_info_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_thread_info_to_rec (BseThreadInfo* rec);
+void bse_thread_info_free (BseThreadInfo* rec);
+
+BseThreadTotals* bse_thread_totals_new (void);
+BseThreadTotals* bse_thread_totals_copy_shallow (BseThreadTotals* rec);
+BseThreadTotals* bse_thread_totals_from_rec (SfiRec *sfi_rec);
+SfiRec *bse_thread_totals_to_rec (BseThreadTotals* rec);
+void bse_thread_totals_free (BseThreadTotals* rec);
+
 BseGConfig* bse_gconfig_new (void);
 BseGConfig* bse_gconfig_copy_shallow (BseGConfig* rec);
 BseGConfig* bse_gconfig_from_rec (SfiRec *sfi_rec);
@@ -967,6 +1037,14 @@ SfiSeq *bse_track_part_seq_to_seq (BseTrackPartSeq* seq);
 void bse_track_part_seq_resize (BseTrackPartSeq* seq, guint new_size);
 void bse_track_part_seq_free (BseTrackPartSeq* seq);
 
+BseThreadInfoSeq* bse_thread_info_seq_new (void);
+void bse_thread_info_seq_append (BseThreadInfoSeq* seq, BseThreadInfo* element);
+BseThreadInfoSeq* bse_thread_info_seq_copy_shallow (BseThreadInfoSeq* seq);
+BseThreadInfoSeq* bse_thread_info_seq_from_seq (SfiSeq *sfi_seq);
+SfiSeq *bse_thread_info_seq_to_seq (BseThreadInfoSeq* seq);
+void bse_thread_info_seq_resize (BseThreadInfoSeq* seq, guint new_size);
+void bse_thread_info_seq_free (BseThreadInfoSeq* seq);
+
 BseSnifferRequestSeq* bse_sniffer_request_seq_new (void);
 void bse_sniffer_request_seq_append (BseSnifferRequestSeq* seq, BseSnifferRequest* element);
 BseSnifferRequestSeq* bse_sniffer_request_seq_copy_shallow (BseSnifferRequestSeq* seq);
@@ -977,6 +1055,8 @@ void bse_sniffer_request_seq_free (BseSnifferRequestSeq* seq);
 
 const gchar* bse_midi_signal_type_to_choice (BseMidiSignalType value);
 BseMidiSignalType bse_midi_signal_type_from_choice (const gchar *choice);
+const gchar* bse_thread_state_to_choice (BseThreadState value);
+BseThreadState bse_thread_state_from_choice (const gchar *choice);
 const gchar* bse_biquad_filter_type_to_choice (BseBiquadFilterType value);
 BseBiquadFilterType bse_biquad_filter_type_from_choice (const gchar *choice);
 const gchar* bse_biquad_filter_norm_to_choice (BseBiquadFilterNorm value);
@@ -1111,6 +1191,7 @@ void bse_source_set_pos (SfiProxy bse_source_object, SfiReal x_pos, SfiReal y_po
 BseErrorType bse_source_unset_input (SfiProxy bse_source_object, const gchar* input_channel, SfiProxy omodule, const gchar* output_channel);
 BseErrorType bse_source_unset_input_by_id (SfiProxy bse_source_object, SfiInt input_channel, SfiProxy omodule, SfiInt output_channel);
 SfiProxy bse_track_create_sniffer (SfiProxy bse_track_object);
+SfiInt bse_track_get_last_tick (SfiProxy bse_track_object);
 SfiProxy bse_track_get_part (SfiProxy bse_track_object, SfiInt tick);
 BseSongTiming* bse_track_get_timing (SfiProxy bse_track_object, SfiInt tick);
 SfiInt bse_track_insert_part (SfiProxy bse_track_object, SfiInt tick, SfiProxy part);
@@ -1187,13 +1268,16 @@ BseErrorType bse_snet_remove_source (SfiProxy bse_snet_object, SfiProxy module);
 SfiBool bse_snet_supports_user_synths (SfiProxy bse_snet_object);
 BseErrorType bse_wave_repo_load_file (SfiProxy bse_wave_repo_object, const gchar* file_name);
 void bse_wave_repo_remove_wave (SfiProxy bse_wave_repo_object, SfiProxy wave);
+SfiProxy bse_song_create_bus (SfiProxy bse_song_object);
 SfiProxy bse_song_create_part (SfiProxy bse_song_object);
 SfiProxy bse_song_create_track (SfiProxy bse_song_object);
 SfiProxy bse_song_find_track_for_part (SfiProxy bse_song_object, SfiProxy part);
 BseSongTiming* bse_song_get_timing (SfiProxy bse_song_object, SfiInt tick);
+void bse_song_remove_bus (SfiProxy bse_song_object, SfiProxy bus);
 void bse_song_remove_part (SfiProxy bse_song_object, SfiProxy part);
 void bse_song_remove_track (SfiProxy bse_song_object, SfiProxy track);
 void bse_song_synthesize_note (SfiProxy bse_song_object, SfiProxy track, SfiInt duration, SfiInt note, SfiInt fine_tune, SfiReal velocity);
+BseThreadTotals* bse_collect_thread_totals (void);
 BseCategory* bse_category_from_id (SfiInt category_id);
 BseCategorySeq* bse_categories_match (const gchar* pattern);
 BseCategorySeq* bse_categories_match_method (const gchar* pattern, const gchar* type);
@@ -1249,6 +1333,7 @@ void bse_sniffer_request_combined (BseSnifferRequestSeq* srs);
 #define BSE_IS_INSTRUMENT_OUTPUT(proxy) bse_proxy_is_a ((proxy), "BseInstrumentOutput")
 #define BSE_IS_PROJECT(proxy) bse_proxy_is_a ((proxy), "BseProject")
 #define BSE_IS_SERVER(proxy) bse_proxy_is_a ((proxy), "BseServer")
+#define BSE_IS_SONG_BUS(proxy) bse_proxy_is_a ((proxy), "BseSongBus")
 #define BSE_IS_SUPER(proxy) bse_proxy_is_a ((proxy), "BseSuper")
 #define BSE_IS_AMPLIFIER(proxy) bse_proxy_is_a ((proxy), "BseAmplifier")
 #define BSE_IS_SNET(proxy) bse_proxy_is_a ((proxy), "BseSNet")
