@@ -56,22 +56,18 @@ static void	 bse_mixer_update_modules	(BseMixer	*self,
 						 GslTrans       *trans);
 
 
+/* --- Export to BSE --- */
+#include "./icons/mixer.c"
+BSE_REGISTER_OBJECT (BseMixer, BseSource, "/Modules/Routing/Mixer",
+                     "The Mixer module sums up incomming signals, and allowes for fine "
+                     "adjusted weighting (volume setting) of the input sources",
+                     mixer_icon,
+                     bse_mixer_class_init, NULL, bse_mixer_init);
+BSE_DEFINE_EXPORTS (BSE_PLUGIN_NAME);
+
+
 /* --- variables --- */
-static GType		 type_id_mixer = 0;
 static gpointer		 parent_class = NULL;
-static const GTypeInfo type_info_mixer = {
-  sizeof (BseMixerClass),
-  
-  (GBaseInitFunc) NULL,
-  (GBaseFinalizeFunc) NULL,
-  (GClassInitFunc) bse_mixer_class_init,
-  (GClassFinalizeFunc) NULL,
-  NULL /* class_data */,
-  
-  sizeof (BseMixer),
-  0 /* n_preallocs */,
-  (GInstanceInitFunc) bse_mixer_init,
-};
 
 
 /* --- functions --- */
@@ -96,65 +92,67 @@ bse_mixer_class_init (BseMixerClass *class)
 			      sfi_pspec_real ("master_volume_f", "Master [float]", NULL,
 					      bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB),
 					      0, bse_dB_to_factor (BSE_MAX_VOLUME_dB), 0.1,
-					      SFI_PARAM_STORAGE SFI_PARAM_FLOAT));
+					      SFI_PARAM_STORAGE ":f"));
   bse_object_class_add_param (object_class, "Adjustments",
 			      PROP_MVOLUME_dB,
 			      sfi_pspec_real ("master_volume_dB", "Master [dB]", NULL,
 					      BSE_DFL_MASTER_VOLUME_dB,
 					      BSE_MIN_VOLUME_dB, BSE_MAX_VOLUME_dB,
 					      BSE_GCONFIG (step_volume_dB),
-					      SFI_PARAM_GUI SFI_PARAM_HINT_DIAL));
+					      SFI_PARAM_GUI ":dial"));
   bse_object_class_add_param (object_class, "Adjustments",
 			      PROP_MVOLUME_PERC,
 			      sfi_pspec_int ("master_volume_perc", "Master [%]", NULL,
 					     bse_dB_to_factor (BSE_DFL_MASTER_VOLUME_dB) * 100,
 					     0, bse_dB_to_factor (BSE_MAX_VOLUME_dB) * 100, 1,
-					     SFI_PARAM_GUI SFI_PARAM_HINT_DIAL));
-  ochannel = bse_source_class_add_ochannel (source_class, "Audio Out", "Sole Output");
+					     SFI_PARAM_GUI ":dial"));
+  ochannel = bse_source_class_add_ochannel (source_class, "audio-out", _("Audio Out"), _("Sole Output"));
   g_assert (ochannel == BSE_MIXER_OCHANNEL_MONO);
   for (i = 1; i <= BSE_MIXER_N_INPUTS; i++)
     {
-      gchar *group, *string, *name;
+      gchar *group, *ident, *label, *blurb;
       
-      group = g_strdup_printf ("Channel%u", i);
-      string = g_strdup_printf ("volume_f%u", i);
-      name = g_strdup_printf ("Channel%u [float]", i);
+      group = g_strdup_printf (_("Channel%u"), i);
+      ident = g_strdup_printf ("volume_f%u", i);
+      label = g_strdup_printf (_("Channel%u [float]"), i);
       bse_object_class_add_param (object_class, group,
 				  PROP_NTH_VOLUME_f + (i - 1) * 3,
-				  sfi_pspec_real (string, name, NULL,
+				  sfi_pspec_real (ident, label, NULL,
 						  bse_dB_to_factor (BSE_DFL_MIXER_VOLUME_dB),
 						  0, bse_dB_to_factor (BSE_MAX_VOLUME_dB), 0.1,
 						  SFI_PARAM_STORAGE));
-      g_free (string);
-      g_free (name);
-      string = g_strdup_printf ("volume_dB%u", i);
-      name = g_strdup_printf ("Channel%u [dB]", i);
+      g_free (ident);
+      g_free (label);
+      ident = g_strdup_printf ("volume_dB%u", i);
+      label = g_strdup_printf (_("Channel%u [dB]"), i);
       bse_object_class_add_param (object_class, group,
 				  PROP_NTH_VOLUME_dB + (i - 1) * 3,
-				  sfi_pspec_real (string, name, NULL,
+				  sfi_pspec_real (ident, label, NULL,
 						  BSE_DFL_MIXER_VOLUME_dB,
 						  BSE_MIN_VOLUME_dB, BSE_MAX_VOLUME_dB,
 						  BSE_GCONFIG (step_volume_dB),
-						  SFI_PARAM_GUI SFI_PARAM_HINT_DIAL));
-      g_free (string);
-      g_free (name);
-      string = g_strdup_printf ("volume_perc%u", i);
-      name = g_strdup_printf ("Channel%u [%%]", i);
+						  SFI_PARAM_GUI ":dial"));
+      g_free (ident);
+      g_free (label);
+      ident = g_strdup_printf ("volume_perc%u", i);
+      label = g_strdup_printf (_("Channel%u [%%]"), i);
       bse_object_class_add_param (object_class, group,
 				  PROP_NTH_VOLUME_PERC + (i - 1) * 3,
-				  sfi_pspec_int (string, name, NULL,
+				  sfi_pspec_int (ident, label, NULL,
 						 bse_dB_to_factor (BSE_DFL_MIXER_VOLUME_dB) * 100,
 						 0, bse_dB_to_factor (BSE_MAX_VOLUME_dB) * 100, 1,
-						 SFI_PARAM_GUI SFI_PARAM_HINT_DIAL));
+						 SFI_PARAM_GUI ":dial"));
       g_free (group);
-      g_free (string);
-      g_free (name);
-      name = g_strdup_printf ("Audio In%u", i);
-      string = g_strdup_printf ("Input Channel %u", i);
-      ichannel = bse_source_class_add_ichannel (source_class, name, string);
+      g_free (ident);
+      g_free (label);
+      ident = g_strdup_printf ("audio-in%u", i);
+      label = g_strdup_printf (_("Audio In%u"), i);
+      blurb = g_strdup_printf (_("Input Channel %u"), i);
+      ichannel = bse_source_class_add_ichannel (source_class, ident, label, blurb);
       g_assert (ichannel == i - 1);
-      g_free (string);
-      g_free (name);
+      g_free (blurb);
+      g_free (label);
+      g_free (ident);
     }
 }
 
@@ -377,20 +375,3 @@ bse_mixer_context_create (BseSource *source,
   /* update module data */
   bse_mixer_update_modules (BSE_MIXER (source), trans);
 }
-
-
-/* --- Export to BSE --- */
-#include "./icons/ampmix.c"
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_OBJECTS = {
-  { &type_id_mixer, "BseMixer", "BseSource",
-    "The Mixer module sums up incomming signals, and allowes for fine adjusted weighting (volume setting) of the input sources",
-    &type_info_mixer,
-    "/Modules/Routing/Mixer",
-    { AMP_MIX_IMAGE_BYTES_PER_PIXEL | BSE_PIXDATA_1BYTE_RLE,
-      AMP_MIX_IMAGE_WIDTH, AMP_MIX_IMAGE_HEIGHT,
-      AMP_MIX_IMAGE_RLE_PIXEL_DATA, },
-  },
-  { NULL, },
-};
-BSE_EXPORTS_END;
