@@ -1,5 +1,5 @@
 /* BseNoise - BSE Noise generator
- * Copyright (C) 1999 Tim Janik
+ * Copyright (C) 1999,2000-2001 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Library General Public License as
@@ -31,16 +31,13 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-
-
-
 /* --- object type macros --- */
-#define BSE_TYPE_NOISE              (type_id_noise)
-#define BSE_NOISE(object)           (BSE_CHECK_STRUCT_CAST ((object), BSE_TYPE_NOISE, BseNoise))
-#define BSE_NOISE_CLASS(class)      (BSE_CHECK_CLASS_CAST ((class), BSE_TYPE_NOISE, BseNoiseClass))
-#define BSE_IS_NOISE(object)        (BSE_CHECK_STRUCT_TYPE ((object), BSE_TYPE_NOISE))
-#define BSE_IS_NOISE_CLASS(class)   (BSE_CHECK_CLASS_TYPE ((class), BSE_TYPE_NOISE))
-#define BSE_NOISE_GET_CLASS(object) ((BseNoiseClass*) (((BseObject*) (object))->bse_struct.bse_class))
+#define BSE_TYPE_NOISE              (BSE_EXPORT_TYPE_ID (BseNoise))
+#define BSE_NOISE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), BSE_TYPE_NOISE, BseNoise))
+#define BSE_NOISE_CLASS(class)      (G_TYPE_CHECK_CLASS_CAST ((class), BSE_TYPE_NOISE, BseNoiseClass))
+#define BSE_IS_NOISE(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), BSE_TYPE_NOISE))
+#define BSE_IS_NOISE_CLASS(class)   (G_TYPE_CHECK_CLASS_TYPE ((class), BSE_TYPE_NOISE))
+#define BSE_NOISE_GET_CLASS(object) (G_TYPE_INSTANCE_GET_CLASS ((object), BSE_TYPE_NOISE, BseNoiseClass))
 
 
 /* --- BseNoise source --- */
@@ -48,9 +45,9 @@ typedef struct _BseNoise      BseNoise;
 typedef struct _BseNoiseClass BseNoiseClass;
 struct _BseNoise
 {
-  BseSource       parent_object;
+  BseSource  parent_object;
 
-  BseSampleValue *static_noise;
+  gfloat    *static_noise;
 };
 struct _BseNoiseClass
 {
@@ -61,8 +58,7 @@ struct _BseNoiseClass
 /* --- channels --- */
 enum
 {
-  BSE_NOISE_OCHANNEL_NONE,
-  BSE_NOISE_OCHANNEL_MONO
+  BSE_NOISE_OCHANNEL_NOISE
 };
 
 
