@@ -896,11 +896,72 @@ g_source_simple (gint            priority,
   return source;
 }
 
+/* --- predicate idle --- */
+typedef struct {
+  GSource     source;
+  GSourceFunc predicate;
+} PredicateIdle;
 
+static gboolean
+predicate_idle_prepare (GSource *source,
+                        gint    *timeout)
+{
+  PredicateIdle *p = (PredicateIdle*) source;
+  if (p->predicate)
+    return p->predicate (source->callback_data);
+  else
+    return FALSE;
+}
+
+static gboolean
+predicate_idle_check (GSource *source)
+{
+  PredicateIdle *p = (PredicateIdle*) source;
+  if (p->predicate)
+    return p->predicate (source->callback_data);
+  else
+    return FALSE;
+}
+
+static gboolean
+predicate_idle_dispatch (GSource    *source,
+                         GSourceFunc callback,
+                         gpointer    user_data)
+{
+  if (callback)
+    return callback (user_data);
+  else
+    return FALSE;
+}
+
+guint
+g_predicate_idle_add_full (gint            priority,
+                           GSourceFunc     predicate,
+                           GSourceFunc     function,
+                           gpointer        data,
+                           GDestroyNotify  notify)
+{
+  static GSourceFuncs predicate_idle_funcs = { predicate_idle_prepare, predicate_idle_check, predicate_idle_dispatch, };
+  g_return_val_if_fail (predicate && function, 0);
+  GSource *source = g_source_new (&predicate_idle_funcs, sizeof (PredicateIdle));
+  g_source_set_priority (source, priority);
+  ((PredicateIdle*) source)->predicate = predicate;
+  g_source_set_callback (source, function, data, notify);
+  guint id = g_source_attach (source, NULL);
+  g_source_unref (source);
+  return id;
+}
+
+guint
+g_predicate_idle_add (GSourceFunc     predicate,
+                      GSourceFunc     function,
+                      gpointer        data)
+{
+  return g_predicate_idle_add_full (G_PRIORITY_DEFAULT_IDLE, predicate, function, data, NULL);
+}
+
+/* --- GLib main loop reentrant signal queue --- */
 #if 0
-
-/* GLib main loop reentrant signal queue
- */
 typedef struct _GUSignalData GUSignalData;
 struct _GUSignalData
 {
@@ -1084,7 +1145,6 @@ static GScannerConfig g_scanner_config_template =
   TRUE			/* char_2_token */,
   FALSE			/* symbol_2_token */,
   FALSE			/* scope_0_fallback */,
-  FALSE			/* store_int64 */,
 };
 
 
@@ -1137,7 +1197,7 @@ g_scanner_char_2_num (guchar	c,
 }
 
 GScanner*
-g_scanner_new (const GScannerConfig *config_templ)
+g_scanner_new64 (const GScannerConfig *config_templ)
 {
   GScanner *scanner;
   
@@ -1181,7 +1241,6 @@ g_scanner_new (const GScannerConfig *config_templ)
   scanner->config->char_2_token		 = config_templ->char_2_token;
   scanner->config->symbol_2_token	 = config_templ->symbol_2_token;
   scanner->config->scope_0_fallback	 = config_templ->scope_0_fallback;
-  scanner->config->store_int64		 = config_templ->store_int64;
   
   scanner->token = G_TOKEN_NONE;
   scanner->value.v_int64 = 0;
@@ -1927,10 +1986,7 @@ g_scanner_unexp_token (GScanner		*scanner,
     case G_TOKEN_OCTAL:
     case G_TOKEN_INT:
     case G_TOKEN_HEX:
-      if (scanner->config->store_int64)
-	g_snprintf (token_string, token_string_len, "number `%llu'", scanner->value.v_int64);
-      else
-	g_snprintf (token_string, token_string_len, "number `%lu'", scanner->value.v_int);
+      g_snprintf (token_string, token_string_len, "number `%llu'", scanner->value.v_int64);
       break;
       
     case G_TOKEN_FLOAT:
@@ -2163,10 +2219,7 @@ g_scanner_get_token_i (GScanner	*scanner,
       scanner->config->int_2_float)
     {
       *token_p = G_TOKEN_FLOAT;
-      if (scanner->config->store_int64)
-	value_p->v_float = value_p->v_int64;
-      else
-	value_p->v_float = value_p->v_int;
+      value_p->v_float = value_p->v_int64;
     }
   
   errno = 0;
@@ -2555,10 +2608,7 @@ g_scanner_get_token_ll	(GScanner	*scanner,
 		  break;
 		default: ;
 		}
-	      if (scanner->config->store_int64)
-		value.v_int64 = ui64;
-	      else
-		value.v_int = ui64;
+              value.v_int64 = ui64;
 	    }
 	  if (endptr && *endptr)
 	    {
