@@ -57,6 +57,9 @@ G_BEGIN_DECLS
 #define	g_scanner_remove_symbol( scanner, symbol )	G_STMT_START { \
   g_scanner_scope_remove_symbol ((scanner), 0, (symbol)); \
 } G_STMT_END
+#if GLIB_CHECK_VERSION (2, 4, 0)                // FIXME: remove <=GLib-2.4.0 dependant code
+#define g_value_set_boxed_take_ownership        g_value_take_boxed
+#endif
 
 
 /* --- abandon typesafety for some frequently used functions --- */
@@ -229,6 +232,17 @@ g_bit_matrix_free (GBitMatrix *matrix)
 }
 
 
+/* --- predicate idle --- */
+guint g_predicate_idle_add      (GSourceFunc     predicate,
+                                 GSourceFunc     function,
+                                 gpointer        data);
+guint g_predicate_idle_add_full (gint            priority,
+                                 GSourceFunc     predicate,
+                                 GSourceFunc     function,
+                                 gpointer        data,
+                                 GDestroyNotify  notify);
+
+
 /* --- unix signal queue --- */
 #if 0
 typedef gboolean (*GUSignalFunc) (gint8          usignal,
@@ -290,7 +304,55 @@ type_name##_get_type (void) \
     } \
   return g_define_type_id; \
 }
-#endif /* !G_DEFINE_TYPE */
+#endif /* !G_DEFINE_DATA_TYPE */
+#ifndef G_DEFINE_DATA_TYPE
+#define G_DEFINE_DATA_TYPE(TN, t_n, T_P)                         G_DEFINE_DATA_TYPE_EXTENDED (TN, t_n, T_P, 0, {})
+#define G_DEFINE_DATA_TYPE_WITH_CODE(TN, t_n, T_P, _C_)          G_DEFINE_DATA_TYPE_EXTENDED (TN, t_n, T_P, 0, _C_)
+#define G_DEFINE_ABSTRACT_DATA_TYPE(TN, t_n, T_P)                G_DEFINE_DATA_TYPE_EXTENDED (TN, t_n, T_P, G_TYPE_FLAG_ABSTRACT, {})
+#define G_DEFINE_ABSTRACT_DATA_TYPE_WITH_CODE(TN, t_n, T_P, _C_) G_DEFINE_DATA_TYPE_EXTENDED (TN, t_n, T_P, G_TYPE_FLAG_ABSTRACT, _C_)
+#define G_IMPLEMENT_INTERFACE(TYPE_IFACE, iface_init)       { \
+  static const GInterfaceInfo g_implement_interface_info = { \
+    (GInterfaceInitFunc) iface_init \
+  }; \
+  g_type_add_interface_static (g_define_type_id, TYPE_IFACE, &g_implement_interface_info); \
+}
+#define G_DEFINE_DATA_TYPE_EXTENDED(TypeName, type_name, TYPE_PARENT, flags, CODE) \
+\
+static void     type_name##_init              (TypeName        *self, \
+                                               TypeName##Class *klass); \
+static void     type_name##_class_init        (TypeName##Class *klass, \
+                                               gpointer         class_data); \
+static gpointer type_name##_parent_class = NULL; \
+static void     type_name##_class_intern_init (gpointer klass, \
+                                               gpointer class_data) \
+{ \
+  type_name##_parent_class = g_type_class_peek_parent (klass); \
+  type_name##_class_init ((TypeName##Class*) klass, class_data); \
+} \
+\
+GType \
+type_name##_get_type (void) \
+{ \
+  static GType g_define_type_id = 0; \
+  if (G_UNLIKELY (g_define_type_id == 0)) \
+    { \
+      static const GTypeInfo g_define_type_info = { \
+        sizeof (TypeName##Class), \
+        (GBaseInitFunc) NULL, \
+        (GBaseFinalizeFunc) NULL, \
+        (GClassInitFunc) type_name##_class_intern_init, \
+        (GClassFinalizeFunc) NULL, \
+        NULL,   /* class_data */ \
+        sizeof (TypeName), \
+        0,      /* n_preallocs */ \
+        (GInstanceInitFunc) type_name##_init, \
+      }; \
+      g_define_type_id = g_type_register_static (TYPE_PARENT, #TypeName, &g_define_type_info, flags); \
+      { CODE ; } \
+    } \
+  return g_define_type_id; \
+}
+#endif /* !G_DEFINE_DATA_TYPE */
 
 
 /* --- FIXME: roll our own 64Bit GScanner --- */
