@@ -23,8 +23,6 @@
 #include "sfilog.h"
 #include <string.h>
 
-#define	DEBUG	sfi_nodebug
-
 
 /* --- prototypes --- */
 static SfiGlueIFace*  encoder_describe_iface		(SfiGlueContext *context,
@@ -136,12 +134,13 @@ sfi_glue_encode_message (guint        log_level,
   
   switch (log_level)
     {
+    case SFI_LOG_ERROR:
+    case SFI_LOG_WARN:
+    case SFI_LOG_INFO:
+    case SFI_LOG_DIAG:
+      break;
     default:
       log_level = SFI_LOG_DEBUG;
-    case SFI_LOG_INFO:
-    case SFI_LOG_WARN:
-    case SFI_LOG_ERROR:
-      break;
     }
   
   seq = sfi_seq_new ();
@@ -176,30 +175,31 @@ encoder_process_message (SfiGlueEncoder *encoder,
 	      return TRUE;
 	    }
 	  else
-	    sfi_warn ("Encoder: ignoring message with spurious return value");
+	    sfi_diag ("ignoring message with spurious return value");
 	  break;
 	case SFI_GLUE_CODEC_ASYNC_MESSAGE:
 	  if (seq->n_elements >= 4)
-	    sfi_log (sfi_seq_get_string (seq, 1),
-		     sfi_seq_get_int (seq, 2),
-		     sfi_seq_get_string (seq, 3));
+	    sfi_log_printf (sfi_seq_get_string (seq, 1),
+                            sfi_seq_get_int (seq, 2),
+                            SfiLogger (NULL, NULL, NULL),
+                            sfi_seq_get_string (seq, 3));
 	  else
-	    sfi_warn ("Encoder: ignoring message with invalid message contents");
+	    sfi_diag ("ignoring message with invalid message contents");
 	  break;
 	case SFI_GLUE_CODEC_ASYNC_EVENT:
 	  seq = seq->n_elements >= 2 ? sfi_seq_get_seq (seq, 1) : NULL;
 	  if (seq)
 	    encoder->events = sfi_ring_append (encoder->events, sfi_seq_ref (seq));
 	  else
-	    sfi_warn ("Encoder: ignoring message with NULL event");
+	    sfi_diag ("ignoring message with NULL event");
 	  break;
 	default:
-	  sfi_warn ("Encoder: ignoring message with invalid ID: %u", cmd);
+	  sfi_diag ("ignoring message with invalid ID: %u", cmd);
 	  break;
 	}
     }
   else
-    sfi_warn ("Encoder: ignoring message of invalid type: %s", G_VALUE_TYPE_NAME (value));
+    sfi_diag ("ignoring message of invalid type: %s", G_VALUE_TYPE_NAME (value));
   sfi_value_free (value);
   
   return FALSE;
@@ -786,7 +786,7 @@ decoder_proxy_processed_notify (SfiGlueDecoder *decoder,
   if (seq->n_elements >= 2)
     _sfi_glue_proxy_processed_notify (sfi_seq_get_int (seq, 1));
   else
-    sfi_warn ("ignoring invalid \"processed notify\" receipt");
+    sfi_diag ("ignoring invalid \"processed notify\" receipt");
 }
 
 static GValue*
@@ -889,7 +889,7 @@ decoder_process_request (SfiGlueDecoder *decoder,
   if (!seq || seq->n_elements < 1)
     {
       *one_way = FALSE;
-      sfi_warn ("Decoder: discarding invalid empty request");
+      sfi_diag ("discarding invalid empty request");
       return NULL;
     }
   *one_way = FALSE;
@@ -944,7 +944,7 @@ decoder_process_request (SfiGlueDecoder *decoder,
     case SFI_GLUE_CODEC_CLIENT_MSG:
       return decoder_client_msg (decoder, seq);
     }
-  sfi_warn ("Decoder: ignoring request with invalid ID: %d", cmd);
+  sfi_diag ("ignoring request with invalid ID: %d", cmd);
   return NULL;
 }
 
@@ -1044,9 +1044,7 @@ sfi_glue_decoder_dispatch (SfiGlueDecoder *decoder)
       GValue *rvalue, *value = decoder->incoming;
       gboolean one_way;
       decoder->incoming = NULL;
-      DEBUG ("DECODER: processing request");
       rvalue = decoder_process_request (decoder, value, &one_way);
-      DEBUG ("DECODER: done");
       sfi_value_free (value);
       if (!one_way)
 	{
