@@ -29,8 +29,6 @@
 #include <errno.h>
 
 
-#define SER_INFO	sfi_info_keyfunc ("serialization")
-
 
 /* --- structures --- */
 typedef struct {
@@ -193,11 +191,11 @@ sfi_wstore_put_param (SfiWStore	   *wstore,
       if (g_param_value_validate (spspec, &svalue))
 	{
 	  if (G_VALUE_TYPE (&svalue) != G_VALUE_TYPE (value))
-	    SER_INFO ("fixing up value for \"%s\" of type `%s' (converted from `%s')",
+	    sfi_diag ("fixing up value for \"%s\" of type `%s' (converted from `%s')",
 		      pspec->name, g_type_name (G_VALUE_TYPE (&svalue)),
 		      g_type_name (G_VALUE_TYPE (value)));
 	  else
-	    SER_INFO ("fixing up value for \"%s\" of type `%s'",
+	    sfi_diag ("fixing up value for \"%s\" of type `%s'",
 		      pspec->name, g_type_name (G_VALUE_TYPE (&svalue)));
 	}
       sfi_value_store_param (&svalue, gstring, spspec, wstore->indent);
