@@ -24,12 +24,17 @@
 #include "sfimemory.h"
 #include "sfiprimitives.h"
 #include "sfilog.h"
+#include "sfitime.h"
 #include <sys/time.h>
 #include <sched.h>
 #include <unistd.h>
+#include <stdio.h>
 #include <time.h>
 #include <errno.h>
 #include <string.h>
+#include <sys/resource.h>
+#include <sys/time.h>
+#include <sys/times.h>
 
 
 /* --- structures --- */
@@ -40,6 +45,7 @@ struct _SfiThread
   gpointer	  data;
   gint8		  aborted;
   gint8		  got_wakeup;
+  gint8           accounting;
   SfiCond	 *wakeup_cond;
   SfiThreadWakeup wakeup_func;
   gpointer	  wakeup_data;
@@ -47,6 +53,19 @@ struct _SfiThread
   guint64	  awake_stamp;
   GData		 *qdata;
   gint            tid;
+  /* accounting */
+  struct {
+    struct timeval stamp;
+    gint64         utime, stime;
+    gint64         cutime, cstime;
+  }                ac;
+  struct {
+    guint          processor;
+    gint           priority;
+    SfiThreadState state;
+    gint           utime, stime;
+    gint           cutime, cstime;
+  }                info;
 };
 
 
@@ -64,7 +83,7 @@ sfi_thread_handle_new (const gchar *name)
 {
   SfiThread *thread;
   gint error = 0;
-
+  
   thread = sfi_new_struct0 (SfiThread, 1);
   thread->func = NULL;
   thread->data = NULL;
@@ -101,8 +120,8 @@ sfi_thread_handle_new (const gchar *name)
 #include <sys/types.h>
 #include <sys/syscall.h>
 #include <linux/unistd.h>
-#ifdef  __NR_gettid             /* present on linux >= 2.4.20 */
-static inline _syscall0(pid_t,gettid);
+#ifdef  __NR_gettid                     /* present on linux >= 2.4.20 */
+static inline _syscall0(pid_t,gettid);  /* declares gettid(); */
 #endif
 #endif
 static void
@@ -110,8 +129,8 @@ thread_get_tid (SfiThread *thread)
 {
   gint ppid = thread->tid;      /* creator process id */
   gint tid = -1;
-
-#ifdef  __NR_gettid             /* present on linux >= 2.4.20 */
+  
+#if     defined (__linux__) && defined (__NR_gettid)    /* present on linux >= 2.4.20 */
   tid = gettid ();
 #endif
   if (tid < 0)
@@ -128,43 +147,143 @@ sfi_thread_exec (gpointer thread)
 {
   SfiThread *self;
   sfi_thread_table.thread_set_handle (thread);
-
+  
   self = sfi_thread_self ();
   g_assert (self == thread);
-
+  
   thread_get_tid (thread);
-
+  
   SFI_SYNC_LOCK (&global_thread_mutex);
   global_thread_list = sfi_ring_append (global_thread_list, self);
   sfi_cond_broadcast (&global_thread_cond);
   SFI_SYNC_UNLOCK (&global_thread_mutex);
-
+  
   self->func (self->data);
-
+  
   g_datalist_clear (&self->qdata);
   /* sfi_thread_handle_deleted() does final destruction */
   return NULL;
 }
 
+static inline unsigned long long int
+timeval_usecs (const struct timeval *tv)
+{
+  return tv->tv_usec + tv->tv_sec * (guint64) 1000000;
+}
+
+static void
+thread_info_from_stat_L (SfiThread *self,
+                         double     usec_norm)
+{
+  int pid = -1, ppid = -1, pgrp = -1, session = -1, tty_nr = -1, tpgid = -1;
+  int exit_signal = 0, processor = 0;
+  long cutime = 0, cstime = 0, priority = 0, nice = 0, dummyld = 0;
+  long itrealvalue = 0, rss = 0;
+  unsigned long flags = 0, minflt = 0, cminflt = 0, majflt = 0, cmajflt = 0;
+  unsigned long utime = 0, stime = 0, vsize = 0, rlim = 0, startcode = 0;
+  unsigned long endcode = 0, startstack = 0, kstkesp = 0, kstkeip = 0;
+  unsigned long signal = 0, blocked = 0, sigignore = 0, sigcatch = 0;
+  unsigned long wchan = 0, nswap = 0, cnswap = 0, rt_priority = 0, policy = 0;
+  unsigned long long starttime = 0;
+  char state = 0, command[8192 + 1] = { 0 };
+  FILE *file = NULL;
+  int n = 0;
+  static int success = 1;
+  if (success)
+    {
+      gchar *filename = g_strdup_printf ("/proc/%u/stat", self->tid);
+      file = fopen (filename, "r");
+      g_free (filename);
+      if (!file)
+        success = 0;    /* reading /proc/self/stat should _always_ succeed */
+    }
+  if (file)
+    n = fscanf (file,
+                "%d %8192s %c "
+                "%d %d %d %d %d "
+                "%lu %lu %lu %lu %lu %lu %lu "
+                "%ld %ld %ld %ld %ld %ld "
+                "%llu %lu %ld "
+                "%lu %lu %lu %lu %lu "
+                "%lu %lu %lu %lu %lu "
+                "%lu %lu %lu %d %d "
+                "%lu %lu",
+                &pid, command, &state, /* n=3 */
+                &ppid, &pgrp, &session, &tty_nr, &tpgid, /* n=8 */
+                &flags, &minflt, &cminflt, &majflt, &cmajflt, &utime, &stime, /* n=15 */
+                &cutime, &cstime, &priority, &nice, &dummyld, &itrealvalue, /* n=21 */
+                &starttime, &vsize, &rss, /* n=24 */
+                &rlim, &startcode, &endcode, &startstack, &kstkesp, /* n=29 */
+                &kstkeip, &signal, &blocked, &sigignore, &sigcatch, /* n=34 */
+                &wchan, &nswap, &cnswap, &exit_signal, &processor, /* n=39 */
+                &rt_priority, &policy /* n=41 */
+                );
+  if (file)
+    fclose (file);
+  
+  if (n >= 3)
+    self->info.state = state;
+  if (n >= 39)
+    self->info.processor = 1 + processor;
+}
+
+#define ACCOUNTING_MSECS        (500)
+
+static inline void
+sfi_thread_accounting_L (SfiThread *self)
+{
+  struct timeval stamp, ostamp = self->ac.stamp;
+  guint diff = 0;
+  if (self->accounting)
+    {
+      gettimeofday (&stamp, NULL);
+      diff = timeval_usecs (&stamp) - timeval_usecs (&ostamp);
+      diff = MAX (diff, 0);
+    }
+  if (diff >= ACCOUNTING_MSECS * 1000)  /* limit accounting to a few times per second */
+    {
+      struct rusage res = { { 0 } };
+      gint64 utime = self->ac.utime;
+      gint64 stime = self->ac.stime;
+      gdouble dfact = 1000000.0 / diff;
+      self->ac.stamp = stamp;
+      getrusage (RUSAGE_SELF, &res);
+      self->ac.utime = timeval_usecs (&res.ru_utime); /* user time used */
+      self->ac.stime = timeval_usecs (&res.ru_stime); /* system time used */
+      self->info.utime = MAX (self->ac.utime - utime, 0) * dfact;
+      self->info.stime = MAX (self->ac.stime - stime, 0) * dfact;
+      utime = self->ac.cutime;
+      stime = self->ac.cstime;
+      getrusage (RUSAGE_CHILDREN, &res);
+      self->ac.cutime = timeval_usecs (&res.ru_utime);
+      self->ac.cstime = timeval_usecs (&res.ru_stime);
+      self->info.cutime = MAX (self->ac.cutime - utime, 0) * dfact;
+      self->info.cstime = MAX (self->ac.cstime - stime, 0) * dfact;
+      self->info.priority = getpriority (PRIO_PROCESS, self->tid);
+      thread_info_from_stat_L (self, dfact);
+      self->accounting--;
+    }
+}
+
 void
 sfi_thread_handle_deleted (SfiThread *thread)
 {
   g_datalist_clear (&thread->qdata);
-
+  
   if (thread->wakeup_destroy)
     {
       GDestroyNotify wakeup_destroy = thread->wakeup_destroy;
       thread->wakeup_destroy = NULL;
       wakeup_destroy (thread->wakeup_data);
     }
-
+  
   SFI_SYNC_LOCK (&global_thread_mutex);
   global_thread_list = sfi_ring_remove (global_thread_list, thread);
   if (thread->awake_stamp)
     thread_awaken_list = sfi_ring_remove (thread_awaken_list, thread);
   sfi_cond_broadcast (&global_thread_cond);
   SFI_SYNC_UNLOCK (&global_thread_mutex);
-
+  
   if (thread->wakeup_cond)
     {
       sfi_cond_destroy (thread->wakeup_cond);
@@ -208,16 +327,16 @@ sfi_thread_run (const gchar  *name,
   guint hid = 0;
   
   g_return_val_if_fail (func != NULL, FALSE);
-
+  
   /* silence those stupid priority warnings triggered by glib */
   hid = g_log_set_handler ("GLib", G_LOG_LEVEL_WARNING, filter_priority_warning, NULL);
-
+  
   /* create thread */
   thread = sfi_thread_handle_new (name);
   if (thread)
     {
       const gboolean joinable = FALSE;
-
+      
       /* don't dare setting joinable to TRUE, that prevents the thread's
        * resources from being freed, since we don't offer pthread_join().
        * so we'd just run out of stack at some point.
@@ -228,7 +347,7 @@ sfi_thread_run (const gchar  *name,
       gthread = g_thread_create_full (sfi_thread_exec, thread, 0, joinable, FALSE,
 				      G_THREAD_PRIORITY_NORMAL, &gerror);
     }
-
+  
   if (gthread)
     {
       SFI_SYNC_LOCK (&global_thread_mutex);
@@ -246,10 +365,10 @@ sfi_thread_run (const gchar  *name,
       g_message ("failed to create thread \"%s\": %s", name ? name : "Anon", gerror->message);
       g_error_free (gerror);
     }
-
+  
   /* withdraw warning filter */
   g_log_remove_handler ("GLib", hid);
-
+  
   return thread;
 }
 
@@ -262,7 +381,7 @@ SfiThread*
 sfi_thread_self (void)
 {
   SfiThread *thread = sfi_thread_table.thread_get_handle ();
-
+  
   if (!thread)
     {
       thread = sfi_thread_handle_new (NULL);
@@ -277,6 +396,19 @@ sfi_thread_self (void)
   return thread;
 }
 
+void
+sfi_thread_set_name (const gchar *name)
+{
+  SfiThread *thread = sfi_thread_self ();
+  if (name)
+    {
+      SFI_SYNC_LOCK (&global_thread_mutex);
+      g_free (thread->name);
+      thread->name = g_strdup (name);
+      SFI_SYNC_UNLOCK (&global_thread_mutex);
+    }
+}
+
 /**
  * sfi_thread_self_pid
  * @RETURNS: thread id
@@ -304,27 +436,32 @@ sfi_thread_wakeup_L (SfiThread *thread)
 /**
  * sfi_thread_sleep
  * @max_useconds: maximum amount of micro seconds to sleep (-1 for infinite time)
- * @returns:      %TRUE if the thread should continue execution
+ * @returns:      %TRUE while the thread should continue execution
  * Sleep for the amount of time given.
  * This function may get interrupted by wakeup requests from
  * sfi_thread_wakeup(), abort requests from sfi_thread_queue_abort()
  * or other means. It returns whether the thread is supposed to
  * continue execution after waking up.
+ * This function or alternatively sfi_thread_aborted() should be called
+ * periodically, to react to thread abortion requests and to update
+ * internal accounting information.
  */
 gboolean
 sfi_thread_sleep (glong max_useconds)
 {
   SfiThread *self = sfi_thread_self ();
   gboolean aborted;
-
+  
   SFI_SYNC_LOCK (&global_thread_mutex);
   if (!self->wakeup_cond)
     {
       self->wakeup_cond = g_new0 (SfiCond, 1);
       sfi_cond_init (self->wakeup_cond);
     }
-
-  if (!self->got_wakeup)
+  
+  sfi_thread_accounting_L (self);
+  
+  if (!self->got_wakeup && max_useconds != 0)
     {
       if (max_useconds >= 0) /* wait once without time adjustments */
 	sfi_cond_wait_timed (self->wakeup_cond, &global_thread_mutex, max_useconds);
@@ -332,11 +469,11 @@ sfi_thread_sleep (glong max_useconds)
 	while (!self->got_wakeup)
 	  sfi_cond_wait (self->wakeup_cond, &global_thread_mutex);
     }
-
+  
   self->got_wakeup = FALSE;
   aborted = self->aborted != FALSE;
   SFI_SYNC_UNLOCK (&global_thread_mutex);
-
+  
   return !aborted;
 }
 
@@ -357,10 +494,10 @@ sfi_thread_set_wakeup (SfiThreadWakeup wakeup_func,
 		       GDestroyNotify  destroy)
 {
   SfiThread *self = sfi_thread_self ();
-
+  
   g_return_if_fail (wakeup_func != NULL);
   g_return_if_fail (self->wakeup_func == NULL);
-
+  
   SFI_SYNC_LOCK (&global_thread_mutex);
   self->wakeup_func = wakeup_func;
   self->wakeup_data = wakeup_data;
@@ -379,7 +516,7 @@ void
 sfi_thread_wakeup (SfiThread *thread)
 {
   g_return_if_fail (thread != NULL);
-
+  
   SFI_SYNC_LOCK (&global_thread_mutex);
   g_assert (sfi_ring_find (global_thread_list, thread));
   sfi_thread_wakeup_L (thread);
@@ -397,9 +534,9 @@ void
 sfi_thread_awake_after (guint64 stamp)
 {
   SfiThread *self = sfi_thread_self ();
-
+  
   g_return_if_fail (stamp > 0);
-
+  
   SFI_SYNC_LOCK (&global_thread_mutex);
   if (!self->awake_stamp)
     {
@@ -422,9 +559,9 @@ void
 sfi_thread_emit_wakeups (guint64 wakeup_stamp)
 {
   SfiRing *ring, *next;
-
+  
   g_return_if_fail (wakeup_stamp > 0);
-
+  
   SFI_SYNC_LOCK (&global_thread_mutex);
   for (ring = thread_awaken_list; ring; ring = next)
     {
@@ -453,7 +590,7 @@ sfi_thread_abort (SfiThread *thread)
 {
   g_return_if_fail (thread != NULL);
   g_return_if_fail (thread != sfi_thread_self ());
-
+  
   SFI_SYNC_LOCK (&global_thread_mutex);
   g_assert (sfi_ring_find (global_thread_list, thread));
   thread->aborted = TRUE;
@@ -487,18 +624,22 @@ sfi_thread_queue_abort (SfiThread *thread)
  * sfi_thread_aborted
  * @returns: %TRUE if the thread should abort execution
  * Find out if the currently running thread should be aborted (the thread is
- * supposed to return from its main thread function).
+ * supposed to return from its main thread function). This function or
+ * alternatively sfi_thread_sleep() should be called periodically, to
+ * react to thread abortion requests and to update internal accounting
+ * information.
  */
 gboolean
 sfi_thread_aborted (void)
 {
   SfiThread *self = sfi_thread_self ();
   gboolean aborted;
-
+  
   SFI_SYNC_LOCK (&global_thread_mutex);
+  sfi_thread_accounting_L (self);
   aborted = self->aborted != FALSE;
   SFI_SYNC_UNLOCK (&global_thread_mutex);
-
+  
   return aborted;
 }
 
@@ -534,28 +675,65 @@ sfi_cond_wait_timed (SfiCond  *cond,
 {
   if (max_useconds < 0)
     sfi_cond_wait (cond, mutex);
-  else
+  else if (max_useconds > 0)
     {
-      struct timeval now;
-      glong secs;
-
+      struct timeval now, limit;
+      glong secs = max_useconds / 1000000;
       gettimeofday (&now, NULL);
-      secs = max_useconds / 1000000;
-      now.tv_sec += secs;
+      limit.tv_sec = now.tv_sec + secs;
       max_useconds -= secs * 1000000;
-      now.tv_usec += max_useconds;
-      if (now.tv_usec >= 1000000)
-	{
-	  now.tv_usec -= 1000000;
-	  now.tv_sec += 1;
-	}
-
-      /* linux on x86 with pthread has actually 10ms resolution */
-      sfi_thread_table.cond_wait_timed (cond, mutex, now.tv_sec, now.tv_usec);
+      limit.tv_usec = now.tv_usec + max_useconds;
+      if (limit.tv_usec >= 1000000)
+        {
+          limit.tv_usec -= 1000000;
+          limit.tv_sec += 1;
+        }
+      
+      sfi_thread_table.cond_wait_timed (cond, mutex, limit.tv_sec, limit.tv_usec);
     }
 }
 
 
+/* --- thread info --- */
+SfiThreadInfo*
+sfi_thread_info_collect (SfiThread *thread)
+{
+  SfiThreadInfo *info = g_new0 (SfiThreadInfo, 1);
+  struct timeval now;
+  gboolean recent = TRUE;
+  if (!thread)
+    thread = sfi_thread_self ();
+  gettimeofday (&now, NULL);
+  SFI_SYNC_LOCK (&global_thread_mutex);
+  info->name = g_strdup (thread->name);
+  info->aborted = thread->aborted;
+  info->thread_id = thread->tid;
+  if (timeval_usecs (&thread->ac.stamp) + ACCOUNTING_MSECS * 1000 < timeval_usecs (&now))
+    recent = FALSE;             /* accounting data too old */
+  info->state = thread->info.state;
+  info->priority = thread->info.priority;
+  info->processor = thread->info.processor;
+  if (recent)
+    {
+      info->utime = thread->info.utime;
+      info->stime = thread->info.stime;
+      info->cutime = thread->info.cutime;
+      info->cstime = thread->info.cstime;
+    }
+  thread->accounting = 5;       /* update accounting info in the future */
+  SFI_SYNC_UNLOCK (&global_thread_mutex);
+  return info;
+}
+
+void
+sfi_thread_info_free (SfiThreadInfo  *info)
+{
+  g_return_if_fail (info != NULL);
+  g_free (info->name);
+  g_free (info);
+}
+
+
 /* --- fallback (GLib) SfiThreadTable --- */
 static GPrivate *fallback_thread_table_key = NULL;
 
@@ -588,13 +766,13 @@ static void
 fallback_mutex_lock (SfiMutex *mutex)
 {
   static gboolean is_smp_system = FALSE; // FIXME
-
+  
   /* spin locks should be held only very short times,
    * so usually, we should succeed here.
    */
   if (g_mutex_trylock (mutex->mutex_pointer))
     return;
-
+  
   if (!is_smp_system)
     {
       /* on uni processor systems, there's no point in busy spinning */
@@ -642,7 +820,7 @@ static int
 fallback_rec_mutex_trylock (SfiRecMutex *rec_mutex)
 {
   SfiThread *self = sfi_thread_self ();
-
+  
   if (rec_mutex->owner == self)
     {
       g_assert (rec_mutex->depth > 0);  /* paranoid */
@@ -666,7 +844,7 @@ static void
 fallback_rec_mutex_lock (SfiRecMutex *rec_mutex)
 {
   SfiThread *self = sfi_thread_self ();
-
+  
   if (rec_mutex->owner == self)
     {
       g_assert (rec_mutex->depth > 0);  /* paranoid */
@@ -685,7 +863,7 @@ static void
 fallback_rec_mutex_unlock (SfiRecMutex *rec_mutex)
 {
   SfiThread *self = sfi_thread_self ();
-
+  
   if (rec_mutex->owner == self && rec_mutex->depth > 0)
     {
       rec_mutex->depth -= 1;
@@ -720,7 +898,7 @@ fallback_cond_init (SfiCond *cond)
 
 static void
 fallback_cond_wait (SfiCond  *cond,
-		   SfiMutex *mutex)
+                    SfiMutex *mutex)
 {
   /* infinite wait */
   g_cond_wait (cond->cond_pointer, mutex->mutex_pointer);
@@ -746,12 +924,12 @@ fallback_cond_destroy (SfiCond *cond)
 
 static void
 fallback_cond_wait_timed (SfiCond  *cond,
-			 SfiMutex *mutex,
-			 gulong    abs_secs,
-			 gulong    abs_usecs)
+                          SfiMutex *mutex,
+                          gulong    abs_secs,
+                          gulong    abs_usecs)
 {
   GTimeVal gtime;
-
+  
   gtime.tv_sec = abs_secs;
   gtime.tv_usec = abs_usecs;
   g_cond_timed_wait (cond->cond_pointer, mutex->mutex_pointer, &gtime);
@@ -832,7 +1010,7 @@ pth_cond_wait_timed (SfiCond  *cond,
 		     gulong    abs_usecs)
 {
   struct timespec abstime;
-
+  
   abstime.tv_sec = abs_secs;
   abstime.tv_nsec = abs_usecs * 1000;
   pthread_cond_timedwait ((pthread_cond_t*) cond, (pthread_mutex_t*) mutex, &abstime);
@@ -862,7 +1040,7 @@ get_pth_thread_table (void)
 {
   if (pthread_key_create (&pth_thread_table_key, (void(*)(void*)) sfi_thread_handle_deleted) != 0)
     {
-      sfi_info ("failed to create pthread key, falling back to GLib threads");
+      sfi_diag ("failed to create pthread key, falling back to GLib threads");
       return NULL;
     }
   return &pth_thread_table;
@@ -878,10 +1056,10 @@ _sfi_init_threads (void)
   if (!table)
     table = get_fallback_thread_table ();
   sfi_thread_table = *table;
-
+  
   sfi_mutex_init (&global_thread_mutex);
   sfi_cond_init (&global_thread_cond);
-
+  
   _sfi_init_memory ();
   
   sfi_thread_self ();
